/* NOTE: 
* SAVE THIS FILE AND ALL OTHER DOFILES IN THIS REPLICATION FOLDER IN "D:\Replication"
* ALL OTHER NECESSARRY PATHS ARE IN THE D-DISK "Uruguay" AND SHARED BETWEEN USERS - NO NEED TO CHANGE. 
* THE FOLDERS "proc_data_AEJ" and "replication_AEJ" are empty and will collect all the processed data and output. 
* SEE NOTE IN LINE 49-50 TO DECOMPRESS DATA
*/

*-------------------------------------------------------------------------------
*0. Path:
*-------------------------------------------------------------------------------

	clear
	clear matrix
	set more off

	glo rootdir "D:\Uruguay"
	
	* CD to output folder
	cd "$rootdir\output\replication_AEJ"

	* Raw Data
	glo rawdatadir "$rootdir\data\Raw Data original format"
	glo trans_raw  "$rawdatadir\Card Transaction\detalle_tarjeta_text_files"
	glo vat_raw    "$rawdatadir\VAT returns"
	glo stata_raw  "$rootdir\data\stata"
	
	*Proc Data
	glo datadir "$rootdir\proc_data_AEJ"
	
	*Code 
	if c(username)=="s382635" {
	glo codes "C:\Users\s382635\Uruguay\do_files\Replication do files"
	}
	if c(username)=="s552941" {
	glo codes "C:\Users\s552941\Uruguay\do_files\Replication do files"
	}
	else {
	glo codes "D:\Replication"
	}
	
	
cap log close
log using "replication_AEJ.log", replace 
display c(current_time)
*-------------------------------------------------------------------------------
*1. Data Cleaning
*-------------------------------------------------------------------------------
* Importing data from original format to dta
/* the card transaction data is heavy so we keep the zipped files. We unzipped the files for the replication, but the code deletes the unzipped version once it's processed. In case you need to run again, you will need to unzip the files in:
"D:\Uruguay\data\Raw Data original format\Card Transaction\detalle_tarjeta_text_files"*/
*do "$codes\c_importing_data.do"

* Card Transaction Level Data
do "$codes\c_rd_cleaning_transactions.do"

** CIT data 
do "$codes\c_cit_cleaning.do"

* Monthly VAT returns long format 
do "$codes\c_vat_returns_month_long.do"

* Annual VAT return data 
do "$codes\c_annual_vat_returns_long.do"

* DiD Heterogeneity Data
do "$codes\c_did_heterogeneity.do"

*-------------------------------------------------------------------------------
*2.Regression Discontinuity in Time
*-------------------------------------------------------------------------------
/*MONTHLY TRENDS OF TRANSACTION OUTCOMES
this do files creates Fig 1 (main paper) and Fig B1 (appendix)*/
do "$codes\rdd_trends_transformed_f1.do"

/*WEEKLY RD ANALYSIS
this do file creates panel A of Fig 2 (main paper) and panel A of Fig B6
(input in line 80 one or both of the analysis to execute)
		--> main executes panel A of Fig 2 (prefered main specification)
		--> jan13 executes panel A of Fig b6 (allowing trend break in Jan 2013)*/
global option_rd main jan13  

do "$codes\rdd_graphs_main.do"

/*MONTH ON MONTH GROWTH RATES HISTORGRAM
*creates figs for panel B of Fig 2 (main paper)
*creates fig for pabel B of Fig B6. (appendix)
(as before specify in line 91 the analysis to execute)
		--> main executes panel A of Fig 2 (prefered main specification)
		--> jan13 executes panel A of Fig b6 (allowing trend break in Jan 2013)*/

global option_hist main jan13
 
do "$codes\rdd_week_histograms_main.do"


* RD ANALYSIS AND MONTH ON MONTH GROWTH TRENDS FOR RETAIL FIRMS IN LOW ADOPTION SUBSECTORS 
*creates figs B3 (appendix)
do "$codes\rdd_low_sector_adoption"

/*ROBUSTNESS OF RDD ANALYSIS TO DIFFERENT BANDWIDTHS AND POLYNOMIALS 
do rd_robustness_bw_0815
* creates figs for Fig B4 (appendix)
* creates figs for Fig B5 (appendix)
(specify in line 108 the analysis to execute)
		--> main (Fig B5) executes the robustness to the prefered main specification 
		--> 0815 (Fig B4) executes the analysis for the of VAT reductions in August 2015*/

global option_rd_robust main 0815 

do "$codes\rdd_robustness_bw.do"


/* VAT OUTCOMES RD*/
*CREATES FIG B10  (appendix)
do "$codes\rdd_vat_outcomes.do"


/* WEEKLY RD AT THE FIRM LEVEL 
creates fig B2 (appendix)*/
do "$codes\rdd_firm"

*DISTRIBUTION OF REBATE RATES
*creates panel A and B for Fig b11 (appendix)
do "$codes\rdd_distribution_rebate"

*creates panel C for fig b11 (appendix)
do "$codes\rdd_rebate_rate_dist"


/* PLACEBO TEST VARYING THE WEEK OF INTRODUCTION
* creates figs for Fig B7 (appendix)*/
do "$codes\rdd_histograms_random.do"

*week on week growht rates 
* creates fig for Fig b9 (appendix)
do "$codes\rdd_histograms_weekly.do"


/*RD estimates varying the level of aggregation */
*creates table B1  (appendix)
do "$codes\rdd_level_aggregation.do"

/* Donut RD 
creates table B2 (appendix)*/
do "$codes\rdd_SRS_donut.do"

/*RD two steps estimation 
creates table B3 (appendix)*/
do "$codes\rdd_steps.do"

/* RD robustness to heterogeneity 
creates table B4, B5 and B6 (appendix) */
do "$codes\rdd_autoregression.do"

/* RD firm rebate rate heterogeneity (RD)
creates fig B12 (appendix)*/
do "$codes\rdd_het_rebate_rate.do"

/* RD firm rebate rate heterogeneity (DID)
creates fig B13 (appendix) (for a test run change parameters in lines 162-164)*/

global random_s 100 /* only set up to 50 or 100*/
global run_time 10
global replication 10
do "$codes\rdd_did_year_rebate_share.do"

*-------------------------------------------------------------------------------
*3.Difference in Difference
*-------------------------------------------------------------------------------
/*creates fig 1 (main paper) and Fig C1-C3 (Appendix)
*creates table 1 (main paper) and table (C1-C7)
* "did_setup" sets the specification utilized in each item and then runs "did_implementation"
* running all the items will take about 3-4 days. (For a test run, change parameters in line 194-197)
* specify which item to execute in line 191
	--> fig1_ab fig1_c (Fig 1) DID Preferred Specification 
	--> figc1_ab figc1_c  (Fig C1) Robustness to Alternate Specifications
	--> figc2_ab figc2_c (Fig C2) Control group: Wholesale without POS 
	--> figc3_ab figc3_c (Fig C3) Control group: Service Sector 
	--> tab1_ab tab1_c  (Table 1) Alternate Specifications 
	--> tabc1_ab tabc1_c (Table C1) Robustness to varying epsilon 
	--> tab_c2_ab tab_c2_ca tab_c2_cb (Table C2) Extensive Margin Response
	--> tab_c3_ab tab_c3_ca tab_c3_cb (Table C3) Intensive Margin Response 
	--> tab_c4 (Table C5) Robustness to varying balancing and FE 
	--> tab_c5 (Table C6) Monthly Estimates and Robustness to varying balancing and FE 
	--> tabc6_ab tabc6_c Robustness to varying time frame
	--> tabc7_ab tabc7_c (Table C7) Same as table 1 but wholesale without pos as the control group*/
	
* WARNING: FOR THE TABLES COMPOSED OF TWO OR MORE PARTS (EX: tab1_ab tab1_c), YOU SHOULD RUN THEM TOGETHER, OTHERWISE THE CODE WILL BREAK. 	
	

global option_did_set  fig1_ab fig1_c figc1_ab figc1_ca figc1_cb figc2_ab figc2_c figc3_ab figc3_c tab1_ab tab1_ca ///
tab1_cb tabc1_ab tabc1_c tab_c2_ab tab_c2_ca tab_c2_cb tab_c3_ab tab_c3_ca tab_c3_cb tab_c4 tab_c5 tabc6_ab tabc6_c tabc7_ab tabc7_c

global random_s 100 /* only set up to 50 or 100*/
global run_time 10
global replication 10
do "$codes\did_setup.do"

/* DID HETEROGENEITY BY SIZE OF THE RD FIRST STAGE */

	*creates subsector first stage
	do "$codes\did_rd_subsector_first_stage.do"
	* creates region first stage 
	do "$codes\did_rd_region_first_stage.do"
	
		* creates C4 panels AI, AII, BI and B2 (Appendix)
		do "$codes\did_bar_size_rd.do"
		*creates C4 panels AIII and BIII (Appendix)
		do "$codes\did_descriptive_subsectors.do"
		
		*DID with size of the first stage
		*creates c5 and c6
		*global het_by selects between heterogeneity by region(3) and/or by sector (4)
		global het_by 3 4
		global random_s 100 /* only set up to 50 or 100*/
		global run_time 10
		global replication 10

		do "$codes\did_heterogeneity_region_sector"
		
		*Triple DID
		*creates table C8 (appendix)*/
		do "$codes\did_triple_log_modif.do"

*-------------------------------------------------------------------------------
*4.Descriptive, Context and Supplemental Analysis
*-------------------------------------------------------------------------------
/* DESCRIPTIVE STATS TABLE
creates table A3 (appendix)*/
do "$codes\s_descriptive_stats.do"

/* BUNCHING CARD TRANSACTIONS
creates fig A3 (appendix)*/
do "$codes\s_UI_trans_distribution.do"

/*Variation rebates rates across sectors
creates table A7 (appendix) */
do "$codes\s_rebrate_sectors.do"

/*FILERS BY MONTH
creates table A10 (appendix) */
do "$codes\s_vat_filers_firms.do"

/* Impact Reduction Comission Fees and Tax WH rates
creates fig D1 */
do "$codes\s_trends_subsidy.do"

/*Effect on share of firms with POS
creates fig D2 */
do "$codes\s_hascard_final.do"

/* DID estimates
creates fig D3*/
do "$codes\s_did_jan2012.do"

/* FISCAL COST*/
do "$codes\s_cost_est.do"


/* POS Adoption Appendix
creates tables E1-E4*/
do "$codes\s_difference_hascard.do"

/* NO EFFECT RATIONALE
creates fig 4 (main paper)*/
*Panel A
do "$codes\s_subsidy_firms_share.do"
*Panel B
do "$codes\s_event_study_log_b.do"
*Panel C
do "$codes\s_card_sales_v_reported_sales.do"


/* SHARE OF CARD SALES IN COSTA RICA */
* Fig D4 (appendix)
do "$codes\s_share_cardsales_costa_rica.do"

display c(current_time)

log close 
