

****************************************************************
****** construction of the base for rebate rate heterogeneity 
****************************************************************

		use "$stata_raw\card_data_ext_2014.dta", clear

		*keeping local currency transactions
		keep if moneda==1

		*keeping only september 2014 (month after reform)
		keep if month==9

		*rebate id var 
		gen rebate=(tot_credito>0 & tot_credito!=.)

		* rebate rate
		gen rebate_fraction=(tot_credito/tot_venta) if rebate==1
		replace rebate_fraction=0 if rebate==0
		
		*rebate type tag 
		gen high=rebate_fraction>.05
		gen zero=rebate_fraction==0
		
		*dropping transactions with high rebate rate
		drop if high==1

		*weight by sales 
		egen tot_sales=sum(tot_venta), by(id_afi)
		gen share_venta=tot_venta/tot_sales
		*rebate rate weighted
		gen rebate_fraction_w=share_venta*rebate_fraction

		*collapse firm level 
		collapse (mean) rebate_fraction (sum) tot_credito tot_venta rebate rebate_fraction_w ///
		(count) moneda, by(id_afi month)
		drop if id_afi==0
		drop month
		
		*dropping firms with zero sales 
		drop if tot_venta==0

		rename tot_credito amount_rebate
		rename tot_venta tot_trans_amount
		rename rebate count_rebate
		rename moneda count_trans
		rename id_afi ide

		rename rebate_fraction rebate_fraction_s
		
		sum rebate_fraction_w, d

		gen above_median=rebate_fraction_w>=r(p50)
		gen above_mean=rebate_fraction_w>=r(mean)

		save "${datadir}/firm_rebate_rate_0914.dta", replace
		

*********************************************************************
***** Subsector POS adoption 
*********************************************************************

		use "${datadir}/data_ab_11.dta", clear
		
		*keeping retail and wholesale firms in 2013 
		keep if (retail==1 | wholesale==1) & year==2013

		egen maxcard=max(hascard), by(ide year)

		*sector code 
		gen sector4=floor(codgiro/10)
		gen sector3=floor(sector4/10)

		*collapsing at the sector level

		collapse (mean) maxcard retail (count) nfirms=maxcard (sum) count_card=maxcard, by(sector4)
		
		*dropping sectors with less than 10 firms 
		drop if nfirms<10

		*Treatment assigns across retail and wholesale
			sum maxcard, d
			* treatment greater than p75 
			gen treat2=(maxcard>=r(p75))
			* treatment greated than median 
			gen treat3=(maxcard>r(p50))
			* treatment greated than p25 
			gen treat4=(maxcard>r(p25))
			* treatment greated than 50%
			gen treat5=(maxcard>.5)			
			
		*Treatment assignment with retailers only
			sum maxcard if retail==1, d		
			* treatment greater than p75
			gen _treat2=(maxcard>=r(p75))
			* treatment greated than median 
			gen _treat3=(maxcard>r(p50))	
			* treatment greated than p25 
			gen _treat4=(maxcard>r(p25))
			* treatment greated than 50%
			gen _treat5=(maxcard>.5)		
			foreach t in _treat2 _treat3 _treat4 _treat5 {
				replace `t'=. if retail==0
			}
			
		sort sector4
		gen subsector=_n

		save "${datadir}/treat_sector_n.dta", replace


****************************************************************
* Regional POS Adoption
****************************************************************
		
		use "${datadir}/data_ab_11.dta", clear

		keep if (retail==1 | wholesale==1) & year==2013

		* identifying firms with POS at any time within the year
		egen maxcard=max(hascard), by(ide year)
		duplicates drop ide year, force	
		
		recode coddeptofiscal (1=1 "Artigas") (2=2 "Canelones") /// 
		(3=3 "Cerro Largo") (4=4 "Colonia") (5=5 "Durazno") (6=6 "Flores") ///
		(7=7 "Florida") (8=8 "Lavalleja") (9=9 "Maldonado") (10=10 "Montevideo") ///
		(11=11 "Paysandu") (12=12 "Rio Negro") (13=13 "Rivera") (14=14 "Rocha")  /// 
		(15=15 "Salto") (16=16 "San Jose") (17=17 "Soriano") (18=18 "Tacuarembo") ///
		(19=19 "Treinta y Tres"), gen(state)		
		
		
	*Loop to create treatement based on retailers only
		preserve
		keep if retail==1 
		
		*collapse at the region level
		collapse (mean) maxcard retail (count) count=maxcard (sum) count_card=maxcard , by(coddeptofiscal)
					// montevideo and lavallejo have lowest penetration
					
		*Treatment 
			sum maxcard, d
			* treatment greater than p75 
			gen treat2=(maxcard>=r(p75))
			* treatment greater than median 
			gen treat3=(maxcard>r(p50))
			* treatment greater than p25 
			gen treat4=(maxcard>=r(p25))

			
		keep coddeptofiscal treat2 treat3 treat4 
		sort coddeptofiscal
		gen departamento=_n
		
		tempfile treat_retailers
		sa `treat_retailers'
		restore
			
	*Loop to create treatment based on RT+WS
		
		keep if retail==1 | retail==0
		
		*collapse at the region level
		collapse (mean) maxcard retail (count) count=maxcard (sum) count_card=maxcard , by(coddeptofiscal)
					// penetration from bottom up: montevideo, soriano, lavalleja
		*Treatment 
			sum maxcard, d
			* treatment greater than 75th percentile 
			gen treat6=(maxcard>=r(p75))
			* treatment greated than median 
			gen treat7=(maxcard>r(p50))
			* treatment greater than 50% rate
			gen treat8=(maxcard>.5)
			
		sort coddeptofiscal
		gen departamento=_n
		
		merge 1:1 departamento using `treat_retailers'		
		drop _merge
		
		save "${datadir}/reg_adop2013_n.dta", replace


****************************************************************
*Firm Characteristics 
****************************************************************

		use "${datadir}/data_ab_11.dta", clear
		keep if (retail==1 | wholesale==1) & year==2013
		
		gen sector4=floor(codgiro/10)

		rename ide id_afi

		merge m:1 coddeptofiscal using "${datadir}/reg_adop2013_n.dta", gen(merge_adop)
		keep if merge_adop==3
		drop merge_adop
		
		
		merge m:1 sector4 using "${datadir}/treat_sector_n.dta", gen(merge_sector)
		keep if merge_sector==3
		drop merge_sector

		keep id_afi coddeptofiscal retail sector4 departamento subsector 		
		save "${datadir}/firm_characteristics_heterogeneity.dta", replace

