*-------------------------------------------------------------------------------
*1 CARD TRANSACTION DATA
*-------------------------------------------------------------------------------
foreach year in 2007 2008 2009 2010 2011 2012 2013 2014 2015 2016 20161  {

 import delimited "$trans_raw\detalle_tarjeta_`year'.txt", clear

	*date setting
	tostring fecha_oper , gen(date)
	gen month=substr(date,5,2)
	gen day=substr(date,7,2)
	destring month, replace
	destring day, replace
	gen year=`year'
		
 save "$stata_raw\card_data_ext_`year'.dta", replace 
 
*erase "$trans_raw\detalle_tarjeta_`year'.txt"

}


*-------------------------------------------------------------------------------
*2 VAT Return Data
*-------------------------------------------------------------------------------
* CEDE firms
import delimited "$vat_raw\2176_2006_2016_entregar.txt", clear
save "$stata_raw\cede_vat_returns.dta", replace 

import delimited "$vat_raw\2178_2006_2016_entregar.txt", clear
save "$stata_raw\non-cede_vat_returns.dta", replace 

*-------------------------------------------------------------------------------
*3 Taxpayer Characteristics
*-------------------------------------------------------------------------------
import excel "$rawdatadir\Others\Características contribuyentes (parte 1).xlsx", sheet("datos1") firstrow clear
rename *, lower
save "$stata_raw\taxpayers_1.dta", replace 

import excel "$rawdatadir\Others\Características contribuyentes (parte 2).xlsx", sheet("datos2") firstrow clear
rename *, lower
save "$stata_raw\taxpayers_2.dta", replace 

append using "$stata_raw\taxpayers_1.dta"

split fechainicio , p(/)
keep ide codgiro fechainicio3 codnatjuridica coddeptofiscal
rename fechainicio3 year_birth

save "$stata_raw\taxpayers_characteristics.dta", replace 

erase "$stata_raw\taxpayers_1.dta"
erase "$stata_raw\taxpayers_2.dta"

*-------------------------------------------------------------------------------
*4 N Branches
*-------------------------------------------------------------------------------
import excel "$rawdatadir\Others\Sucursales.xlsx", sheet("sucursales") firstrow clear
rename *, lower
rename cantidadsucursales n_branches
save "$stata_raw\branches.dta", replace 

*-------------------------------------------------------------------------------
*5 UNIDADES INDEXADAS
*-------------------------------------------------------------------------------
import excel "$rawdatadir\Others\Unidad Indexada.xls", sheet("UI") firstrow clear
destring B, force gen(UI)
keep UnidadIndexada UI B
drop if UI==.
drop B
split UnidadIndexada, p(/) gen(date)
rename date1  month
rename date2 day
rename date3 year
drop UnidadIndexada
destring month year day, replace
save "$stata_raw\unidades_indexadas_daily.dta", replace 

*-------------------------------------------------------------------------------
*TAX REVENUE
*-------------------------------------------------------------------------------
import delimited "$rawdatadir\Others\M Recaudacion por impuesto - series mensuales_n.csv", clear 
keep if year>=2010
destring vat, ignore(",") gen(vat_revenue)
encode month, gen(m)
drop month 

recode m (4=1) (5=2) (8=3) (1=4) (9=5) (7=6) (6=7) (2=8) (12=9) (11=10) (10=11) (3=12), gen(month)
/*
          m |      Freq.     Percent        Cum.
------------+-----------------------------------
     1. abr |          6        8.33        8.33
     2. ago |          6        8.33       16.67
     3. dic |          6        8.33       25.00
     4. ene |          6        8.33       33.33
     5. feb |          6        8.33       41.67
     6. jul |          6        8.33       50.00
     7. jun |          6        8.33       58.33
     8. mar |          6        8.33       66.67
     9. may |          6        8.33       75.00
    10. nov |          6        8.33       83.33
    11. oct |          6        8.33       91.67
    12. sep |          6        8.33      100.00
------------+-----------------------------------
      Total |         72      100.00
*/
format vat_revenue  %12.0g
keep year month vat_revenue
save "$stata_raw\tax_revenue.dta", replace 
*-------------------------------------------------------------------------------
* POS Subsidy
*-------------------------------------------------------------------------------

import excel "$rawdatadir\Others\BM_Subsidio POS.xlsx", sheet("BM_Subsidio POS") cellrange(A2:BL15855) firstrow clear
local a=1 
foreach var in B C D E F G H I J K L M N O P Q R S T U V W X Y Z AA AB AC AD AE AF AG AH AI AJ AK AL AM AN AO AP AQ AR AS AT AU AV AW AX AY AZ BA BB BC BD BE BF BG BH BI BJ BK BL {
	rename `var' pos_`a'
	local a=`a'+1
}

duplicates drop IDE, force
reshape long pos_, i(IDE) j(n)

recode n (1/4=2012) (5/16=2013) (17/28=2014) (29/40=2015) (41/52=2016) (53/64=2017), gen(year)


gen month=. 
replace month=n-4 if year==2013 
replace month=n-16 if year==2014 
replace month=n-28 if year==2015 
replace month=n-40 if year==2016
replace month=n-52 if year==2017 
replace month=n+8 if year==2012

drop n 

rename IDE ide 

save "$stata_raw\BM_Subsidy.dta", replace 
