*-------------------------------------------------------------------------------
*2 Month - Firm
*-------------------------------------------------------------------------------

foreach year in 2007 2008 2009 2010 2011 2012 2013 2014 2015 20161  {
 use "$stata_raw\card_data_ext_`year'.dta", clear
 
 if `year'==2007 {
 destring tipo_tran, replace force
 }

 
 if `year'==20161 {
 replace year=2016
 } 
 
 gen cantidad_oper=1
 gen oper19210=tipo_tran==9
 gen tot_venta19210=tot_venta if tipo_tran==9
 gen tot_credito19210=tot_credito if tipo_tran==9
 collapse (sum) cantidad_oper oper19210 tot_venta tot_venta19210 tot_credito tot_credito19210, by(id_afi year month)
 rename id_afi id

 save "$datadir\card_month_firm_`year'.dta", replace 

 }

 use "$datadir\card_month_firm_2007.dta", clear 
 foreach year in 2008 2009 2010 2011 2012 2013 2014 2015 20161  {
 append using "$datadir\card_month_firm_`year'.dta", force 
 }

 gen periodo=year*100+month
 drop year month
 save "$datadir\card_month_firm.dta", replace 
 
 foreach year in 2007 2008 2009 2010 2011 2012 2013 2014 2015 20161  {
 erase "$datadir\card_month_firm_`year'.dta" 
 }
 
*-------------------------------------------------------------------------------
*2 Day - Firm - POS Level 
*-------------------------------------------------------------------------------
foreach y in 2009 2010 2011 2012 2013 2014 2015 2016 {
use "$stata_raw\card_data_ext_`y'.dta", clear

*count transactions
gen count=1 

gen tot_venta_m1=tot_venta if moneda==1
gen count_m1=count if moneda==1

*collapse at the firm-month-day-pos level
collapse (sum) tot_venta count tot_venta_m1 count_m1, by(month day year id_afi nro_pos)

save "${datadir}/daily_firm_pos_`y'.dta", replace
}

*-------------------------------------------------------------------------------
*3 Weekly Data 
*-------------------------------------------------------------------------------
*appending firm day data of all years
use "${datadir}/daily_firm_pos_2011.dta", replace

foreach y in 2012 2013 2014 2015 2016 {
append using "${datadir}/daily_firm_pos_`y'.dta"
}

*setting up week with respect to introduction of rebates
gen edate=mdy(month, day, year)
gen reform_day=edate if year==2014 & month==8 & day==1
gen one=1
egen reform_dayt=mean(reform_day), by(one)
drop reform_day
gen day_dist=edate-reform_dayt
replace day_dist=day_dist/7
gen week=floor(day_dist)

*collapse at the week-firm-pos level
collapse (sum) tot_venta count (mean) month year, by(week id_afi nro_pos)

*count of unique pos
gen count_pos_total=1

*collapse at the week-firm-level
collapse (sum) tot_venta count count_pos_total (mean) month year, by(week id_afi)

*count of unique firms
gen count_firms_total=1

*collapse at the week level
collapse (sum) tot_venta count count_pos_total count_firms_total (mean) month year, by(week)

gen week_since_reform=week


* weeks over the span of two different months, take the value of the first month
replace month=floor(month)
replace year=floor(year)
*fixing month 
replace month=8 if week==-31
replace month=10 if week==21 

*rename and transform into millions
rename count count_trans  
rename tot_venta tot_sales

replace count_trans=count_trans/1000000
replace tot_sales=tot_sales/1000000 

*log of outcomes
foreach y in tot_sales count_trans count_pos_total count_firms_total {
	gen log_`y'=ln(`y')
}

*dropping everything after june 2016
drop if (year==2016 & month>6)

save "$datadir\card_transaction_weekly_rd.dta", replace

*-------------------------------------------------------------------------------
*4 Monthly DATA 
*-------------------------------------------------------------------------------
*appending firm day data of all years
use "${datadir}/daily_firm_pos_2011.dta", replace

foreach y in 2012 2013 2014 2015 2016 {
append using "${datadir}/daily_firm_pos_`y'.dta"
}

*collapse at the firm-month-pos level
collapse (sum) tot_venta count, by(month year id_afi nro_pos)

*count unique pos
gen count_pos=1

*collapse at the firm-month level
collapse (sum) tot_venta count count_pos, by(month year id_afi)

*count of firms 
gen count_firms=1 

*collpase at the month level
collapse (sum) tot_venta count count_pos count_firms, by(month year)

*rename and transform into millions
rename count countn  
rename tot_venta tot_sales

replace countn=countn/1000000
replace tot_sales=tot_sales/1000000 


*log of outcomes
foreach var in count_firms count_pos countn tot_sales {
gen log_`var'=ln(`var')
}

*dropping everything after june 2016
drop if (year==2016 & month>=6)

save "$datadir\card_transaction_monthly_rd.dta", replace

*-------------------------------------------------------------------------------
*5 WEEK FIRM DATA
*-------------------------------------------------------------------------------

*appending firm day data of all years
use "${datadir}/daily_firm_pos_2011.dta", replace

foreach y in 2012 2013 2014 2015 {
append using "${datadir}/daily_firm_pos_`y'.dta"
}

drop if count_m1==0 

*collapse at the week-firm-pos level
collapse (sum) tot_venta_m1 count_m1, by(year month day id_afi)


*setting up week with respect to introduction of rebates
gen edate=mdy(month, day, year)
gen reform_day=edate if year==2014 & month==8 & day==1
gen one=1
egen reform_dayt=mean(reform_day), by(one)
drop reform_day
gen day_dist=edate-reform_dayt
replace day_dist=day_dist/7
gen week=floor(day_dist)

*collapse at the week-firm-pos level
collapse (sum) tot_venta_m1 count_m1 (min) month year, by(week id_afi)
drop if id_afi==0
*rename and transform into thousands
rename count_m1 count_trans  
rename tot_venta_m1 tot_sales


*log of outcomes
foreach var in count_trans tot_sales {
gen log_`var'=ln(`var')
}



save "$datadir\card_transaction_weekly_firm_rd.dta", replace

*-------------------------------------------------------------------------------
*5 DAILY
*-------------------------------------------------------------------------------
*appending firm day data of all years
use "${datadir}/daily_firm_pos_2011.dta", replace

foreach y in 2012 2013 2014 2015 2016 {
append using "${datadir}/daily_firm_pos_`y'.dta"
}

*count unique pos
gen count_pos=1 


*collapse at the week-firm-pos level
collapse (sum) tot_venta count count_pos, by(day month year id_afi)


*count of firms 
gen count_firms=1 


*collpase at the month level
collapse (sum) tot_venta count count_pos count_firms, by(month year day)

sort year month day 
gen n=_n
sum n if year==2014 & month==8 & day==1
local reform=r(mean)
gen distt=n-`reform'

gen dow=dow(mdy(month, day, year))
recode dow (5=1) (6=2) (0=3) (1=4) (2=5) (3=6) (4=7), gen(dayweek) //chaging week start day to friday

*rename and transform into millions
rename count count_trans  
rename tot_venta tot_sales

replace count_trans=count_trans/1000000
replace tot_sales=tot_sales/1000000 

*log of outcomes
foreach y in tot_sales count_trans count_pos count_firms {
	gen log_`y'=ln(`y')
}

*dropping everything after june 2016
drop if (year==2016 & month>6)

save "$datadir\card_transaction_daily_rd.dta", replace

*-------------------------------------------------------------------------------
*5 BIWEEK DATA
*-------------------------------------------------------------------------------

use "$datadir\card_transaction_daily_rd.dta", clear

recode day (1/15=1) (16/31=2), gen(biweek)

collapse (sum) tot_sales count_trans (max) count_pos count_firms , by(biweek month year)

sort year month biweek 
gen n=_n
sum n if year==2014 & month==8 & biweek==1
local reform=r(mean)
gen distt=n-`reform'

*log of outcomes
foreach y in tot_sales count_trans count_pos count_firms  {
	gen log_`y'=ln(`y')
}

*dropping everything after june 2016
drop if (year==2016 & month>6)

save "$datadir\card_transaction_biweekly_rd.dta", replace
