*************************************************
	/*SIZE OF THE FIRST STAGE BY SUBSECTOR*/
*************************************************

	use "${datadir}/subsector_rd_trend_1.dta", clear

	*ascending order for volume of transactions 
	gsort - b_tot_venta_p1_
	gen order_sales=_n

	*confidence interval for volume of transactions 
	gen upper=b_tot_venta_p1_+(se_tot_venta_p1_*1.96)
	gen lower=b_tot_venta_p1_-(se_tot_venta_p1_*1.96)

	**total sales 	
	twoway (bar b_tot_venta_p1_ order_sales, fcolor(orange%60) lcolor(orange)) ///
	(rcap upper lower order_sales, lcolor(orange)), ///
	ytitle(Size of First Stage) xtitle(4 Digit Sectors) xline(26) legend(off) scale(1.2) ///
	graphregion(fcolor(white) ifcolor(white)) plotregion(fcolor(white) ifcolor(white))  ///
	xlabel(1 "Harware" 2 "Drugstores"  3 "Groceries" 4 "Bookstores" 5 "Other-Non Specialized" ///
	6 "Other-Specialized" 7 "Food Specialized" 8 "Gas Stations" ///
	9 "Other Retail" 10 "ICT Stores" 11 "Sport Stores" 12 "Appliances and Furniture" 13 "Clothing" ///
	, labsize(vsmall) angle(forty_five)) ylabel(-.15(.15).3)
	graph export "bar_size_rd_sector_sales.pdf", replace


	*ascending order for number of transaction 
	gsort - b_count_p1_
	gen order_count=_n

	drop upper lower 
	*confidence interval for volume of transactions 
	gen upper=b_count_p1_+(se_count_p1_*1.96)
	gen lower=b_count_p1_-(se_count_p1_*1.96)

	*number of card transactions
	twoway (bar b_count_p1_ order_count, fcolor(orange%60) lcolor(orange)) ///
	(rcap upper lower order_count, lcolor(orange)), ///
	ytitle(Size of First Stage) xtitle(4 Digit Sectors) xline(26) legend(off) scale(1.2) ///
	graphregion(fcolor(white) ifcolor(white)) plotregion(fcolor(white) ifcolor(white))  ///
	xlabel(1 "Harware" 2 "Drugstores"  3 "Groceries" 4 "Bookstores" 5 "Other-Non Specialized" ///
	6 "Appliances and Furniture" 7 "Gas Stations" 8 "ICT Stores" ///
	9 "Other-Specialized" 10 "Food Specialized"  11 "Other Retail" 12 "Sport Stores" 13 "Clothing" ///
	, labsize(vsmall) angle(forty_five)) ylabel(-.2(.1).4)
	graph export "bar_size_rd_sector_number.pdf", replace

*************************************************
	/*SIZE OF THE FIRST STAGE BY REGION*/
*************************************************		

	use "${datadir}/state_rd_trend.dta", clear
	*ascending order for volume of transactions 
	gsort - b_tot_venta_p1_
	gen order_sales=_n

	*confidence interval for volume of transactions 
	gen upper=b_tot_venta_p1_+(se_tot_venta_p1_*1.96)
	gen lower=b_tot_venta_p1_-(se_tot_venta_p1_*1.96)


	*total sales 
	twoway (bar b_tot_venta_p1_ order_sales, fcolor(orange%60) lcolor(orange)) ///
	(rcap upper lower order_sales, lcolor(orange)), ///
	ytitle(Size of First Stage) xtitle(4 Digit Sectors) xline(26) legend(off) scale(1.2) ///
	graphregion(fcolor(white) ifcolor(white)) plotregion(fcolor(white) ifcolor(white))  ///
	xlabel(1 "Maldonado" 2 "Rocha" 3 "Canelones" 4 "Montevideo" 5 "San Jose" 6 "Florida" 7 "Durazno" 8 "Lavalleja" ///
	9 "Treinta y Tres" 10 "Flores" 11 "Tacuarembo" 12 "Rio Negro" 13 "Cerro Negro" ///
	14 "Colonia" 15 "Paysandu" 16 "Artigas" 17 "Soriano" 18 "Salto" 19 "Rivera", ///
	labsize(vsmall) angle(forty_five)) ylabel(-.2(.2).6)
	graph export "bar_size_rd_region_sales.pdf", replace


	*ascending order for number of transaction 
	gsort - b_count_p1_
	gen order_count=_n

	drop upper lower 
	*confidence interval for volume of transactions 
	gen upper=b_count_p1_+(se_count_p1_*1.96)
	gen lower=b_count_p1_-(se_count_p1_*1.96)


	*number of transactions
	twoway (bar b_count_p1_ order_count, fcolor(orange%60) lcolor(orange)) ///
	(rcap upper lower order_count, lcolor(orange)), ///
	ytitle(Size of First Stage) xtitle(4 Digit Sectors) xline(26) legend(off) scale(1.2) ///
	graphregion(fcolor(white) ifcolor(white)) plotregion(fcolor(white) ifcolor(white))  ///
	xlabel(1 "Rocha" 2 "Maldonado"  3 "Canelones" 4 "Montevideo" 5 "Colonia" 6 "Soriano"  ///
	7 "Durazno" 8 "San Jose" 9 "Flores" 10 "Florida" 11 "Tacuarembo" 12 "Treinta y Tres" ///
	13 "Lavalleja" 14 "Artigas" 15 "Cerro Negro" 16 "Rio Negro" 17 "Paysandu" ///
	18 "Rivera" 19 "Salto", labsize(vsmall) angle(forty_five)) ylabel(-.2(.2).6)
	graph export "bar_size_rd_region_number.pdf", replace








