use "${datadir}/vat_returns_month_long.dta", clear

		bysort ide: egen sector = max(codgiro)
		gen retail = 0
		replace retail = 1 if floor(codgiro/1000) == 47
		gen wholesale = 0
		replace wholesale = 1 if floor(codgiro/1000) == 46
		
		keep if retail==1 | wholesale==1
		
		egen total_sales=rowtotal(rlinea_14 rlinea_214)
		
		collapse (max) hascard codgiro retail cede nocede_sales=total_sales (sum) cede_sales=total_sales, by(ide year)
		keep if year==2013
		
		gen total_sales=cede_sales if cede==1
		replace total_sales=nocede_sales if cede==0
		
		drop cede
		
		tostring codgiro, replace
		gen sector=substr(codgiro, 3, 2)
		destring sector, replace
		
		replace sector=100 if retail==1 & (sector==22 | sector==23 | sector==51 | sector==53 ///
		| sector==62 | sector==63 | sector==64 | sector==74 | sector==81 | sector==82 | sector==89 | sector==91 | sector==99)
		replace sector=100 if retail==0 & (sector==10 | sector==31 | sector==51 | sector==52 | sector==61 | sector==62 | sector==90)
		
		collapse (mean) pos_adop_sector=hascard (count) count=hascard (p50) total_sales, by(sector retail)
		
		gsort - retail - pos_adop_sector
		
		gen order=_n
	
		gen order2=_n 
		replace order2=order2-1
		replace order=order+order2
		
		replace order=order+1 if retail==0

		
		twoway (bar pos_adop_sector order if order<=25, fcolor(orange%60) lcolor(orange)) ///
		(bar pos_adop_sector order if order>=27, fcolor(navy%60) lcolor(navy)), ///
		ytitle(Share of Firms with  a POS) xtitle(4 Digit Sectors) xline(26) ///
		legend(order(1 "Retail Sector" 2 "Wholesale Sector")) scale(1.2) ///
		graphregion(fcolor(white) ifcolor(white)) plotregion(fcolor(white) ifcolor(white)) ///
		xlabel(		1 "Gas Stations" 3 "Clothing" 5 "Drug Stores" 7 "Appliances and Furniture" 9 "Hardware" 11 "Audio and Video" ///
		13 "Bookstores" ///
		15"Groceries" 17 "ICT" 19 "Other-Specialized" 21 "Other Retail" 23 "Other-Non Specialized" ///
		25 "Food-Specialized" 26 " " 28 "Clothing" ///
		30 "Construction and Hardware" 32 "Domestic Items" 34 "Other Wholesale" 36 "Other Machinery" 38 "Agro Machinery" 40 "Trash" ///
		42 "Agro Supplies" 44 "Food and Beverages"  ///
		, labsize(vsmall) angle(forty_five)) ///
		text(.9 7 "Retail Sector", place(e)) ///
		text(.9 28 "Wholesale Sector", place(e)) 
		graph export subsector_posshare.pdf, replace
		
		gsort - retail - count
		drop order order2 
		
		gen order=_n
		gen order2=_n 
		replace order2=order2-1
		replace order=order+order2
		
		replace order=order+1 if retail==0
		
				twoway (bar count order if order<=25, fcolor(orange%60) lcolor(orange)) ///
				(bar count order if order>=27, fcolor(navy%60) lcolor(navy)), ///
				ytitle(Number of Firms) xtitle(4 Digit Sectors) xline(26) ///
				legend(order(1 "Retail Sector" 2 "Wholesale Sector")) ///
				scale(1.2) graphregion(fcolor(white) ifcolor(white)) plotregion(fcolor(white) ifcolor(white)) ///
		xlabel(1 "Groceries" 3 "Food-Specialized" 5 "Hardware" 7 "Drug Stores" 9 "Clothing" 11 "Other-Specialized" ///
		13 "Appliances and Furniture" ///
		15 "Other-Non Specialized"  17 "Other Retail" 19 "ICT" 21 "Gas Stations" 23 "Bookstores" 25 "Audio and Video" 26 " " ///
		28 "Food and Beverages" 30 "Other Wholesale" 32 "Domestic Items" 34 "Trash" 36 "Clothing" 38 "Construction and Hardware" ///
		40 "Agro Supplies" 42 "Other Machinery" 44 "Agro Machinery"  ///
		, labsize(vsmall) angle(forty_five)) ///
		ylabel(, labsize(small)) ///
		text(2400 7 "Retail Sector", place(e)) ///
		text(2400 28 "Wholesale Sector", place(e)) 
		graph export subsector_firmcount.pdf, replace



use "${datadir}/vat_returns_month_long.dta", clear

		bysort ide: egen sector = max(codgiro)
		gen retail = 0
		replace retail = 1 if floor(codgiro/1000) == 47
		gen wholesale = 0
		replace wholesale = 1 if floor(codgiro/1000) == 46
		
		keep if retail==1
		
egen maxcard=max(hascard), by(ide year)

duplicates drop ide year, force
keep if year==2013


collapse (mean) maxcard (count) count=maxcard (sum) count_card=maxcard, by(coddeptofiscal)
gen one=1

recode coddeptofiscal (1=1 "Artigas") (2=2 "Canelones") (3=3 "Cerro Largo") (4=4 "Colonia") (5=5 "Durazno") (6=6 "Flores") (7=7 "Florida") (8=8 "Lavalleja") (9=9 "Maldonado") (10=10 "Montevideo") (11=11 "Paysandu") (12=12 "Rio Negro") (13=13 "Rivera") (14=14 "Rocha")  (15=15 "Salto") (16=16 "San Jose") (17=17 "Soriano") (18=18 "Tacuarembo") (19=19 "Treinta y Tres"), gen(state)


graph bar (mean) count, over(state, sort(count) descending label(angle(forty_five) labsize(medsmall))) bar(1, fcolor(navy%80) lcolor(navy)) ytitle(Number of Firms) graphregion(fcolor(white))
graph export "n_firms_departamento.pdf", replace 
