/*-------------------------------------------------------------------------------
	 1. Heterogeneity by region and sector POS adoption in 2013 
*-------------------------------------------------------------------------------*/
foreach var in nout {
foreach bal in ab   {
foreach y in 10 {
foreach est in log_modif {
foreach w in 99 {
foreach f in 11 {
foreach as in 1   {
foreach eps in 10 {
foreach het in $het_by  { 
foreach tr in treat1 treat2 treat3 treat4 treat5  {
foreach est_m in 1 2  {
foreach random in $random_s {
foreach run in $run_time {

use "${datadir}/data_`bal'_`y'.dta", clear

/*-------------------------------------------------------------------------------
				0. Control and treatment group selection
*-------------------------------------------------------------------------------*/

	*Generate post reform
		gen distt=year-2014
		gen post=(distt>=0) 

	*POS pre reform
		egen card_pre_aux=max(hascard), by(post ide)
		replace card_pre_aux=. if post==1
		egen card_pre=mean(card_pre_aux), by(ide)
		
	* POS EVER
		egen card_ever=max(hascard), by(ide)
		
	*sample 
	keep if retail==1	
	keep if card_pre==1
	
	*merging relevant variables for assigment 
	gen sector4=floor(codgiro/10)
		
	if `het'==3 {
		merge m:1 coddeptofiscal using "${datadir}/region_rd_assig.dta"
		keep if _merge==3 & coddeptofiscal!=9 & coddeptofiscal!=14
		drop if `tr'==.
		drop _merge
	}
	
	if `het'==4 {
		merge m:1 sector4 using "${datadir}/subsector_rd_assig_1.dta"
		keep if _merge==3
		drop if `tr'==.
		drop _merge

	}



/*-------------------------------------------------------------------------------
				2. Subsample for SDID 
*-------------------------------------------------------------------------------*/
if `est_m'==2 {

		set seed 1234
		** selecting 50% random sample 
		local tt10 2010
		gen random=runiform() if year==`tt`y''
		
		local r50 0.5
		local r100 1
		
		egen random_t=mean(random), by(ide)
		keep if random_t<=`r`random''

		}
		
count 

/*-------------------------------------------------------------------------------
				2. Relevant Variables
*-------------------------------------------------------------------------------*/

rename total_tsales s_ta
rename rtaxsale out 
rename rtaxpur input 
rename rnetliab liab
rename total_sales stot
rename aoutput nout
rename aliability nliab

	
*recode of year of birth
destring year_birth, replace
		replace year_birth=1950 if year_birth<=1950
		
		recode  year_birth (1950=1950) (1951/1955=1951) (1956/1960=1956) (1961/1965=1961) ///
		(1966/1970=1966) (1971/1975=1971) (1976/1980=1976), gen(year_inc)
		
		recode  year_birth (1950=1950) (1951/1955=1951) (1956/1960=1956) (1961/1965=1961) ///
		(1966/1970=1966) (1971/1975=1971) (1976/1980=1976) (1981/1985=1981) (1986/1990=1986) ///
		(1991/1995=1991) (1996/2000=1996) (2001/2005=2001) (2006/2009=2006) ///
		(2010/2015=2010), gen(year_inc_r)
		
		recode  year_birth (1950=1950) (1951/1955=1951) (1956/1960=1956) (1961/1965=1961) ///
		(1966/1970=1966) (1971/1975=1971) (1976/1980=1976) (1981/1983=1981) (1984/1986=1984) ///
		(1987/1989=1987) (1990/1992=1990) (1991/1993=1991) (1994/1996=1994) ///
		(1997/1999=1997) (2000/2002=2000) (2003/2005=2003) (2006/2008=2006) ///
		(2009/2011=2009), gen(year_inc_3)


		*for extensive and ppml keeps individual zeros
		foreach s in `bal' {
		gen ez_log_modif_`var'_`s'=1
		}
		
		keep if ez_`est'_`var'_`bal'==1
	
		display "`bal' `est'"
		tab year `tr' /*just making sure that is still balanced (unless the unbalanced panel)*/

		local w_95 95 
		local w_99 99
		local w_100 99.9
		
		*Winsorizing level value * if w=o no winsorizing
		

		winsor2 `var', suffix(_`w') cuts(0 `w') by(year `tr') 
	
		
		gen l_`var'_m=`var'_`w'==.
		egen ever_log_modif_`var'_m=max(l_`var'_m), by(ide)
		
		*Log(x+epsilon) with modification as in Chen & Roth 2023
		gen aux2=`var'_`w'
		replace aux2=. if `var'_`w'==0
		egen minvar=min(aux2)
		sum minvar
		gen log_modif_`var'=log(`var'_`w'/(minvar))
		replace log_modif_`var'=-(`eps'/100) if `var'_`w'==0
				
		
		drop if ever_`est'_`var'_m==1
		
					
	if `est_m'==1 { 
		* Interaction 
		gen did_rvsw=`tr'*post
	
		egen tag=tag(ide)
				
		tab distt, gen(pe)
		
		local t10 6

		forvalues  i = 1(1)`t`y'' {
		gen did_`i'=`tr'*pe`i'
		}
						
		* Scaling outcome variables by pre-reform mean
		bys  post `tr': egen aux_sc_`est'_`var'=mean(`est'_`var')
		replace aux_sc_`est'_`var'=. if post==1
		bys `tr': egen scale_`est'_`var'=min(aux_sc_`est'_`var')
		gen s_`est'_`var'=`est'_`var'/scale_`est'_`var'	

/*-------------------------------------------------------------------------------
				3. Regressions
*-------------------------------------------------------------------------------*/
		
		local slog_modif reghdfe

		local dlog_modif=1
		local c_log_modif="OLS DiD Log(x)"
		
		gen all_sample=1
	
		*No FE
		local fe_1  

		* Year Birth
		local fe_11  i.year_birth#i.year 

		`s`est'' `est'_`var' did_rvsw `w_`p'', absorb(i.ide i.distt `fe_`f'' ) cluster(i.ide)
		
		foreach x in se b {
		local coef_`x'=string(_`x'[did_rvsw], "%15.3fc")
		}
		
		** Sample size for graph (unique taxpayers)
		count if `tr'==1 & tag==1 & e(sample)==1
		local n_treat=r(N)
		count if `tr'==0 & tag==1 & e(sample)==1
		local n_control=r(N)
		
		sum `est'_`var' if post==0 & `tr'==0 & e(sample)==1
		local c_pre=string(r(mean), "%15.2fc")
		sum `est'_`var' if post==1 & `tr'==0 & e(sample)==1
		local c_post=string(r(mean), "%15.2fc")
		sum `est'_`var' if post==0 & `tr'==1 & e(sample)==1
		local t_pre=string(r(mean), "%15.2fc")
		sum `est'_`var' if post==1 & `tr'==1 & e(sample)==1
		local t_post=string(r(mean), "%15.2fc")
		
		local d_10 did_1 did_2 did_3 did_5 did_6
		
		* Treatment Effect by period
		`s`est'' `est'_`var' `d_`y'', abs(i.ide i.distt `fe_`f'') cluster(i.ide)
		local t10 1 2 3 5 6
			foreach x in se b {
			foreach m in `t`y'' {
		gen m`x'_`var'_`m'=_`x'[did_`m']
			}
			}
			
			
		keep distt mse_`var'_*  mb_`var'_* 



		foreach m in `t`y'' {
		gen upper_`var'_`m'=mb_`var'_`m'+(mse_`var'_`m'*1.960)
		gen lower_`var'_`m'=mb_`var'_`m'-(mse_`var'_`m'*1.960)
		}

		keep distt mb_`var'_* upper_* lower_*
		keep if distt==0
		duplicates drop distt, force

		local t10 4 

		gen mb_`var'_`t`y''=0
		gen upper_`var'_`t`y''=.
		gen lower_`var'_`t`y''=.
		reshape long mb_`var'_ upper_`var'_ lower_`var'_, i(distt) j(period)

		local t10 5 
		replace period=period-`t`y''

		gen value=0

		local l_nz="ylabel(, labsize(medium))"
		local l_logx="ylabel(-0.1(0.05)0.1, labsize(medium))"
		local l_log_modif="ylabel(-0.5(0.1)0.5, labsize(medium))"
		
		local l_10="xlabel(-4(1)1, labsize(medium))"


		local n1 region 
		local n2 sector
		local n3 region_rd
		local n4 sector_rd
		
		local c_log_modif DiD
		
		graph twoway (rcap upper_`var'_ lower_`var'_ period, fcolor(blue) lwidth(0.3) lcolor(blue)) ///
		(scatter mb_`var'_ period, mcolor(blue) msize(small) lcolor(blue)) ///
		(line value  period, lcolor(red) lwidth(medthin)), ///
		graphregion(fcolor(white)) legend(off) `l_`est'' `l_`y''  xline(-0.5, lwidth(medium) lcolor(black)) yline(0, lwidth(medthin) lcolor(red))  ytitle(Point Estimate, size(medium))  ///
	  xtitle(Years to Reform) scale(1.2) ///
	  note("DiD: `coef_b' (`coef_se') . N Treated:`n_treat', N Control=`n_control'" "Treated: Mean Pre-Reform (`t_pre'), Mean Post-Reform (`t_post')" "Control: Mean Pre-Reform (`c_pre'), Mean Post-Reform (`c_post')")
		graph export did_es_`var'_`bal'_`y'_`f'_`est'_`w'_as`as'_esp`eps'_`n`het''_`tr'.pdf, replace
}


	
/*-------------------------------------------------------------------------------
				5. Synthetic DID
*-------------------------------------------------------------------------------*/

	if `est_m'==2 {
		
	* Variables for SDID
		* Post 
		gen did_treat=`tr'*post
		egen group=group(ide)
		egen tag=tag(ide)
		
local n1_10 4
local n2_10 6
		
sdid `est'_`var' group year did_treat, vce(bootstrap) reps($replication) graph  g2_opt(ylab(-4(1)1) ytitle("Output") scheme(sj)) graph_export(output,.pdf) 
local  coef=string(e(ATT), "%15.3fc")
local 	se=string(e(se), "%15.3fc")

count if tag==1 & `tr'*post==1
local count_t=string(r(N), "%15.0fc")
count if tag==1 & `tr'*post==0
local count_c=string(r(N), "%15.0fc")

matrix lambda = e(lambda)[1..`n1_`y'',1] //save lambda weight
matrix yco = e(series)[1..`n1_`y'',2] //control baseline
matrix ytr = e(series)[1..`n1_`y'',3] //treated baseline
matrix aux = lambda'*(ytr - yco) //calculate the pre-treatment mean
scalar meanpre_o = aux[1,1]
matrix difference = e(difference)[1..`n2_`y'',1..2] // Store Ytr-Yco
svmat difference
ren (difference1 difference2) (time d)
replace d = d - meanpre_o // Calculate vector in (8)

local b=1
local B =`run'

while `b'<=`B' {
preserve
bsample, cluster(group) idcluster(c2)
qui count if did_treat==0
local rt1=r(N)
qui count if did_treat!=0
local rt2=r(N)
if (`rt1'!=0 & `rt2'!=0) { 
sdid `est'_`var' c2 year did_treat, vce(noinference) graph 
matrix lambda_b = e(lambda)[1..`n1_`y'',1] //save lambda weight
matrix yco_b = e(series)[1..`n1_`y'',2] //control baseline
matrix ytr_b = e(series)[1..`n1_`y'',3] //treated baseline
matrix aux_b = lambda_b'*(ytr_b - yco_b) //calculate the pre-treatment mean
matrix meanpre_b = J(`n2_`y'',1,aux_b[1,1])

matrix d`b' = e(difference)[1..`n2_`y'',2] - meanpre_b

local ++b
} 
restore 
}



keep time d
keep if time!=.
replace time=time-2014

forval b=1/`B' { 
    svmat d`b' //import each bootstrap replicate of difference between trends
}

egen rsd = rowsd(d11 - d`B'1) //calculate standard deviation of this difference
gen LCI = d + invnormal(0.025)*rsd //lower bounds on bootstrap CIs
gen UCI = d + invnormal(0.975)*rsd //upper bounds on bootstrap CIs

gen value=0

	*	local n1 region 
	*	local n2 sector
	*	local n3 region_rd
	*	local n4 sector_rd

graph twoway (rcap UCI LCI time, fcolor(blue) lcolor(blue)) ///
(scatter d time, mcolor(blue) msize(small) lcolor(blue)) ///
(line value time, lcolor(red) lwidth(medthin)), ///
ylabel(-0.5(0.1)0.5, labsize(medium)) ///
graphregion(fcolor(white)) legend(off) xtitle("Years to Reform") ytitle("Point Estimate") xlab(-4(1)1) ///
xline(-0.5, lwidth(medium) lcolor(black)) yline(0, lwidth(medthin) lcolor(red)) scale(1.2) ///
note("ATT: `coef' (`se')" "N Treated `count_t' N Control `count_c'") 

graph export "event_sdid_`est'_`var'_`y'_`bal'_r`random'_`w'_`r'_`eps'_`as'_`het'_`tr'.pdf", replace

	
	
}

}
}
}
}
}
}
}
}
}
}
}
}
}


