/**********************************************
List of firms in retail and wholesale subsectors
***********************************************/
use "${datadir}/vat_returns_month_long.dta", clear

drop if period==. 

bysort ide: egen sector = max(codgiro)
gen retail = 0
replace retail = 1 if floor(codgiro/1000) == 47
gen wholesale = 0
replace wholesale = 1 if floor(codgiro/1000) == 46

keep if retail==1 | wholesale==1

duplicates drop ide year, force

keep if year==2013

gen sector4=floor(codgiro/10)
rename ide id_afi

preserve 
collapse (mean) retail (count) year, by(sector4)
sort sector4 
gen subsector=_n 
save "${datadir}/subset.dta", replace
restore

merge m:1 sector4 using "${datadir}/subset.dta"
drop _merge
save "${datadir}/firm_retail.dta", replace
erase "${datadir}/subset.dta"

/**********************************************
RDD Analysis by each subsector
***********************************************/
foreach g in 0 1 {
use "${datadir}/daily_firm_pos_2013.dta", clear

foreach y in 2014 2015  {
append using "${datadir}/daily_firm_pos_`y'.dta", force
}

drop if count_m1==0 

*collapse at the week-firm-pos level
collapse (sum) tot_venta_m1 count_m1, by(year month day id_afi)

rename (tot_venta_m1 count_m1) (tot_venta count)
			
merge m:1 id_afi using "${datadir}/firm_retail.dta"
keep if _merge==3
drop _merge	
keep if retail==`g'

if `g'==1 {
replace subsector=subsector-15 
}	

	collapse (sum) tot_venta count, by(month day year subsector sector4)
	
	preserve
	collapse (sum) tot_venta count, by(year subsector sector4)
	drop tot_venta count
	reshape wide subsector, i(sector4) j(year)
	egen subsector=rowmean( subsector2013 subsector2014 subsector2015)
	save "${datadir}/year_sector_subsector_`g'.dta", replace
	restore
	
	drop sector4
	reshape wide tot_venta count, i(month day year) j(subsector)
	sort year month day

	gen edate=mdy(month, day, year)
	gen reform_day=edate if year==2014 & month==8 & day==1
	gen one=1
	egen reform_dayt=mean(reform_day), by(one)
	drop reform_day
	gen day_dist=edate-reform_dayt
	replace day_dist=day_dist/7
	gen week=floor(day_dist)

	*generating week ID
	gen periodo=year*100+month
	tostring periodo, replace

	egen peri=concat(periodo day)
	gen period_day=date(peri, "YMD")

	format period_day %td
			gen period=mofd(period_day)
			format period %tm
			
	gen dow=dow(period_day)

	recode dow (5=1) (6=2) (0=3) (1=4) (2=5) (3=6) (4=7), gen(dayweek) //chaging week start day to friday

	gen week_since_reform=week
	

	
if `g'==1 {
*collapsing by week
collapse (sum) tot_venta1 tot_venta2 tot_venta3 tot_venta4  tot_venta6 tot_venta7 tot_venta8 tot_venta9 tot_venta10 tot_venta11 tot_venta12 tot_venta13 tot_venta14 tot_venta15 tot_venta16 tot_venta17 tot_venta18 tot_venta19  tot_venta20 tot_venta21 tot_venta22 tot_venta23 tot_venta24 tot_venta25 count1 count2 count3 count4 count6 count7 count8 count9 count10 count11 count12 count13 count14 count15 count16 count17 count18 count19 count20 count21 count22 count23 count24 count25 (mean) week_since_reform month year, by(week)
}

if `g'==0 {
*collapsing by week
collapse (sum) tot_venta1 tot_venta2 tot_venta3 tot_venta4 tot_venta5 tot_venta6 tot_venta7 tot_venta8 tot_venta9 tot_venta10 tot_venta11 tot_venta12 tot_venta13 tot_venta14 tot_venta15 count1 count2 count3 count4 count5 count6 count7 count8 count9 count10 count11 count12 count13 count14 count15 (mean) week_since_reform month year, by(week)
}

local n_1  1 2 3 4 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25
local n_0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 
*converting sales and transaction count to millions
foreach i in `n_`g'' {
foreach y in tot_venta count {
	replace `y'`i'=`y'`i'/1000000
	gen log_`y'`i'=ln(`y'`i') 
	
}
}


		*Creating additional variables for running RDs
			gen distt=week_since_reform 
			gen post=(distt>=0)
			gen inter=distt*post 
			replace month=floor(month)
			gen running=(distt-0)

save "${datadir}/weekly_sector_subsector_`g'.dta", replace

********************************************************
* Running RD regression
*******************************************************

use "${datadir}/weekly_sector_subsector_`g'.dta", clear


		* RD Regression with 2 levels of polynomial using the outcome var using rdrobust package to get bias corrected confidence intervals
		 *Run regression and save results
local n_1  1 2 3 4 6 7 8 9 10 11 12 13 15 16 17 18 19 20 21 22 23 24 25
local n_0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 

	 foreach i in `n_`g'' {
		foreach y in tot_venta count {
				foreach poly in 1 2 {
				rdrobust log_`y'`i' running, c(0) p(`poly') h(70) covs(month)
					gen  b_`y'_p`poly'_`i'=e(tau_cl)
					gen se_`y'_p`poly'_`i'=e(se_tau_cl)
					gen  n_`y'_p`poly'_`i'=e(N)
				}
			}
		}
		
	keep if running==1
	keep b_* se_* running
	reshape long b_tot_venta_p1_ se_tot_venta_p1_ b_count_p1_ se_count_p1_  ///
	        b_tot_venta_p2_ se_tot_venta_p2_ b_count_p2_ se_count_p2_ , i(running) j(subsector)

merge 1:1 subsector using "${datadir}/year_sector_subsector_`g'.dta", gen(m) keepusing(sector4 subsector)


	save "${datadir}/rd_subsector_coeff_`g'.dta", replace

/**********************************************
Subsector Characteristics (Size, POS Adoption, Size of the First Stage and Treatment Assigment)
***********************************************/
	*get pos adoption from vat returns for all years for trends 
			use "${datadir}/data_ab_10.dta", clear
			keep if service==0
			
			if `g'==1 { 
			keep if retail==1
			}

			if `g'==0 { 
			keep if wholesale==1
			}
			
			egen maxcard=max(hascard), by(ide year)
			duplicates drop ide year, force

			gen sector4=floor(codgiro/10)


			collapse (mean) maxcard retail (count) nfirms=maxcard (sum) count_card=maxcard, by(sector4 year)
			drop if nfirms<50

			keep if year>=2010

			drop count_card
			rename maxcard pos_adopt
			reshape wide pos_adopt nfirms, i(sector4) j(year)
		 
			merge 1:1 sector4 using "${datadir}/rd_subsector_coeff_`g'.dta", gen(merge_coef)
			keep if merge_coef==3

	
			keep sector4 subsector b_tot_venta_p1 se_tot_venta_p1 b_count_p1 se_count_p1 ///
			b_tot_venta_p2 se_tot_venta_p2 b_count_p2 se_count_p2 ///
			pos_adopt2010 pos_adopt2011 pos_adopt2012 pos_adopt2013 pos_adopt2014 pos_adopt2015 nfirms2013

			save "${datadir}/subsector_rd_trend_`g'.dta", replace
	
	*Different ways of assigning treatment, using polynomial 1 (mostly consistly with results  from poly2)

		sum b_tot_venta_p1, d 
		gen treat2=b_tot_venta_p1>=r(p50)
		gen treat3=b_tot_venta_p1>=r(p75)

		sum b_count_p1, d 
		gen treat4=b_count_p1>=r(p50)
		gen treat5=b_count_p1>=r(p75)
						   						   
		
	save "${datadir}/subsector_rd_assig_`g'.dta", replace
}

*data for triple dif in dif 
	use "${datadir}/subsector_rd_assig_1.dta", replace
	append using "${datadir}/subsector_rd_assig_0.dta"
	keep sector4 b_tot_venta_p1_  b_count_p1_  treat2 treat4 

	
	rename treat2 rd_s_sales
	rename treat4 rd_s_count 
	sum b_tot_venta_p1, d 
	gen rd_s_sales_a=b_tot_venta_p1>=r(p50)
	sum b_count_p1, d 
	gen rd_s_count_a=b_count_p1>=r(p50)

	rename b_tot_venta_p1 b_tot_venta_s
	rename b_count_p1 b_count_s

	keep sector4 rd_s_sales rd_s_count rd_s_sales_a rd_s_count_a b_tot_venta_s  b_count_s
	
	save "${datadir}/rd_coef_retail_wholesale_sub.dta", replace

	

