
/**********************************************
RDD Analysis by each subsector
***********************************************/

use "${datadir}/daily_firm_pos_2013.dta", clear

foreach y in 2014 2015  {
append using "${datadir}/daily_firm_pos_`y'.dta", force
}

drop if count_m1==0 

*collapse at the week-firm-pos level
collapse (sum) tot_venta_m1 count_m1, by(year month day id_afi)

rename (tot_venta_m1 count_m1) (tot_venta count)


merge m:1 id_afi using "${datadir}/firm_retail.dta", keepusing(retail coddeptofiscal)
keep if _merge==3
drop _merge	
keep if retail==1

	collapse (sum) tot_venta count, by(month day year coddeptofiscal)
	
	reshape wide tot_venta count, i(month day year) j(coddeptofiscal)
	sort year month day

	gen edate=mdy(month, day, year)
	gen reform_day=edate if year==2014 & month==8 & day==1
	gen one=1
	egen reform_dayt=mean(reform_day), by(one)
	drop reform_day
	gen day_dist=edate-reform_dayt
	replace day_dist=day_dist/7
	gen week=floor(day_dist)

	*generating week ID
	gen periodo=year*100+month
	tostring periodo, replace

	gen day_t=""

	forvalues i= 1/9 {
	replace  day_t="0`i'" if day==`i'
	}

	forvalues i= 10/31 {
	replace  day_t="`i'" if day==`i'
	}

	egen peri=concat(periodo day_t)
	gen period_day=date(peri, "YMD")

	format period_day %td
			gen period=mofd(period_day)
			format period %tm
			
	gen dow=dow(period_day)

	recode dow (5=1) (6=2) (0=3) (1=4) (2=5) (3=6) (4=7), gen(dayweek) //chaging week start day to friday

	gen week_since_reform=week
	

*collapsing by week
collapse (sum) tot_venta1 tot_venta2 tot_venta3 tot_venta4 tot_venta5 tot_venta6 tot_venta7 tot_venta8 tot_venta9 tot_venta10 tot_venta11 tot_venta12 tot_venta13 tot_venta14 tot_venta15 tot_venta16 tot_venta17 tot_venta18 tot_venta19  count1 count2 count3 count4 count5 count6 count7 count8 count9 count10 count11 count12 count13 count14 count15 count16 count17 count18 count19 (mean) week_since_reform month year, by(week)


*converting sales and transaction count to millions
forvalues i=1(1)19 {
foreach y in tot_venta count {
	replace `y'`i'=`y'`i'/1000000
	gen log_`y'`i'=ln(`y'`i') 
	
}
}

		*Creating additional variables for running RDs
			gen distt=week_since_reform 
			gen post=(distt>=0)
			gen inter=distt*post 
			replace month=floor(month)
			gen running=(distt-0)

save "${datadir}/weekly_geo_state.dta", replace

	
********************************************************
* Running RD regression
*******************************************************


use "${datadir}/weekly_geo_state.dta", clear


		* RD Regression with 2 levels of polynomial using the outcome var using rdrobust package to get bias corrected confidence intervals
		 *Run regression and save results

	 forvalues i=1(1)19 {
		foreach y in tot_venta count {
				foreach poly in 1 2 {
				rdrobust log_`y'`i' running, c(0) p(`poly') h(70) covs(month)
					gen  b_`y'_p`poly'_`i'=e(tau_cl)
					gen se_`y'_p`poly'_`i'=e(se_tau_cl)
					gen  n_`y'_p`poly'_`i'=e(N)
				}
			}
		}
		
	keep if running==1
	keep b_* se_* running
	reshape long b_tot_venta_p1_ se_tot_venta_p1_ b_count_p1_ se_count_p1_  ///
	        b_tot_venta_p2_ se_tot_venta_p2_ b_count_p2_ se_count_p2_ , i(running) j(coddeptofiscal)

	save "${datadir}/rd_state_coeff.dta", replace


	*get pos adoption from vat returns for all years for trends 
			use "${datadir}/data_ab_10.dta", clear
			keep if retail==1
			
			egen maxcard=max(hascard), by(ide year)
			duplicates drop ide year, force

			collapse (mean) maxcard retail (count) nfirms=maxcard (sum) count_card=maxcard, by(coddeptofiscal year)
			drop if nfirms<50

			keep if year>=2010

			drop count_card
			rename maxcard pos_adopt
			reshape wide pos_adopt nfirms, i(coddeptofiscal) j(year)
		 
			merge 1:1 coddeptofiscal using "${datadir}/rd_state_coeff.dta", gen(merge_coef)
			keep if merge_coef==3

			
			keep coddeptofiscal b_tot_venta_p1 se_tot_venta_p1 b_count_p1 se_count_p1 ///
			b_tot_venta_p2 se_tot_venta_p2 b_count_p2 se_count_p2 ///
			pos_adopt2010 pos_adopt2011 pos_adopt2012 pos_adopt2013 pos_adopt2014 pos_adopt2015 nfirms2013

			save "${datadir}/state_rd_trend.dta", replace
/**********************************************
Region Characteristics (Size, POS Adoption, Size of the First Stage and Treatment Assigment)
***********************************************/		
		*Examining consistency of RD estimates across specs
	
		gen definite_jump=(b_tot_venta_p1/se_tot_venta_p1>1.96 & b_tot_venta_p2/se_tot_venta_p2>1.96 & ///
						   b_count_p1/se_count_p1>1.96 & b_count_p2/se_count_p2>1.96)
		egen mean_jump=rowmean(b_tot_venta_p1 b_tot_venta_p2 b_count_p1 b_count_p2)
				 replace definite_jump=. if mean_jump==.						   
		egen mean_volume_jump=rowmean(b_tot_venta_p1 b_tot_venta_p2)
		
	*Different ways of assigning treatment, using polynomial 1 (mostly consistly with results  from poly2)
		
		gen treat1=(definite_jump==1 | mean_jump>.2)

		sum b_tot_venta_p1, d 
		gen treat2=b_tot_venta_p1>=r(p50)
		gen treat3=b_tot_venta_p1>=r(p75)

		sum b_count_p1, d 
		gen treat4=b_count_p1>=r(p50)
		gen treat5=b_count_p1>=r(p75)
						   						   
	save "${datadir}/region_rd_assig.dta", replace

	*data for triple dif in dif 

	use "${datadir}/region_rd_assig.dta", clear
	keep coddeptofiscal treat2 treat4 b_tot_venta_p1 b_count_p1
	rename b_tot_venta b_tot_venta_r
	rename b_count b_count_r
	rename treat2 rd_r_sales
	rename treat4 rd_r_count 

	save "${datadir}/rd_coef_retail_wholesale_reg.dta", replace




