*LOADING WEEKLY DATA 
use "$datadir\card_transaction_weekly_rd.dta", clear


********************************************************
*  MAIN VARIABLES
*******************************************************
*rename count_pos count_pos_c
	gen distt=week_since_reform 
	gen post=(distt>=0)
	gen inter=distt*post 
	
********************************************************
* Running RD regression
*******************************************************
		gen running=(distt-0)
		
		*local for optimal bandwidth
		local o_log_count_trans 17 
		local o_log_tot_sales 15
		
		
		foreach P in 1 2 { 
		foreach y in log_count_trans log_tot_sales {
		foreach nweek in  80 40 `o_`y'' {
		    foreach d in 2 4 8 {
		    preserve
				drop if distt>=-`d' & distt<=`d'
		rdrobust `y' running, c(0) p(`P') h(`nweek') covs(month)
		local mean_`y'`P'_`nweek'_`d'=string(e(tau_cl), "%15.3fc")
		local se_`y'`P'_`nweek'_`d'=string(e(se_tau_cl), "%15.3fc")
		restore
		}
		}
		}
		}
						
		*All Weeks
		foreach P in 1 2 { 
		foreach y in log_count_trans log_tot_sales  {
		foreach nweek in 80 40 `o_`y''  {
		rdrobust `y' running, c(0) p(`P') h(`nweek') covs(month)
		local mean_`y'`P'_`nweek'=string(e(tau_cl), "%15.3fc")
		local se_`y'`P'_`nweek'=string(e(se_tau_cl), "%15.3fc")
		}
		}
		}
		
		

texdoc init "RD_cutweeks_d_short.tex", force replace
tex						\begin{tabular}{lcccc}
tex							\toprule 
tex							\hline
tex  &  (1) & (2) & (3) &(4)  \\
tex \hline
tex  &  All Weeks & Cut 2 Weeks & Cut 4 Weeks & Cut 8 Weeks  \\
tex \hline
tex & \multicolumn{4}{c}{I. Number of Card Transactions} \\
tex \hline 
tex  i. 80 Weeks BW & `mean_log_count_trans1_80'  & `mean_log_count_trans1_80_2' & `mean_log_count_trans1_80_4' & `mean_log_count_trans1_80_8'  \\
tex & (`se_log_count_trans1_80') & (`se_log_count_trans1_80_2') & (`se_log_count_trans1_80_4') & (`se_log_count_trans1_80_8')  \\
tex ii. 40 Weeks BW &  `mean_log_count_trans1_40' & `mean_log_count_trans1_40_2' & `mean_log_count_trans1_40_4' & `mean_log_count_trans1_40_8'  \\
tex &  (`se_log_count_trans1_40')  & (`se_log_count_trans1_40_2') &  (`se_log_count_trans1_40_4') &  (`se_log_count_trans1_40_8')  \\
tex iii. Optimal BW & `mean_log_count_trans1_17' & `mean_log_count_trans1_17_2' & `mean_log_count_trans1_17_4' & `mean_log_count_trans1_17_8'  \\
tex &  (`se_log_count_trans1_17') &  (`se_log_count_trans1_17_2') & (`se_log_count_trans1_17_4') & (`se_log_count_trans1_17_8')  \\
tex \hline
tex & \multicolumn{4}{c}{II. Volume of Card Transactions} \\
tex \hline 
tex i. 80 Weeks BW & `mean_log_tot_sales1_80'  & `mean_log_tot_sales1_80_2' & `mean_log_tot_sales1_80_4' & `mean_log_tot_sales1_80_8'  \\
tex &  (`se_log_tot_sales1_80')  & (`se_log_tot_sales1_80_2') & (`se_log_tot_sales1_80_4') & (`se_log_tot_sales1_80_8')  \\
tex ii. 40 Weeks BW &  `mean_log_tot_sales1_40'  & `mean_log_tot_sales1_40_2' & `mean_log_tot_sales1_40_4' & `mean_log_tot_sales1_40_8'  \\
tex &  (`se_log_tot_sales1_40')  & (`se_log_tot_sales1_40_2') &  (`se_log_tot_sales1_40_4') &  (`se_log_tot_sales1_40_8') \\
tex iii. Optimal BW & `mean_log_tot_sales1_15'  & `mean_log_tot_sales1_15_2' & `mean_log_tot_sales1_15_4' & `mean_log_tot_sales1_15_8'  \\
tex &  (`se_log_tot_sales1_15')  &  (`se_log_tot_sales1_15_2') & (`se_log_tot_sales1_15_4') & (`se_log_tot_sales1_15_8')  \\
tex				\hline
tex				\end{tabular}
texdoc close
