
local outcome_list s_ta nout 
 
foreach t in p25_0 p75_0 p50_0 {
foreach bal in ab  {
foreach y in 09  {
foreach f in 2  {
foreach eps in 10 {
foreach est in  log_modif {
foreach est_m in 1 2 {
foreach random in $random_s {
foreach run in $run_time {
use "${datadir}/data_`bal'_`y'.dta", clear

	*rename and keep relevant variables
	rename total_tsales s_ta
	rename rtaxsale out 
	rename rtaxpur input 
	rename rnetliab liab
	rename total_sales stot
	rename aoutput nout
	rename aliability nliab

	keep liab hascard retail wholesale ide year cede coddeptofiscal stot s_ta out ainput ///
	hascard nout nliab year_birth serv_* card_sales

	*keeping only retail firms 
	keep if retail==1

	
/*-------------------------------------------------------------------------------
				2. Subsample for SDID 
*-------------------------------------------------------------------------------*/
if `est_m'==2 {

		set seed 1234
		** selecting 50% random sample 
		local tt10 2010
		local tt11 2011
		local tt09 2009
		gen random=runiform() if year==`tt`y''
		
		local r50 0.5
		local r100 1
		
		egen random_t=mean(random), by(ide)
		keep if random_t<=`r`random''

		}
		
count 

	local t09 2009 
	local t10 2010 
	local t11 2011 

	*keeping firms that had a POS pre-reform
	gen hascard_initial=hascard if year<2014 // year==`t`y''
	egen pos_initial=mean(hascard_initial), by(ide)
	keep if pos_initial!=0 & pos_initial!=. 

	*quintiles of card sales in first year
	gen card_sale_1=card_sales if year==`t`y''
	egen t_card_sale_1=mean(card_sale_1), by(ide)
	drop if t_card_sale_1==.
	egen decile=cut(t_card_sale_1), group(5)
	
	*merge rebate rate from card transaction data
	merge m:1 ide using "$datadir\firm_rebate_rate_0914.dta", gen(merge_card)
	
	keep if merge_card==3
	drop merge_card 
	

	*recode of year of incorporation	
	recode  year_birth (1950=1950) (1951/1955=1951) (1956/1960=1956) (1961/1965=1961) /// 
	(1966/1970=1966) (1971/1975=1971) (1976/1980=1976), gen(year_inc)

	*assigning firms into treatment below median mean, or zero 
		foreach d in p50 mean {
		sum rebate_fraction_w if year==2014, d
		local mean_`d'_w=r(`d')
		gen treated_`d'=rebate_fraction_w<=`mean_`d'_w'
		}
		gen treated_z=(rebate_fraction_w==0)
	
	* different than zero
		foreach d in p50 mean p25 p75 {
		sum rebate_fraction_w if rebate_fraction_w!=0 & year==2014, d
		local mean_`d'_w=r(`d')
		gen treated_`d'_0=(rebate_fraction_w<=`mean_`d'_w') if rebate_fraction_w!=0
		}
		
	* excluding top and bottom 5% 
		winsor2 rebate_fraction_w, cuts(5 95) suffix(_t) trim
		foreach d in p50 mean {
		sum rebate_fraction_w_t if year==2014, d
		local mean_`d'_w=r(`d')
		gen treated_`d'_t=(rebate_fraction_w_t<=`mean_`d'_w') if rebate_fraction_w_t!=.
		}

	*variables for regression
		
		*Simple treatment indicator
			gen distt=year-2014
			gen post=distt>=0
			tab distt, gen(pe)
			gen did_rvsw=post*treated_`t'

		*Event study treatment indicator
			local m09 7
			local m10 6
			local m11 5
			
			forvalues  i = 1(1)`m`y'' {
			gen did_`i'=treated_`t'*pe`i'
			}
		
		*Transformations of outcomes
			local w 99
			foreach var in `outcome_list'  {
			*winsorizing
			winsor2 `var', suffix(_`w') cuts(0 `w') by(year treated_`t') 
			
			*Log(x+epsilon) with modification as in Chen & Roth 2023
			gen aux2_`var'=`var'_`w'
			replace aux2_`var'=. if `var'_`w'==0
			egen minvar_`var'=min(aux2_`var')
			sum minvar_`var'
			gen log_modif_`var'=log(`var'_`w'/(minvar_`var'))
			replace log_modif_`var'=-(`eps'/100) if `var'_`w'==0
			}
		
		
		if `est_m'==1 {
	*Definining different sets of FE
		local d_09 did_1 did_2 did_3 did_4 did_6 did_7
		local d_10 did_1 did_2 did_3 did_5 did_6
		local d_11 did_1 did_2 did_4 did_5
		
		local fe_1 i.cede 
		local fe_2 i.year_inc#i.year
		local fe_3 i.decile#i.year 
		local fe_4 i.year_inc#i.year i.decile#i.year
	
		foreach var in `outcome_list' {
		preserve
		drop if treated_`t'==. 
		* Scaling outcome variables by pre-reform mean
		bys  post treated_`t': egen aux_sc_`est'_`var'=mean(`est'_`var')
		replace aux_sc_`est'_`var'=. if post==1
		bys treated_`t': egen scale_`est'_`var'=min(aux_sc_`est'_`var')
		gen s_`est'_`var'=`est'_`var'/scale_`est'_`var'	

		collapse (mean) s_`est'_`var'=s_`est'_`var' m_`est'_`var'=`est'_`var' (semean) se_`est'_`var'=s_`est'_`var', by(distt  treated_`t')
		
		** building means and confidence interval 
		gen v_`est'_`var'=se_`est'_`var'*1.96
		gen lower_`est'_`var'=s_`est'_`var'-v_`est'_`var'
		gen upper_`est'_`var'=s_`est'_`var'+v_`est'_`var'
		gen mean_`est'_`var'=s_`est'_`var'
		
		*Reshape
		keep lower_* upper_* mean_* distt treated_`t'
		reshape wide lower_* upper_* mean_*, i(distt) j( treated_`t')
		
	local xl_09 xlabel(-5(1)1)
	local xl_10 xlabel(-4(1)1)
	
	twoway (conn mean_`est'_`var'0 distt, lcolor(blue) mcolor(blue) msymbol(X) msize(medium)) ///
	(conn mean_`est'_`var'1 distt, color(red) mcolor(red) msize(medium)), ///
	 graphregion(fcolor(white)) ///
	ylabel(.85(.1)1.15, labsize(medium)) legend(order(2 "Treatment" 1 "Control") rows(1) size(small)) ///
	ytitle("Normalized Log Outcome", size(medium)) xline(-0.5, lwidth(medthin) lcolor(black)) ///
	xtitle(Years to Reform, size(medium)) scale(1.2) `xl_`y''
		graph export did_2lines_rebate_share_`f'_`est'_`var'_`t'_`bal'_`y'_`eps'.pdf, replace
		restore
		}
		
	
	
	*Regression estimations
	foreach var in `outcome_list' {
		* TWFE
		reghdfe `est'_`var' did_rvsw, abs(i.ide i.distt  `fe_`f'') cluster(i.ide)
		foreach x in se b {
		local p`x'_`var'=string(_`x'[did_rvsw], "%15.3fc")
		
		count if did_rvsw==1 & distt==0 & e(sample)==1
		local n_treat=r(N)
		count if did_rvsw==0 & distt==0 & e(sample)==1
		local n_control=r(N)		
		
		}
	
		*EVENT STUDY ESTIMATES
		reghdfe `est'_`var' `d_`y'', abs(i.ide i.distt `fe_`f'') cluster(i.ide)

		local m09 1 2 3 4 6 7
		local m10 1 2 3 5 6
		local m11 1 2 4 5
		
		
		foreach x in se b {
		foreach p in `m`y''  {
			gen m`x'_`var'_`p'=_`x'[did_`p']
		}
		}
	}
			
	*Keep relevant data and reshape
		keep distt mse_*_*  mb_*_*

		foreach p in `m`y'' {
		foreach var in `outcome_list' {
		gen upper_`var'_`p'=mb_`var'_`p'+(mse_`var'_`p'*1.960)
		gen lower_`var'_`p'=mb_`var'_`p'-(mse_`var'_`p'*1.960)
		}
		}

		keep distt mb_*_* upper_* lower_*

		keep if distt==0
		duplicates drop distt, force

				local m09 5
				local m10 4
				local m11 3
				
		foreach var in `outcome_list' {
		gen mb_`var'_`m`y''=0
		gen upper_`var'_`m`y''=.
		gen lower_`var'_`m`y''=.
		}

	*Loop to shape data and produce graph	
		foreach var in `outcome_list' {
		preserve
		
		reshape long mb_`var'_ upper_`var'_ lower_`var'_ , i(distt) j(period)
			
		local m09 6
		local m10 5
		local m11 4				
		replace period=period-`m`y''

		gen value=0

		local c_log_modif="OLS DiD (Log)"
		local c_log="OLS DiD (Log)"
		
		local l_09="xlabel(-5(1)1, labsize(medium))"
		local l_10="xlabel(-4(1)1, labsize(medium))"
		local l_11="xlabel(-3(1)1, labsize(medium))"

	*Output graph
		graph twoway (rcap upper_`var'_ lower_`var'_ period, fcolor(blue) lwidth(0.3) lcolor(blue)) ///
		(scatter mb_`var'_ period, mcolor(blue) msize(small) lcolor(blue)) ///
		(line value  period, lcolor(red) lwidth(medthin)), ///
		graphregion(fcolor(white)) legend(off) ylabel(-0.5(0.1)0.5, labsize(medium)) ///
		xline(-0.5, lwidth(medium) lcolor(black)) yline(0, lwidth(medthin) lcolor(red)) ///
		ytitle(Point Estimate, size(medium))  ///
	    xtitle(Years to Reform) scale(1.2) `l_`y''   ///
	    note("DiD: `pb_`var'' (`pse_`var''), N Treated:`n_treat', N Control=`n_control'")
	graph export did_period_rebate_share_`f'_`est'_`var'_`t'_`bal'_`y'_`eps'.pdf, replace		
	restore
	}
	

		}
		
		
		if `est_m'==2 {
			drop if treated_`t'==.
			tab year treated_`t'
		* Variables for SDID
		* Post 
		gen did_treat=treated_`t'*post
		egen group=group(ide)
		egen tag=tag(ide)
		
local n1_10 4
local n2_10 6
local n1_11 3
local n2_11 5
local n1_09 5
local n2_09 7 

foreach var in `outcome_list' {
sdid `est'_`var' group year did_treat, vce(bootstrap) reps($replication) graph  g2_opt(ylab(-4(1)1) ytitle("Output") scheme(sj)) graph_export(output,.pdf) 
local  coef=string(e(ATT), "%15.3fc")
local 	se=string(e(se), "%15.3fc")

count if tag==1 & treated_`t'==1
local count_t=string(r(N), "%15.0fc")
count if tag==1 & treated_`t'==0
local count_c=string(r(N), "%15.0fc")

matrix lambda = e(lambda)[1..`n1_`y'',1] //save lambda weight
matrix yco = e(series)[1..`n1_`y'',2] //control baseline
matrix ytr = e(series)[1..`n1_`y'',3] //treated baseline
matrix aux = lambda'*(ytr - yco) //calculate the pre-treatment mean
scalar meanpre_o = aux[1,1]
matrix difference = e(difference)[1..`n2_`y'',1..2] // Store Ytr-Yco
svmat difference
ren (difference1 difference2) (time d)
replace d = d - meanpre_o // Calculate vector in (8)

local b=1
local B =`run'

while `b'<=`B' {
preserve
bsample, cluster(group) idcluster(c2)
qui count if did_treat==0
local rt1=r(N)
qui count if did_treat!=0
local rt2=r(N)
if (`rt1'!=0 & `rt2'!=0) { 
sdid `est'_`var' c2 year did_treat, vce(noinference) graph 
matrix lambda_b = e(lambda)[1..`n1_`y'',1] //save lambda weight
matrix yco_b = e(series)[1..`n1_`y'',2] //control baseline
matrix ytr_b = e(series)[1..`n1_`y'',3] //treated baseline
matrix aux_b = lambda_b'*(ytr_b - yco_b) //calculate the pre-treatment mean
matrix meanpre_b = J(`n2_`y'',1,aux_b[1,1])

matrix d`b' = e(difference)[1..`n2_`y'',2] - meanpre_b

local ++b
} 
restore 
}


preserve
keep time d
keep if time!=.
replace time=time-2014

forval b=1/`B' { 
    svmat d`b' //import each bootstrap replicate of difference between trends
}

egen rsd = rowsd(d11 - d`B'1) //calculate standard deviation of this difference
gen LCI = d + invnormal(0.025)*rsd //lower bounds on bootstrap CIs
gen UCI = d + invnormal(0.975)*rsd //upper bounds on bootstrap CIs

gen value=0


graph twoway (rcap UCI LCI time, fcolor(blue) lcolor(blue)) ///
(scatter d time, mcolor(blue) msize(small) lcolor(blue)) ///
(line value time, lcolor(red) lwidth(medthin)), ///
ylabel(-0.5(0.1)0.5, labsize(medium)) ///
graphregion(fcolor(white)) legend(off) xtitle("Years to Reform") ytitle("Point Estimate") xlab(-4(1)1) ///
xline(-0.5, lwidth(medium) lcolor(black)) yline(0, lwidth(medthin) lcolor(red)) scale(1.2) ///
note("ATT: `coef' (`se')" "N Treated `count_t' N Control `count_c'")
graph export "event_sdid_`est'_`var'_`y'_`bal'_`eps'_r`random'_`t'.pdf", replace
restore
drop time d 
}	
}
	

	
}
}
}
}
}
}
}
}
}








