/***********************************************************************************************/
* bar chart with transactions  grouped by approximate rebate rate ///// 
/***********************************************************************************************/
		*imports transaction data
		use "$stata_raw\card_data_ext_2014.dta", clear
		
		*keeping local currency
		keep if moneda==1

		*keeping august september 2014
		keep if month==9

		* rebate dummy 
		gen rebate=(tot_credito>0 & tot_credito!=.)

		*rebate fraction
		gen rebate_fraction=(tot_credito/tot_venta) if rebate==1
		
		*rebate rate 2% margin
		gen rebate_4_lower=((4/122)*.98) if rebate==1
		gen rebate_4_upper=((4/110)*1.02) if rebate==1
		
	*	classifying transactions based on rebate rate (4pp, less than 4pp , more than 4pp)
		gen rebate_4=(rebate_fraction>=rebate_4_lower & rebate_fraction<=rebate_4_upper) if rebate==1
		gen rebate_4_more=(rebate_fraction>rebate_4_upper) if rebate==1
		gen rebate_4_less=(rebate_fraction<rebate_4_lower) if rebate==1
		egen rebate_type=rowtotal(rebate_4 rebate_4_more rebate_4_less)
		replace rebate_type=2 if rebate_type==1 & rebate_4_more==1
		replace rebate_type=3 if rebate_type==1 & rebate_4_less==1

		gen count=1
		
		*Monthly aggregates
		egen total_venta=sum(tot_venta), by(month)
		egen tot_count=sum(count), by(month)
		gen share_venta=tot_venta/total_venta
		gen share_count=count/tot_count

		label define rebate_type 0 "No VAT rebate" 1 "Rebate 4 ppt" 2 "Rebate > 4 ppt" 3 "Rebate 2 ppt"
		label values rebate_type rebate_type

		*Collpase month level
		collapse (sum) share_venta share_count, by(month rebate_type)
		replace share_venta=share_venta*100
		replace share_count=share_count*100
		
		foreach m in 9 {
		graph bar (mean) share_venta if month==`m', over(rebate_type, sort(share_venta) descending label(labsize(medsmall))) ///
		ytitle(Share of Transactions) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(fcolor(white) lcolor(	white) ifcolor(white) ilcolor(white)) blabel(bar, format(%9.3g))
		graph export "bar_rebates_`m'.pdf", replace

		}

/***********************************************************************************************/
// Preparing figure B.11, panel A - distribution of exact transaction-level rebate rates
/***********************************************************************************************/			
		use "$stata_raw\card_data_ext_2014.dta", clear
		keep if moneda==1
		keep if month>=8 & month<=9

		
		*keeping firms with rebates
		gen rebate=(tot_credito>0 & tot_credito!=.)
		keep if rebate==1

		*rebate share out of total transaction
		gen rebate_fraction=(tot_credito/tot_venta) 

		winsor2 rebate_fraction, cuts(0 99) by(month) replace
		
		*estimated rebate rates 
		gen rebate_fraction_100=rebate_fraction*100
		gen rebate_fraction_122=rebate_fraction*122
		gen rebate_fraction_110=rebate_fraction*110

		local l_100="3.2"
		local u_100="3.7"
		local l_110="3.52"
		local u_110="4.07"
		local l_122="3.90"
		local u_122="4.51"


		*histogram of estimated rebate rate by month 
		foreach r in 122 {
		sum rebate_fraction_`r' if month==9 & rebate_fraction_`r'<=8
		local mean_9=r(mean)
		local mean_line_9=round(`mean_9', .01)
		local mean_t_9=`mean_line_9'+.05
		local mean_s_9=string(r(mean), "%15.2fc")
		twoway (histogram rebate_fraction_`r' if month== 9 & rebate_fraction_`r'<=8, percent fcolor(none) lcolor(blue)), ///
		/*xline(`l_`r'', lwidth(medthick) lpattern(dash) lcolor(black)) ///
		xline(`u_`r'', lwidth(medthick) lpattern(dash) lcolor(black)) ///
		xline(`mean_line_9', lwidth(medthick) lpattern(solid) lcolor(red)) */ legend(off) ///
		ytitle(Share of Transactions) xtitle((Rebate Value/VAT Inclusive Value)*`r') scale(1.2) ///
		graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(fcolor(white) ifcolor(white)) 
		graph export "hist_rebate_fraction_month9_`r'.pdf", replace
		}
		


