
*-------------------------------------------------------------------------------
*2 RDD Estimation
*-------------------------------------------------------------------------------
foreach nweek in 80  {
foreach y in log_tot_sales log_count_trans {
foreach pgraph in 1   {

use "$datadir\card_transaction_weekly_firm_rd.dta", clear

********************************************************
*  MAIN VARIABLES
*******************************************************
	gen week_since_reform=week
	gen distt=week_since_reform 
	gen post=(distt>=0)
	gen inter=distt*post 
	
	tostring id_afi, gen(id)
	encode id,gen(id_code)
	sum id_code	
	



********************************************************
* Running RD regression
*******************************************************

		* RD Regression with 3 levels of polynomial using the outcome var using rdrobust package to get bias corrected confidence intervals
		 *Run regression and save results
		gen running=(distt-0)
		
		*specific time window
		drop if running<-`nweek' | running>`nweek'

		foreach P in 1 2 { 
		rdrobust `y' running, c(0) p(`P') h(`nweek') covs(month id_code)
		glo mean_`y'`P'=string(e(tau_cl), "%15.3fc")
		glo se_`y'`P'=string(e(se_tau_cl), "%15.3fc")
		}
		
********************************************************
* De-season outcome for scatter plot
*******************************************************

		
		gen interaction=running*post
		gen interaction_sq=interaction*running
		gen interaction_c=interaction_sq*running
		gen distt_sq=running*running
		gen distt_c=distt_sq*running

		foreach P in 1 2 { 
		local spec1 running post interaction i.month id_code, r  
		local spec2 running distt_sq post interaction interaction_sq i.month id_code, r

		reg `y' `spec`P''
		
		* Deseason weekly data by  month and day of the week
			gen `y'_`P'd = `y' if month==1
			forvalues i = 2/12 {
			replace `y'_`P'd = `y' - _b[`i'.month] if month==`i'
			}
		
			}
		
********************************************************
* AGGREGATED SCATTER PLOT
*******************************************************
		* creating bins
		egen ranking=rank(week_since_reform)
		egen group_b=cut(ranking) if week_since_reform<0 & week_since_reform>=-`nweek', group(10)
		egen group_a=cut(ranking) if week_since_reform>=0 & week_since_reform<=`nweek', group(10)

		replace group_a=10+group_a
		gen group=group_a if group_a!=. 
		replace group=group_b if group_a==. & group_b!=.
	
		*aggregating variables 
		foreach P in 1 2 { 
		*  binned scatter
		egen b`y'_`P'd=mean(`y'_`P'd), by(group)
		}
	
		egen bweek_since_reform=mean(week_since_reform), by(group)

********************************************************
* GRAPHS
******************************************************
		
		* Creating text references for graph
		foreach P in 1 2 { 
		sum `y'_`P'd if week_since_reform>=-`nweek' & week_since_reform<=`nweek', d
		glo m`y'_`P'd = r(p90)
		}
		
		sum week_since_reform if week_since_reform>=-`nweek' & week_since_reform<=`nweek', d
		glo xposi=r(min)
		glo textx=5*(${xposi}/5)
		glo textx: di %3.2f ${textx}
		scalar rmin=round(r(min),0.1)
		scalar rmax=round(r(max),0.1)
		
			*Bin Collapsed
			collapse (mean) `y'_1d `y'_2d `y' week_since_reform , by(group)

			*position of text
			foreach p in 1 2 {
			gen coeff_`y'`p'=${mean_`y'`p'}
			sum `y'_`p'd if group==9
			gen lev_`y'_`p'=r(mean)
			gen rev_`y'_`p'=(coeff_`y'`p'/lev_`y'_`p')*100
			sum rev_`y'_`p'
			glo del_`y'_`p'=r(mean)
			glo del_`y'_`p': di %3.2f  ${del_`y'_`p'}
			}

			
			sum `y'_`pgraph'd if week_since_reform>=-`nweek' & week_since_reform<=`nweek', d
			glo yt`y'_`pgraph'd = r(p90)
			sum `y'_`pgraph'd if week_since_reform>=-`nweek' & week_since_reform<=`nweek', d
			glo yt`y'_`pgraph'dd = r(p50)
			glo xtext=1
			
			*labels for y axis
				local l_log_tot_sales ="Log Volume of Card Transactions"
				local l_log_count_trans ="Log Number of Card Transactions"
				

twoway fpfitci `y'_`pgraph'd week_since_reform if week_since_reform<0 & week_since_reform>=-`nweek', level(95) estopts(degree(`pgraph')) lcolor(blue) acolor(gs12) alcolor(gs12) || ///
fpfitci `y'_`pgraph'd week_since_reform if week_since_reform>=0 & week_since_reform<=`nweek', level(95) estopts(degree(`pgraph')) lcolor(blue) acolor(gs12) alcolor(gs12) || ///
scatter `y'_`pgraph'd week_since_reform if week_since_reform>=-`nweek' & week_since_reform<=`nweek' , xline(0, lcolor(black)) xline(54, lpattern(dash_dot) lcolor(black%50)) color(red) ///
xscale(r(`=scalar(rmin)' `=scalar(rmax)')) xlabel(-`nweek'(20)`nweek') ///
legend(off) graphregion(color(white)) bgcolor(white) xtitle("Weeks to reform") ytitle(`l_`y'') ///
text(${yt`y'_`pgraph'd} ${textx} "RD (Linear): ${mean_`y'1} (${se_`y'1})" "RD (Quadratic): ${mean_`y'2} (${se_`y'2})", place(e) size(medlarge)) 			///
text(${yt`y'_`pgraph'dd} ${xtext} "{&lArr} August 2014 VAT Rebates" "of up to 4 ppt Enter Into Effect", place(e)) 

graph export "RDrobust_firm_`y'_`nweek'_`pgraph'_all.pdf", replace
}
}
}