
*-------------------------------------------------------------------------------
*1 RDD Estimation
*-------------------------------------------------------------------------------
foreach nweek in  80  {
foreach y in log_count_pos_total log_count_firms_total log_tot_sales log_count_trans {
foreach pgraph in 2   {
foreach a in $option_rd {

use "$datadir\card_transaction_weekly_rd.dta", clear

********************************************************
*  MAIN VARIABLES
*******************************************************
*rename count_pos count_pos_c
	gen distt=week_since_reform 
	gen post=(distt>=0)
	gen inter=distt*post 
	sum week if year==2013 & month==1 
	local new_week=r(min)
	gen break_2013=(week_since_reform>=`new_week')



********************************************************
* Running RD regression
*******************************************************


		* RD Regression with 3 levels of polynomial using the outcome var using rdrobust package to get bias corrected confidence intervals
		 *Run regression and save results
		gen running=(distt-0)
		foreach P in 1 2 3 { 
		rdrobust `y' running, c(0) p(`P') h(`nweek') covs(month)
		glo mean_`y'`P'=e(tau_cl)
		glo se_`y'`P'=e(se_tau_cl)
		glo mean_`y'`P': di %3.2f ${mean_`y'`P'}
		glo se_`y'`P': di %3.2f ${se_`y'`P'}
		}
		
********************************************************
* De-season outcome for scatter plot
*******************************************************
		foreach P in 1 2 3 { 

		local spec1_main c.distt##i.post i.month, r  
		local spec2_main c.distt##c.distt##i.post##i.post i.month, r
		local spec3_main c.distt##c.distt##c.distt##i.post##i.post##i.post i.month, r
		local spec1_jan13 c.distt##i.post c.distt##i.break_2013  i.month, r  
		local spec2_jan13 c.distt##c.distt##i.post##i.post c.distt##c.distt##i.break_2013##i.break_2013 i.month, r
		local spec3_jan13 c.distt##c.distt##c.distt##i.post##i.post##i.post c.distt##c.distt##c.distt##i.break_2013##i.break_2013##i.break_2013 i.month, r

		reg `y' `spec`P'_`a''
		
		* Deseason weekly data by  month and day of the week
			gen `y'_`P'd = `y' if month==1
			forvalues i = 2/12 {
			replace `y'_`P'd = `y' - _b[`i'.month] if month==`i'
			}
		}
********************************************************
* AGGREGATED SCATTER PLOT
*******************************************************
		* creating bins
		egen ranking=rank(week_since_reform)
		egen group_b=cut(ranking) if week_since_reform<0 & week_since_reform>=-`nweek', group(10)
		egen group_a=cut(ranking) if week_since_reform>=0 & week_since_reform<=`nweek', group(10)

		replace group_a=10+group_a
		gen group=group_a if group_a!=. 
		replace group=group_b if group_a==. & group_b!=.
	
		*aggregating variables 
		foreach P in 1 2 3 { 
		*  binned scatter
		egen b`y'_`P'd=mean(`y'_`P'd), by(group)
		}
	
		egen bweek_since_reform=mean(week_since_reform), by(group)

********************************************************
* GRAPHS
******************************************************
		
		* Creating text references for graph
		foreach P in 1 2 3 { 
		sum `y'_`P'd if week_since_reform>=-`nweek' & week_since_reform<=`nweek', d
		glo m`y'_`P'd = r(p90)
		}
		
		sum week_since_reform if week_since_reform>=-`nweek' & week_since_reform<=`nweek', d
		glo xposi=r(min)
		glo textx=5*(${xposi}/5)
		glo textx: di %3.2f ${textx}
		scalar rmin=round(r(min),0.1)
		scalar rmax=round(r(max),0.1)
		
			*Bin Collapsed
			collapse (mean) `y'_1d `y'_2d `y'_3d `y' week_since_reform , by(group)

			*position of text
			foreach p in 1 2 3 {
			gen coeff_`y'`p'=${mean_`y'`p'}
			sum `y'_`p'd if group==9
			gen lev_`y'_`p'=r(mean)
			gen rev_`y'_`p'=(coeff_`y'`p'/lev_`y'_`p')*100
			sum rev_`y'_`p'
			glo del_`y'_`p'=r(mean)
			glo del_`y'_`p': di %3.2f  ${del_`y'_`p'}
			}

			
			sum `y'_`pgraph'd if week_since_reform>=-`nweek' & week_since_reform<=`nweek', d
			glo yt`y'_`pgraph'd = r(p90)
			sum `y'_`pgraph'd if week_since_reform>=-`nweek' & week_since_reform<=`nweek', d
			glo yt`y'_`pgraph'dd = r(p50)
			glo xtext=1
			
			*labels for y axis
				local l_log_tot_sales ="Log Volume of Card Transactions"
				local l_log_count_trans ="Log Number of Card Transactions"
				local l_log_count_pos_total ="Log Number of POS"
				local l_log_count_firms_total ="Log Number of Firms with POS"
				

twoway fpfitci `y'_`pgraph'd week_since_reform if week_since_reform<0 & week_since_reform>=-`nweek', level(95) estopts(degree(`pgraph')) lcolor(blue) acolor(gs12) alcolor(gs12) || ///
fpfitci `y'_`pgraph'd week_since_reform if week_since_reform>=0 & week_since_reform<=`nweek', level(95) estopts(degree(`pgraph')) lcolor(blue) acolor(gs12) alcolor(gs12) || ///
scatter `y'_`pgraph'd week_since_reform if week_since_reform>=-`nweek' & week_since_reform<=`nweek' , xline(0, lcolor(black)) xline(54, lpattern(dash_dot) lcolor(black%50)) color(red) ///
xscale(r(`=scalar(rmin)' `=scalar(rmax)')) xlabel(-`nweek'(20)`nweek') ///
legend(off) graphregion(color(white)) bgcolor(white) xtitle("Weeks to reform") ytitle(`l_`y'') ///
text(${yt`y'_`pgraph'd} ${textx} "RD (Linear): ${mean_`y'1} (${se_`y'1})" "RD (Quadratic): ${mean_`y'2} (${se_`y'2})", place(e) size(medlarge)) 			///
text(${yt`y'_`pgraph'dd} ${xtext} "{&lArr} August 2014 VAT Rebates" "of up to 4 ppt Enter Into Effect", place(e)) 

graph export "RDrobust_`y'_`nweek'_deseason_bc`pgraph'_2015_`a'.pdf", replace
}
}
}
}

