
/*****************************************************************/
/* Get average rebates rates at the firm-level for Sept 2014 */
/*****************************************************************/
	use "$stata_raw\card_data_ext_2014.dta", clear

		keep if month==9 
		keep if moneda==1

		gen rebate=(tot_credito>0 & tot_credito!=.)

		* rebate rate
			gen rebate_fraction=(tot_credito/tot_venta) if rebate==1
			replace rebate_fraction=. if tipo_tran!=9
		
		* rebate rate new
			gen rebate_fraction_n=(tot_credito/tot_venta) 
			replace rebate_fraction_n=. if rebate_fraction>.05

		* weight rebate rate by sales 
			gen sales_rebate=tot_venta if tipo_tran==9 & rebate==1
			egen tot_sales=sum(sales_rebate), by(id_afi) 
			gen share_venta=tot_venta/tot_sales if tipo_tran==9 & rebate==1
			*rebate rate weighted
			gen rebate_fraction_w=share_venta*rebate_fraction ///
			if rebate==1 & tipo_tran==9

		* weight new rebate rate by sales
			gen sales_rebate_n=tot_venta if rebate_fraction<=.05
			egen tot_sales_n=sum(sales_rebate_n), by(id_afi) 
			gen share_venta_n=tot_venta/tot_sales ///
			if  rebate_fraction<=.05
			*rebate rate weighted
			gen rebate_fraction_w_n=share_venta_n*rebate_fraction_n ///
			if  rebate_fraction<=.05 


		*collapse firm level 
		collapse (mean) rebate_fraction rebate_fraction_n (sum) tot_credito tot_venta rebate rebate_fraction_w ///
		rebate_fraction_w_n (count) moneda, by(id_afi month)
		
		foreach v in rebate_fraction rebate_fraction_n rebate_fraction_w rebate_fraction_w_n {
			replace `v'=0 if `v'==.
		}
		
		drop if rebate_fraction>.17  /*extreme values*/
		drop if id_afi==0
		drop month
		
		*dropping firms with zero sales 
		drop if tot_venta==0

		rename tot_credito amount_rebate
		rename tot_venta tot_trans_amount
		rename rebate count_rebate
		rename moneda count_trans
		rename id_afi ide
		rename rebate_fraction rebate_fraction_s
		
		*Generate mean/median division			
		sum rebate_fraction_w_n, d 
		gen above_median_n=rebate_fraction_w_n>=r(p50)
		gen above_mean_n=rebate_fraction_w_n>=r(mean)
		
		save "${datadir}/firm_rebate_rate_w.dta", replace

/*****************************************************************/
/* Merge rebate rate into transaction count/volume by day*firm */
/* Collapse at daily level for each sample cut and year */
/*****************************************************************/		
		
		foreach year in 2013 2014 2015  {
		use "${datadir}/daily_firm_pos_`year'.dta", clear
		
		drop if count_m1==0 

		*collapse at the week-firm-pos level
		collapse (sum) tot_venta_m1 count_m1, by(year month day id_afi)

		rename (tot_venta_m1 count_m1) (tot_venta count)
		
		rename id_afi ide 
		
		merge m:1 ide using "${datadir}/firm_rebate_rate_w.dta", nogen keep(3)
		
		foreach x in mean median {
			preserve
		drop if above_`x'_n==.
		collapse (sum) tot_venta count, by(month day year above_`x'_n)
		reshape wide tot_venta count, i(month day year) j(above_`x'_n)
			rename tot_venta0 tot_venta_c
			rename tot_venta1 tot_venta_t
			rename count0 count_c
			rename count1 count_t
			save "$datadir\daily_type_`year'_`x'_n.dta", replace
			restore
		}
		}



/*****************************************************************/
/* Appending those datasetst and creating weekly data */
/*****************************************************************/

		foreach t in mean median {
		use "$datadir\daily_type_2013_`t'_n.dta", clear

		foreach year in 2014 2015 {
			append using "$datadir\daily_type_`year'_`t'_n.dta"
		}

		sort year month day

		gen edate=mdy(month, day, year)
		gen reform_day=edate if year==2014 & month==8 & day==1
		gen one=1
		egen reform_dayt=mean(reform_day), by(one)
		drop reform_day
		gen day_dist=edate-reform_dayt
		replace day_dist=day_dist/7
		gen week=floor(day_dist)

		*generating week ID
		gen periodo=year*100+month
		tostring periodo, replace

		egen peri=concat(periodo day)
		gen period_day=date(peri, "YMD")

		format period_day %td
				gen period=mofd(period_day)
				format period %tm
				
		gen dow=dow(period_day)

		recode dow (5=1) (6=2) (0=3) (1=4) (2=5) (3=6) (4=7), gen(dayweek) //chaging week start day to friday

		gen week_since_reform=week

		*collapsing by week
		collapse (sum) tot_venta_c tot_venta_t count_c count_t (mean) week_since_reform month year, by(week)

		*converting sales and transaction count to millions
		replace tot_venta_c=tot_venta_c/1000000
		replace tot_venta_t=tot_venta_t/1000000
		replace count_c=count_c/1000000
		replace count_t=count_t/1000000

		foreach y in tot_venta_c tot_venta_t count_c count_t {
			gen log_`y'=ln(`y')
		}

		save "$datadir\card_transaction_weekly_pp_`t'_n.dta", replace
		}





/*****************************************************************/
/* Taking the weekly data to run RD estimation */
/*****************************************************************/


		foreach t in mean median {
		foreach nweek in  70  {
		foreach y in log_tot_venta_c log_tot_venta_t log_count_c log_count_t {
		foreach pgraph in 1  {

		use "$datadir\card_transaction_weekly_pp_`t'_n.dta", clear


		********************************************************
		*  MAIN VARIABLES
		*******************************************************
		*rename count_pos count_pos_c
			gen distt=week_since_reform 
			gen post=(distt>=0)
			gen inter=distt*post 
			replace month=floor(month)
			
		********************************************************
		* Running RD regression
		*******************************************************

				* RD Regression with 3 levels of polynomial using the outcome var using rdrobust package to get bias corrected confidence intervals
				 *Run regression and save results
				gen running=(distt-0)
				foreach P in 1 2 3 { 
				rdrobust `y' running, c(0) p(`P') h(`nweek') covs(month)
				glo mean_`y'`P'=e(tau_cl)
				glo se_`y'`P'=e(se_tau_cl)
				glo mean_`y'`P': di %3.2f ${mean_`y'`P'}
				glo se_`y'`P': di %3.2f ${se_`y'`P'}
				}
				

		********************************************************
		* Same polynomial in both sides of the threshold
		*******************************************************
				foreach P in 1 2 3 { 
		 local spec_same1 c.distt i.post  i.month if week_since_reform>=-`nweek' & week_since_reform<=`nweek', r 
		 local spec_same2 c.distt##c.distt i.post  i.month if week_since_reform>=-`nweek' & week_since_reform<=`nweek', r 
		 local spec_same3 c.distt##c.dist#c.distt i.post  i.month if week_since_reform>=-`nweek' & week_since_reform<=`nweek', r 
		 
				reg `y' `spec_same`P''
				
				foreach x in se b {
				glo `x'`y'pst`P'=_`x'[1.post]
				glo `x'`y'pst`P': di %3.2f  ${`x'`y'pst`P'}
				}
		}
		********************************************************
		* De-season outcome for scatter plot
		*******************************************************
		*since rdrobust dont let us save coefficients from covariates, I am running the normal OLS

				foreach P in 1 2 3 { 

				local spec1 c.distt##i.post i.month, r  
				local spec2 c.distt##c.distt##i.post##i.post i.month, r
				local spec3 c.distt##c.distt##c.distt##i.post##i.post##i.post i.month, r

				reg `y' `spec`P''
				
				* Deseason weekly data by  month and day of the week
					gen `y'_`P'd = `y' if month==1
					forvalues i = 2/12 {
					replace `y'_`P'd = `y' - _b[`i'.month] if month==`i'
					}
				
					}
		********************************************************
		* AGGREGATED SCATTER PLOT
		*******************************************************
				* creating bins
				egen ranking=rank(week_since_reform)
				egen group_b=cut(ranking) if week_since_reform<0 & week_since_reform>=-`nweek', group(10)
				egen group_a=cut(ranking) if week_since_reform>=0 & week_since_reform<=`nweek', group(10)

				replace group_a=10+group_a
				gen group=group_a if group_a!=. 
				replace group=group_b if group_a==. & group_b!=.
			
				*aggregating variables 
				foreach P in 1 2 3 { 
				*  binned scatter
				egen b`y'_`P'd=mean(`y'_`P'd), by(group)
				}
			
					egen bweek_since_reform=mean(week_since_reform), by(group)

		********************************************************
		* GRAPHS
		******************************************************
				
				* Creating text references for graph
				foreach P in 1 2 3 { 
				sum `y'_`P'd if week_since_reform>=-`nweek' & week_since_reform<=`nweek', d
				glo m`y'_`P'd = r(p90)
				}
				
				sum week_since_reform if week_since_reform>=-`nweek' & week_since_reform<=`nweek', d
				glo xposi=r(min)
				glo textx=5*(${xposi}/5)
				glo textx: di %3.2f ${textx}
				scalar rmin=round(r(min),0.1)
				scalar rmax=round(r(max),0.1)

					*Bin Collapsed
					collapse (mean) `y'_1d `y'_2d `y'_3d `y' week_since_reform , by(group)

					foreach p in 1 2 3 {
					gen coeff_`y'`p'=${mean_`y'`p'}
					sum `y'_`p'd if group==9
					gen lev_`y'_`p'=r(mean)
					gen rev_`y'_`p'=(coeff_`y'`p'/lev_`y'_`p')*100
					sum rev_`y'_`p'
					glo del_`y'_`p'=r(mean)
					glo del_`y'_`p': di %3.2f  ${del_`y'_`p'}
					}

					
					sum `y'_`pgraph'd if week_since_reform>=-`nweek' & week_since_reform<=`nweek', d
					glo yt`y'_`pgraph'd = r(p90)
					sum `y'_`pgraph'd if week_since_reform>=-`nweek' & week_since_reform<=`nweek', d
					glo yt`y'_`pgraph'dd = r(p50)
					glo xtext=1
					
						local l_log_tot_venta_c ="Log Volume of Card Transactions"
						local l_log_tot_venta_t ="Log Volume of Card Transactions"
						local l_log_count_c ="Log Number of Card Transactions"
						local l_log_count_t ="Log Number of Card Transactions"
				
						   
						
					twoway fpfitci `y'_`pgraph'd week_since_reform if week_since_reform<0 & week_since_reform>=-`nweek', level(95) estopts(degree(`pgraph')) lcolor(blue) acolor(gs12) alcolor(gs12) || ///
					fpfitci `y'_`pgraph'd week_since_reform if week_since_reform>=0 & week_since_reform<=`nweek', level(95) estopts(degree(`pgraph')) lcolor(blue) acolor(gs12) alcolor(gs12) || ///
					scatter `y'_`pgraph'd week_since_reform if week_since_reform>=-`nweek' & week_since_reform<=`nweek' , xline(0, lcolor(black)) xline(54, lpattern(dash_dot) lcolor(black%50)) color(red) ///
					xscale(r(`=scalar(rmin)' `=scalar(rmax)')) xlabel(-`nweek'(20)`nweek') ///
					legend(off) graphregion(color(white)) bgcolor(white) xtitle("Weeks to reform") ytitle(`l_`y'') ///
					/*note("Relative Change {&cong} ${del_`y'_1} % (Linear RD), ${del_`y'_2} % (Quadratic RD)")*/ ///
					text(${yt`y'_`pgraph'd} ${textx} "RD (Linear): ${mean_`y'1} (${se_`y'1})" "RD (Quadratic): ${mean_`y'2} (${se_`y'2})", place(e) size(medlarge)) 			///
					text(${yt`y'_`pgraph'dd} ${xtext} "{&lArr} August 2014 VAT Rebates" "of up to 4 ppt Enter Into Effect", place(e)) 

					graph export "RDrobust_`y'_`nweek'_deseason_bc`pgraph'_`t'_n.pdf", replace
					

					}
					}
					}
		}

		/*
		foreach t in mean median {
		erase "D:\Uruguay\proc_data\daily_2013_type_`t'_w_`s'.dta"
		erase "D:\Uruguay\proc_data\daily_2014_type_`t'_w_`s'.dta"
		erase "D:\Uruguay\proc_data\daily_2015_type_`t'_w_`s'.dta"
		erase "D:\Uruguay\proc_data\card_transaction_weekly_pp_`t'_w_`s'.dta"
		}
		*/
