*-------------------------------------------------------------------------------
*1 Using data at the weekly level 
*-------------------------------------------------------------------------------

use "$datadir\card_transaction_weekly_rd.dta", clear

*new placebo reforms
*before the actual reform
local a=1
foreach v in 82 78 74 69 65 60 56 52 47 43 39 34 30 25 21 17 13 8 4 0 {
gen running`a'=week+`v'
local a=`a'+1
}

*after the actual reform
local b=21
foreach v in 5 9 14 18 22 27 31 35 39 44 45 53 57 61 66 70 {
gen running`b'=week-`v'
local b=`b'+1
}

rename log_tot_sales lnsales
rename log_count_trans lntrans
rename log_count_pos_total lnpos
rename log_count_firms_total lnfirms

* RD estimate
		foreach y in lnsales lntrans lnpos lnfirms {
		foreach P in 1 2 { 
		forvalues i = 1(1)36 {
		rdrobust `y' running`i', c(0) p(`P') covs(month)
		gen pe_`y'_`P'_`i'=e(tau_cl)
		}
		}
		}

keep week pe_*
keep if week==0
reshape long pe_lnsales_1_ pe_lnsales_2_ pe_lntrans_1_ pe_lntrans_2_ pe_lnpos_1_ pe_lnpos_2_ pe_lnfirms_1_ pe_lnfirms_2_, i(week) j(placebo)

* rd estimate for the actual reform
foreach var in pe_lnsales_1_ pe_lnsales_2_ pe_lntrans_1_ pe_lntrans_2_ pe_lnpos_1_ pe_lnpos_2_ pe_lnfirms_1_ pe_lnfirms_2_ {
	sum `var' if placebo==20
	local `var'_r=r(mean)
	gen `var'pv=(`var'>``var'_r')
	replace `var'pv=. if placebo==20
}

gen reform=(placebo==20)

* rest of weeks vs reform week
foreach var in lnsales_1 lnsales_2 lntrans_1 lntrans_2 lnpos_1 lnpos_2 lnfirms_1 lnfirms_2 {
	reg pe_`var'_ reform
	local b_`var'=string(_b[reform], "%15.3fc")
	local se_`var'=string(_se[reform], "%15.3fc")
}


foreach var in lnsales_1 lnsales_2 lntrans_1 lntrans_2 lnpos_1 lnpos_2 lnfirms_1 lnfirms_2 {
sum pe_`var'_ if reform==0
local m_0_`var'=string(r(mean), "%15.3fc")
sum pe_`var'_ if reform==1
local m_1_`var'=string(r(mean), "%15.3fc")
}

foreach var in lnsales_1 lnsales_2 lntrans_1 lntrans_2 lnpos_1 lnpos_2 lnfirms_1 lnfirms_2 {
	sum pe_`var'_pv
	local pv_`var'=string(r(mean), "%15.3fc")
}

foreach var in lnsales_1 lnsales_2 lntrans_1 lntrans_2 lnpos_1 lnpos_2 lnfirms_1 lnfirms_2 {

twoway (histogram pe_`var'_, bin(6) gap(35) fcolor(orange%29) lcolor(orange)), xline(`m_1_`var'', lwidth(medthick) lpattern(solid) lcolor(red)) legend(off) scale(1.2) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(fcolor(white) ifcolor(white)) xtitle("") ///
note("August 2014 RD Estimate (`m_1_`var'') vs Mean Placebo RD Estimate (`m_0_`var'')" "Estimates T-test: `b_`var'' (`se_`var'')" "Randomization Inference p-value: (`pv_`var'')", span)
graph export "placebo_rdd_`var'.pdf", replace
}

