foreach y in log_count_pos_total log_count_firms_total log_tot_sales log_count_trans {
foreach week in 70 {
foreach t in d {

*-------------------------------------------------------------------------------
*1 Using data at the weekly level 
*-------------------------------------------------------------------------------

use "$datadir\card_transaction_weekly_rd.dta", clear

*-------------------------------------------------------------------------------
*2 Variables construction
*-------------------------------------------------------------------------------

*main variables
	gen distt=week_since_reform 
	gen post=(distt>=0)
	gen inter=distt*post 

sort year month week  

tsset week_since_reform, weekly

reg `y' c.distt##i.post i.month 

*de-seasonalized outcomes
gen `y'd=`y' if month==1
forvalues i = 2/12 {
replace `y'd = `y' - _b[`i'.month] if month==`i'
		}


*first difference
gen d1_`y'`t'=d.`y'`t'

keep distt post d1_* inter month year 	

keep if dist>=-70 & dist<=70


*creating two time series for months before and after the reform
reshape wide d1_`y'`t', i( year month distt) j(post)


egen d1_`y'`t'_t=rowtotal(d1_`y'`t'0 d1_`y'`t'1) 

gen post=(distt>=0)

*locals for text in graph
gen one=1
gen d1_`y'`t'_t_t=d1_`y'`t'_t if distt==0
egen d1_`y'`t'_t_t_t=sum(d1_`y'`t'_t_t), by(one)
gen random`y'`t'=(d1_`y'`t'_t>d1_`y'`t'_t_t_t)
sum random`y'`t'
scalar random_`y'`t'_t=string(r(mean), "%05.3f")


*value for reform week
sum d1_`y'`t'1 if distt==0 
scalar mean_`y'`t'=r(mean)
scalar mean_`y'`t'_t=string(r(mean), "%05.3f")

*storing values for graphs and t-tests
sum d1_`y'`t'1 if distt>=1
scalar mpost_`y'`t'_t=string(r(mean), "%05.3f")

sum d1_`y'`t'1 if distt>=1
scalar mpost_t_`y'`t'1=r(mean)

sum d1_`y'`t'0 
scalar mpre_`y'`t'_t=string(r(mean), "%05.3f")

ttest d1_`y'`t'0 ==`=scalar(mean_`y'`t')'
scalar ttest1_`y'`t'_t=string(r(p), "%05.3f")

ttest d1_`y'`t'_t if distt!=0, by(post ) 
scalar ttest2_`y'`t'_t=string(r(p), "%05.3f")

sum d1_`y'`t'_t if distt!=0
scalar all_`y'`t'_t=string(r(mean), "%05.3f")

replace d1_`y'`t'_t=. if distt==0

ttest d1_`y'`t'_t==`=scalar(mean_`y'`t')' 
scalar ttest3_`y'`t'_t=string(r(p), "%05.3f")

*histograms
twoway (histogram d1_`y'`t'0, /*bin(6)*/gap(35) fcolor(orange%29) lcolor(orange)) (histogram d1_`y'`t'1 if distt>0, /*bin(6)*/gap(35) fcolor(navy%30) lcolor(navy)) (histogram d1_`y'`t'1, bin(6) gap(35) fcolor(none) lcolor(none)), xline(`=scalar(mean_`y'`t')', lwidth(medthick) lpattern(solid) lcolor(red)) legend(order(1 "Pre-Reform" 2 "Post-Reform")) scale(1.2) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(fcolor(white) ifcolor(white)) ///
note("Mean Pre Reform (`=scalar(mpre_`y'`t'_t)') vs Mean Post Reform (`=scalar(mpost_`y'`t'_t)'): ttest p-value (`=scalar(ttest2_`y'`t'_t)')" "Week of Introduction (`=scalar(mean_`y'`t'_t)') vs Mean All Other Weeks (`=scalar(all_`y'`t'_t)'): ttest p-value (`=scalar(ttest3_`y'`t'_t)')" "Mean Pre Reform (`=scalar(mpre_`y'`t'_t)') vs Week of Introduction (`=scalar(mean_`y'`t'_t)'): ttest p-value (`=scalar(ttest1_`y'`t'_t)')" "Randomization Inference p-value: (`=scalar(random_`y'`t'_t)')", span)

graph export "hist_1dtdif_`y'`t'_`week'.pdf", replace	

}
}
}
