********************************************************
* WEEKLY RD
*******************************************************
use "$datadir\card_transaction_weekly_rd.dta", clear

	gen distt=week_since_reform 
	gen post=(distt>=0)
	gen inter=distt*post 
	
	gen running=(distt-0)
	rename log_tot_sales lnsales
	rename  log_count_trans lntrans
	
		foreach y in lnsales lntrans {
		foreach P in 1 2 3 { 
		display `y' `P'
		rdrobust `y' running, c(0) p(`P') h(80) covs(month)
		local mean_`y'`P'a=string(e(tau_cl), "%15.3fc")
		local se_`y'`P'a=string(e(se_tau_cl), "%15.3fc")
		gen bleft_`y'_`P'a=e(h_l)
		sum bleft_`y'_`P'a
		local hl_`y'_`P'a=string(r(mean), "%15.0fc")
		gen bright_`y'_`P'a=e(h_r)
		sum bright_`y'_`P'a
		local hr_`y'_`P'a=string(r(mean), "%15.0fc")
		}
		}
	
********************************************************
* BIWEEKLY RD
*******************************************************

use "$datadir\card_transaction_biweekly_rd.dta", clear

	gen post=(distt>=0)
	gen inter=distt*post 

	rename log_tot_sales lnsales
	rename  log_count_trans lntrans
	
	gen running=(distt-0)
	
		foreach y in lnsales lntrans {
		foreach P in 1 2 3 { 
		display `y' `P'
		rdrobust `y' running, c(0) p(`P') h(45)  covs(month biweek)
		local mean_`y'`P'b=string(e(tau_cl), "%15.3fc")
		local se_`y'`P'b=string(e(se_tau_cl), "%15.3fc")
		gen bleft_`y'_`P'b=e(h_l)
		sum bleft_`y'_`P'b
		local hl_`y'_`P'b=string(r(mean), "%15.0fc")
		gen bright_`y'_`P'b=e(h_r)
		sum bright_`y'_`P'b
		local hr_`y'_`P'b=string(r(mean), "%15.0fc")

		}
		}

********************************************************
* DAILY RD
*******************************************************

use "$datadir\card_transaction_daily_rd.dta", clear
gen sample2015=(year<=2015 | (year==2016 & month<=6))
keep if sample2015==1

	gen post=(distt>=0)
	gen inter=distt*post 
	
	gen running=(distt-0)
	rename log_tot_sales lnsales
	rename  log_count_trans lntrans

		foreach y in lnsales lntrans {
		foreach P in 1 2 3 { 
		display `y' `P'
		rdrobust `y' running, c(0) p(`P') h(500) covs(month dow)
		local mean_`y'`P'c=string(e(tau_cl), "%15.3fc")
		local se_`y'`P'c=string(e(se_tau_cl), "%15.3fc")
		gen bleft_`y'_`P'c=e(h_l)
		sum bleft_`y'_`P'c
		local hl_`y'_`P'c=string(r(mean), "%15.0fc")
		gen bright_`y'_`P'c=e(h_r)
		sum bright_`y'_`P'c
		local hr_`y'_`P'c=string(r(mean), "%15.0fc")
		}
		}

		
texdoc init "rd_running_aggregation.tex", force replace
tex	\begin{tabular}{lcccccc} \toprule
tex \midrule
tex \midrule 
tex & (1) & (2) & (3) & (4) & (5) & (6) \\
tex \midrule 
tex \multicolumn{7}{l}{A: Log Total Number of Transactions} \\
tex Point Estimate & `mean_lntrans1a' & `mean_lntrans2a' & `mean_lntrans1b' & `mean_lntrans2b' & `mean_lntrans1c' & `mean_lntrans2c' \\
tex SE & (`se_lntrans1a') & (`se_lntrans2a') & (`se_lntrans1b') & (`se_lntrans2b') & (`se_lntrans1c') & (`se_lntrans2c') \\
tex \midrule
tex \multicolumn{7}{l}{B: Log Volume of Card Transactions} \\
tex Point Estimate & `mean_lnsales1a' & `mean_lnsales2a' & `mean_lnsales1b' & `mean_lnsales2b' & `mean_lnsales1c' & `mean_lnsales2c' \\
tex SE & (`se_lnsales1a') & (`se_lnsales2a') & (`se_lnsales1b') & (`se_lnsales2b') & (`se_lnsales1c') & (`se_lnsales2c') \\
tex \midrule 
tex Frecuency & Weekly & Weekly & Bi-weekly & Bi-weekly & Daily & Daily \\
tex Model Fit & Linear & Quadratic & Linear & Quadratic & Linear & Quadratic \\ 
tex \midrule 
tex \midrule
tex \end{tabular}
texdoc close 


