		use "${datadir}/data_ub_11.dta", clear

		keep if retail==1
		
		gen sector4=floor(codgiro/10)
		
		merge m:1 sector4 using "${datadir}/treat_sector_n.dta", gen(merge_sector) 
	
		keep if merge_sector==3
		keep if treat3==0 
		drop merge_sector
		
		keep ide sector4 
		
		duplicates drop ide, force 

		rename ide id_afi 
		
		tempfile treat_low_sector
		sa `treat_low_sector'
		
*appending firm day data of all years
use "${datadir}/daily_firm_pos_2011.dta", replace

foreach y in 2012 2013 2014 2015 2016 {
append using "${datadir}/daily_firm_pos_`y'.dta"
}

merge m:1 id_afi using `treat_low_sector' 
keep if _merge==3 
drop _merge

*setting up week with respect to introduction of rebates
gen edate=mdy(month, day, year)
gen reform_day=edate if year==2014 & month==8 & day==1
gen one=1
egen reform_dayt=mean(reform_day), by(one)
drop reform_day
gen day_dist=edate-reform_dayt
replace day_dist=day_dist/7
gen week=floor(day_dist)

*collapse at the week-firm-pos level
collapse (sum) tot_venta count (mean) month year, by(week id_afi nro_pos)

*count of unique pos
gen count_pos_total=1

*collapse at the week-firm-level
collapse (sum) tot_venta count count_pos_total (mean) month year, by(week id_afi)

*count of unique firms
gen count_firms_total=1

*collapse at the week level
collapse (sum) tot_venta count count_pos_total count_firms_total (min) month year, by(week)

gen week_since_reform=week


* weeks over the span of two different months, take the value of the first month
replace month=floor(month)
replace year=floor(year)

*rename and transform into millions
rename count count_trans  
rename tot_venta tot_sales

replace count_trans=count_trans/1000000
replace tot_sales=tot_sales/1000000 

*log of outcomes
foreach y in tot_sales count_trans count_pos_total count_firms_total {
	gen log_`y'=ln(`y')
}

*dropping everything after june 2016
drop if (year==2016 & month>6)

save "$datadir\card_transaction_weekly_rd_low.dta", replace


foreach nweek in  80  {
foreach y in log_count_pos_total log_count_firms_total{
foreach pgraph in 1   {
foreach a in main {

use "$datadir\card_transaction_weekly_rd_low.dta", clear

********************************************************
*  MAIN VARIABLES
*******************************************************
*rename count_pos count_pos_c
	gen distt=week_since_reform 
	gen post=(distt>=0)
	gen inter=distt*post 
	sum week if year==2013 & month==1 
	local new_week=r(min)
	gen break_2013=(week_since_reform>=`new_week')



********************************************************
* Running RD regression
*******************************************************


		* RD Regression with 3 levels of polynomial using the outcome var using rdrobust package to get bias corrected confidence intervals
		 *Run regression and save results
		gen running=(distt-0)
		foreach P in 1 2 3 { 
		rdrobust `y' running, c(0) p(`P') h(`nweek') covs(month)
		glo mean_`y'`P'=e(tau_cl)
		glo se_`y'`P'=e(se_tau_cl)
		glo mean_`y'`P': di %3.2f ${mean_`y'`P'}
		glo se_`y'`P': di %3.2f ${se_`y'`P'}
		}
		
********************************************************
* De-season outcome for scatter plot
*******************************************************
		foreach P in 1 2 3 { 

		local spec1_main c.distt##i.post i.month, r  
		local spec2_main c.distt##c.distt##i.post##i.post i.month, r
		local spec3_main c.distt##c.distt##c.distt##i.post##i.post##i.post i.month, r
		local spec1_jan13 c.distt##i.post c.distt##i.break_2013  i.month, r  
		local spec2_jan13 c.distt##c.distt##i.post##i.post c.distt##c.distt##i.break_2013##i.break_2013 i.month, r
		local spec3_jan13 c.distt##c.distt##c.distt##i.post##i.post##i.post c.distt##c.distt##c.distt##i.break_2013##i.break_2013##i.break_2013 i.month, r

		reg `y' `spec`P'_`a''
		
		* Deseason weekly data by  month and day of the week
			gen `y'_`P'd = `y' if month==1
			forvalues i = 2/12 {
			replace `y'_`P'd = `y' - _b[`i'.month] if month==`i'
			}
		}
********************************************************
* AGGREGATED SCATTER PLOT
*******************************************************
		* creating bins
		egen ranking=rank(week_since_reform)
		egen group_b=cut(ranking) if week_since_reform<0 & week_since_reform>=-`nweek', group(10)
		egen group_a=cut(ranking) if week_since_reform>=0 & week_since_reform<=`nweek', group(10)

		replace group_a=10+group_a
		gen group=group_a if group_a!=. 
		replace group=group_b if group_a==. & group_b!=.
	
		*aggregating variables 
		foreach P in 1 2 3 { 
		*  binned scatter
		egen b`y'_`P'd=mean(`y'_`P'd), by(group)
		}
	
		egen bweek_since_reform=mean(week_since_reform), by(group)

********************************************************
* GRAPHS
******************************************************
		
		* Creating text references for graph
		foreach P in 1 2 3 { 
		sum `y'_`P'd if week_since_reform>=-`nweek' & week_since_reform<=`nweek', d
		glo m`y'_`P'd = r(p90)
		}
		
		sum week_since_reform if week_since_reform>=-`nweek' & week_since_reform<=`nweek', d
		glo xposi=r(min)
		glo textx=5*(${xposi}/5)
		glo textx: di %3.2f ${textx}
		scalar rmin=round(r(min),0.1)
		scalar rmax=round(r(max),0.1)
		
			*Bin Collapsed
			collapse (mean) `y'_1d `y'_2d `y'_3d `y' week_since_reform , by(group)

			*position of text
			foreach p in 1 2 3 {
			gen coeff_`y'`p'=${mean_`y'`p'}
			sum `y'_`p'd if group==9
			gen lev_`y'_`p'=r(mean)
			gen rev_`y'_`p'=(coeff_`y'`p'/lev_`y'_`p')*100
			sum rev_`y'_`p'
			glo del_`y'_`p'=r(mean)
			glo del_`y'_`p': di %3.2f  ${del_`y'_`p'}
			}

			
			sum `y'_`pgraph'd if week_since_reform>=-`nweek' & week_since_reform<=`nweek', d
			glo yt`y'_`pgraph'd = r(p90)
			sum `y'_`pgraph'd if week_since_reform>=-`nweek' & week_since_reform<=`nweek', d
			glo yt`y'_`pgraph'dd = r(p50)
			glo xtext=1
			
			*labels for y axis
				local l_log_tot_sales ="Log Volume of Card Transactions"
				local l_log_count_trans ="Log Number of Card Transactions"
				local l_log_count_pos_total ="Log Number of POS"
				local l_log_count_firms_total ="Log Number of Firms with POS"
				

twoway fpfitci `y'_`pgraph'd week_since_reform if week_since_reform<0 & week_since_reform>=-`nweek', level(95) estopts(degree(`pgraph')) lcolor(blue) acolor(gs12) alcolor(gs12) || ///
fpfitci `y'_`pgraph'd week_since_reform if week_since_reform>=0 & week_since_reform<=`nweek', level(95) estopts(degree(`pgraph')) lcolor(blue) acolor(gs12) alcolor(gs12) || ///
scatter `y'_`pgraph'd week_since_reform if week_since_reform>=-`nweek' & week_since_reform<=`nweek' , xline(0, lcolor(black)) xline(54, lpattern(dash_dot) lcolor(black%50)) color(red) ///
xscale(r(`=scalar(rmin)' `=scalar(rmax)')) xlabel(-`nweek'(20)`nweek') ///
legend(off) graphregion(color(white)) bgcolor(white) xtitle("Weeks to reform") ytitle(`l_`y'') ///
text(${yt`y'_`pgraph'd} ${textx} "RD (Linear): ${mean_`y'1} (${se_`y'1})" "RD (Quadratic): ${mean_`y'2} (${se_`y'2})", place(e) size(medlarge)) 			///
text(${yt`y'_`pgraph'dd} ${xtext} "{&lArr} August 2014 VAT Rebates" "of up to 4 ppt Enter Into Effect", place(e)) 

graph export "RDrobust_`y'_`nweek'_deseason_bc`pgraph'_2015_low.pdf", replace
}
}
}
}


*appending firm day data of all years
use "${datadir}/daily_firm_pos_2011.dta", replace

foreach y in 2012 2013 2014 2015 2016 {
append using "${datadir}/daily_firm_pos_`y'.dta"
}

merge m:1 id_afi using `treat_low_sector' 
keep if _merge==3 
drop _merge

*collapse at the week-firm-pos level
collapse (sum) tot_venta count, by(month year id_afi nro_pos)

*collapse at the firm-month-pos level
collapse (sum) tot_venta count, by(month year id_afi nro_pos)

*count unique pos
gen count_pos=1

*collapse at the firm-month level
collapse (sum) tot_venta count count_pos, by(month year id_afi)

*count of firms 
gen count_firms=1 

*collpase at the month level
collapse (sum) tot_venta count count_pos count_firms, by(month year)

*rename and transform into millions
rename count countn  
rename tot_venta tot_sales

replace countn=countn/1000000
replace tot_sales=tot_sales/1000000 


*log of outcomes
foreach var in count_firms count_pos countn tot_sales {
gen log_`var'=ln(`var')
}

*dropping everything after june 2016
drop if (year==2016 & month>=6)

save "$datadir\card_transaction_monthly_rd_low.dta", replace

*-------------------------------------------------------------------------------
*1 Loading Monthly DATA
*-------------------------------------------------------------------------------
foreach a in main {

use "$datadir\card_transaction_monthly_rd_low.dta", clear
drop if year==2016
*replace values for April 2014 with average of March and May 2014
gen id_average=1 if (month==3 & year==2014) |(month==5 & year==2014)
gen one_d=1


foreach var in count_firms count_pos countn tot_sales {
		egen average_`var'=mean(`var'), by(id_average)
		replace average_`var'=. if id_average==.
		egen av_`var'=mean(average_`var'), by(one_d)
		replace `var'=av_`var' if month==4 & year==2014
		}

*log of outcomes
foreach var in count_firms count_pos countn tot_sales {
gen ln_`var'=ln(`var')
}

*months relative to reform
sort year month 
gen n=_n
sum n if year==2014 & month==8
gen reform=r(mean)
gen distt=n-reform
gen post=(distt>=0)
sum distt if year==2013 & month==1
local break_dist=r(mean)
gen break_2013=(distt>=`break_dist')

*deseason outcomes
foreach var in count_firms count_pos countn tot_sales {
foreach P in 1 2 { 

		local spec1_main c.distt##i.post  i.month, r  
		local spec2_main c.distt##c.distt##i.post##i.post i.month, r	
		local spec1_jan13 c.distt##i.post c.distt##i.break_2013  i.month, r  
		local spec2_jan13 c.distt##c.distt##i.post##i.post c.distt##c.distt##i.break_2013##i.break_2013 i.month, r			

			
reg ln_`var' `spec`P'_`a''


gen log_`var'_`P' = ln_`var' if month==1
forvalues i = 2/12 {
replace log_`var'_`P' = ln_`var' - _b[`i'.month] if month==`i'
		}
			
		}
rename ln_`var' log_`var'_0
		}

		
sort year month 
gen period=year*100+month
tostring period, gen(p)
gen d="01"
egen period_day=concat(p d)
gen p_day=date(period_day, "YMD")
format p_day %td
drop period
gen period=mofd(p_day)
format period %tm
tsset period, monthly

*log first difference
foreach var in count_firms count_pos countn tot_sales {
foreach P in 0 1 2 { 
gen d1log_`var'_`P'=d.log_`var'_`P'
}
}

*replace values for April 2014 with average of March and May 2014
foreach var in count_firms count_pos countn tot_sales {
foreach P in 0 1 2 { 
		egen average_`var'_`P'=mean(d1log_`var'_`P'), by(id_average)
		replace average_`var'_`P'=. if id_average==.
		egen av_`var'_`P'=mean(average_`var'_`P'), by(one_d)
		replace d1log_`var'_`P'=av_`var'_`P' if month==4 & year==2014

}
}


keep month year d1log_* distt post n reform

*creating two time series for months before and after the reform
reshape wide d1log_count_firms_1 d1log_count_pos_1 d1log_countn_1 d1log_tot_sales_1, i( year month n reform distt) j(post)

	
foreach var in count_firms count_pos countn tot_sales  {
egen d1log_`var'_t=rowtotal(d1log_`var'_11 d1log_`var'_10) 
}
gen post=(dist>=0)

gen one=1

gen seq=_n
tab seq, gen(placebo)

*variable to capture the coefficient
foreach var in count_firms count_pos countn tot_sales  {
gen pvalue_`var'=.
}

foreach var in count_firms count_pos countn tot_sales  {
forvalues i = 1(1)60 {
reg d1log_`var'_t placebo`i'
replace pvalue_`var'=_b[placebo`i'] if seq==`i'
}
}

*locals for text in graph
foreach var in count_firms count_pos countn tot_sales  {
sum pvalue_`var' if distt==0
local value_`var'=r(mean)
gen random_`var'=pvalue_`var'>=`value_`var''
replace random_`var'=. if distt==0
sum random_`var'
scalar random_`var'=r(mean)
scalar random_`var'=string(r(mean), "%05.3f")
}


foreach var in tot_sales countn count_firms count_pos  {
	*value for reform month
sum d1log_`var'_11 if year==2014 & month==8 
scalar mean_`var'=r(mean)
scalar mean_`var'_t=string(r(mean), "%05.3f")

*storing values for graphs and t-tests
sum d1log_`var'_11 if dist>=1
scalar meanpost_`var'_t=string(r(mean), "%05.3f")

sum d1log_`var'_11 if dist>=1
scalar meanpost_t_`var'=r(mean)

sum d1log_`var'_10 
scalar meanpre_`var'_t=string(r(mean), "%05.3f")

ttest d1log_`var'_10==`=scalar(mean_`var')'
scalar ttest1_`var'_t=string(r(p), "%05.3f")

ttest d1log_`var'_t if dist!=0, by(post ) 
scalar ttest2_`var'_t=string(r(p), "%05.3f")

sum d1log_`var'_t if dist!=0
scalar all_`var'_t=string(r(mean), "%05.3f")

replace d1log_`var'_t=. if dist==0

ttest d1log_`var'_t==`=scalar(mean_`var')' 
scalar ttest3_`var'_t=string(r(p), "%05.3f")

	global ly_count_firms=42
	global ly_count_pos=12 
	global ly_countn=10 
	global ly_tot_sales=10 
	global ly_rtaxsale=10 
	global ly_rnetliab=10
	
	global ly2_count_firms=38
	global ly2_count_pos=10 
	global ly2_countn=8 
	global ly2_tot_sales=8 
	global ly2_rtaxsale=8 
	global ly2_rnetliab=8
	
	global lx_count_firms=.013
	global lx_count_pos=.06 
	global lx_countn=.25 
	global lx_tot_sales=.13
	global lx_rtaxsale=.1 
	global lx_rnetliab=.1	
	
	global lx2_count_firms=.015
	global lx2_count_pos=.067
	global lx2_countn=.27 
	global lx2_tot_sales=.15 
	global lx2_rtaxsale=.12 
	global lx2_rnetliab=.12
	
	local a_count_firms="{&lArr} Reform-Month"
	local a_count_pos="{&lArr} Reform-Month"
	local a_countn="Reform-Month {&rArr}"
	local a_tot_sales="Reform-Month {&rArr}"
	
	*histograms
twoway (histogram d1log_`var'_10, /*bin(6)*/gap(35) fcolor(orange%29) lcolor(orange)) (histogram d1log_`var'_11 if distt>0, /*bin(6)*/gap(35) fcolor(navy%30) lcolor(navy)) (histogram d1log_`var'_11, bin(6) gap(35) fcolor(none) lcolor(none)), xline(`=scalar(mean_`var')', lwidth(medthick) lpattern(solid) lcolor(red)) legend(order(1 "Pre-Reform" 2 "Post-Reform")) scale(1.2) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(fcolor(white) ifcolor(white)) ///
note("Mean Pre Reform (`=scalar(meanpre_`var'_t)') vs Mean Post Reform (`=scalar(meanpost_`var'_t)'): ttest p-value (`=scalar(ttest2_`var'_t)')" "Month of Introduction (`=scalar(mean_`var'_t)') vs Mean All Other Months (`=scalar(all_`var'_t)'): ttest p-value (`=scalar(ttest3_`var'_t)')" "Mean Pre Reform (`=scalar(meanpre_`var'_t)') vs Month of Introduction (`=scalar(mean_`var'_t)'): ttest p-value (`=scalar(ttest1_`var'_t)')" "Randomization Inference p-value: (`=scalar(random_`var')')", span) ///
text(${ly_`var'} ${lx_`var'} "`a_`var''" , place(e)) ///
text(${ly2_`var'} ${lx2_`var'} "Growth Rate", place(e))
graph export "hist_1dtdif_`var'_all_random_`a'_low.pdf", replace	
}
}