*LOADING WEEKLY DATA 
use "$datadir\card_transaction_weekly_rd.dta", clear

********************************************************
*  MAIN VARIABLES
*******************************************************
*rename count_pos count_pos_c
	gen distt=week_since_reform 
	gen post=(distt>=0)
	gen inter=distt*post 
	
********************************************************
* Running RD regression
*******************************************************
		gen running=(distt-0)
		foreach P in 1 2 { 
		foreach y in log_tot_sales log_count_trans {
		foreach nweek in 80 70 52 17 39 15 18 {
		rdrobust `y' running, c(0) p(`P') h(`nweek') covs(month)
		local mean_`y'`P'_`nweek'=string(e(tau_cl), "%15.3fc")
		local se_`y'`P'_`nweek'=string(e(se_tau_cl), "%15.3fc")
		}
		}
		}
********************************************************
* De-season outcome for scatter plot
*******************************************************
		local spec1 c.distt##i.post i.month, r  
		local spec2 c.distt##c.distt##i.post##i.post i.month, r
		local spec3 c.distt##c.distt##c.distt##i.post##i.post##i.post i.month, r

		foreach P in 1 2 { 
		foreach y in log_tot_sales log_count_trans {
		    
		reg `y' `spec`P''
		
		* Deseason weekly data by  month and day of the week
			gen `y'_`P'd = `y' if month==1
			forvalues i = 2/12 {
			replace `y'_`P'd = `y' - _b[`i'.month] if month==`i'
			}
			}
			}
********************************************************
* 2 Step Estimation
*******************************************************

		foreach P in 1 2 { 
		foreach y in log_tot_sales log_count_trans {
		foreach nweek in 80 70 52 17 39 15 18 {
		rdrobust `y'_`P'd running, c(0) p(`P') h(`nweek')
		local mean_`y'`P'_`nweek'd=string(e(tau_cl), "%15.3fc")
		local se_`y'`P'_`nweek'd=string(e(se_tau_cl), "%15.3fc")
		}
		}
		}
		
texdoc init "RD_steps_comparisson.tex", force replace
tex						\begin{tabular}{llcc}
tex							\toprule 
tex							\hline
tex & &  A. One-Step & B. Two-Step  \\
tex & &  Estimation & Estimation  \\
tex							\hline
tex \multicolumn{4}{c}{I. Number of Card Transactions} \\
tex							\hline
tex \multirow{4}{*}{Linear} & 80 Weeks BW & `mean_log_count_trans1_80' & `mean_log_count_trans1_80d' \\
tex & & (`se_log_count_trans1_80') & (`se_log_count_trans1_80d') \\
tex & Optimal BW & `mean_log_count_trans1_17' & `mean_log_count_trans1_17d' \\
tex & & (`se_log_count_trans1_17') & (`se_log_count_trans1_17d') \\
tex \multirow{4}{*}{Quadratic} & 80 Weeks BW & `mean_log_count_trans2_80' & `mean_log_count_trans2_80d' \\
tex & & (`se_log_count_trans2_80') & (`se_log_count_trans2_80d') \\
tex & Optimal BW & `mean_log_count_trans2_39' & `mean_log_count_trans2_39d' \\
tex & & (`se_log_count_trans2_39') & (`se_log_count_trans2_39d') \\
tex							\hline
tex \multicolumn{4}{c}{II. Volume of Card Transactions} \\
tex							\hline
tex \multirow{4}{*}{Linear} & 80 Weeks BW & `mean_log_tot_sales1_80' & `mean_log_tot_sales1_80d' \\
tex & & (`se_log_tot_sales1_80') & (`se_log_tot_sales1_80d') \\
tex & Optimal BW & `mean_log_tot_sales1_15' & `mean_log_tot_sales1_15d' \\
tex & & (`se_log_tot_sales1_15') & (`se_log_tot_sales1_15d') \\
tex \multirow{4}{*}{Quadratic} & 80 Weeks BW & `mean_log_tot_sales2_80' & `mean_log_tot_sales2_80d' \\
tex & & (`se_log_tot_sales2_80') & (`se_log_tot_sales2_80d') \\
tex & Optimal BW & `mean_log_tot_sales2_18' & `mean_log_tot_sales2_18d' \\
tex & & (`se_log_tot_sales2_18') & (`se_log_tot_sales2_18d') \\
tex				\hline
tex				\end{tabular}
texdoc close