*-------------------------------------------------------------------------------
*1 Loading Monthly DATA
*-------------------------------------------------------------------------------
clear all
use "$datadir\card_transaction_monthly_rd.dta", clear

sort year month 
gen period=year*100+month
tostring period, gen(p)
gen d="01"
egen period_day=concat(p d)
gen p_day=date(period_day, "YMD")
format p_day %td
drop period
gen period=mofd(p_day)
format period %tm
tsset period, monthly


*replacing atypical values for transaction amount and count 
gen av_id=(year==2014 & (month==4 | month==5))
foreach var in  log_tot_sales  log_countn  {
	egen av_`var'=mean(`var'), by(av_id)
	gen `var'_t=`var' if av_id==0
	replace `var'_t=av_`var' if av_id==1
}

*-------------------------------------------------------------------------------
*2 Raw Trends
*-------------------------------------------------------------------------------
*position of text in graph 	
foreach var in count_firms count_pos countn_t tot_sales_t countn tot_sales  {
    sum log_`var', d
			local ylog_`var' = r(p25)
}


*labels for graph Y axis
local l_tot_sales_t ="Log Volume of Card Transactions"
local l_countn_t ="Log Number of Card Transactions"
local l_tot_sales ="Log Volume of Card Transactions"
local l_countn ="Log Number of Card Transactions"
local l_count_pos ="Log Number of POS"
local l_count_firms ="Log Number of Firms with POS"

*Raw trends graphs
*countn_t and tot_sales_t are the transformed outcomes  
foreach var in countn_t tot_sales_t count_firms count_pos countn tot_sales  {
twoway (connected log_`var' period, mcolor(navy%60) msymbol(circle_hollow) lcolor(navy%60) lpattern(shortdash)), xtitle(Year-Month) ytitle(`l_`var'') tline(2011m12 2012m12 2013m12 2014m12 2015m12, lpattern(shortdash) lcolor(grey*0.2)) /*tline(2013m1, lpattern(solid) lcolor(blue%30))*/ tline(2014m8, lpattern(solid) lcolor(red)) scale(1.2) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) tlabel(2011m12(12)2015m12) text(`ylog_`var'' 656 "{&lArr} August 2014" "VAT Rebates of up to" "4 ppt Enter Into Effect", place(e)) 
graph export "trend_log_`var'_n02016.pdf", replace
}

*-------------------------------------------------------------------------------
*3 De-seasonalized Trends
*-------------------------------------------------------------------------------

*setting variables for de-seasonalized regression
sort year month
gen n=_n
*months to reform
sum n if year==2014 & month==8
gen reform=r(mean)
*post var
gen distt=n-reform
gen post=(distt>=0)


*de-seasonalized regression
foreach var in count_firms count_pos countn tot_sales countn_t tot_sales_t  {
preserve 

*outliers
if "`var'"=="count_pos" | "`var'"=="count_firms" {
drop if (year==2014 & month==4) | (year==2015 & month==12) 
}

*linear
reg log_`var' c.distt##i.post  i.month,r
* Deseason 
gen log_`var'_d1 = log_`var' if month==1
forvalues i = 2/12 {
replace log_`var'_d1 = log_`var' - _b[`i'.month] if month==`i'
}
		


*local for text position
    sum log_`var'_d1, d
			local ylog_`var'_d1 =string(r(p25), "%3.2fc")



*transformed trends  
twoway (connected log_`var'_d1 period, mcolor(navy%60) msymbol(circle_hollow) ///
lcolor(navy%60) lpattern(shortdash)), xtitle(Year-Month) ytitle(`l_`var'') ///
tline(2011m12 2012m12 2013m12 2014m12 2015m12, lpattern(shortdash) lcolor(grey*0.2)) ///
/*tline(2013m1, lpattern(solid) lcolor(blue%30))*/ tline(2014m8, lpattern(solid) lcolor(red)) ///
scale(1.2) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) ///
plotregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) ///
tlabel(2011m12(12)2015m12)  
graph export "trend_d_`var'_d1_n02016.pdf", replace
restore 
}


