use "${datadir}\vat_returns_month_long.dta", clear 
keep if year>=2011 & year<=2015 
			
		foreach v in rtaxsale rtaxpur rnetliab	{
			winsor2 `v', replace cuts(1 95) by(year month) 
		}
		
collapse (mean) rtaxsale rtaxpur rnetliab, by(year month)

foreach v in rtaxsale rnetliab {
	gen log_`v'=log(`v')
}

sort year month 
gen period=year*100+month
tostring period, gen(p)
gen d="01"
egen period_day=concat(p d)
gen p_day=date(period_day, "YMD")
format p_day %td
drop period
gen period=mofd(p_day)
format period %tm
tsset period, monthly

				local l_rtaxsale ="Log Output VAT"
				local l_rnetliab ="Log Net VAT Liability" 
				local ylab_rtaxsale="ylabel(11.75(.25)12.25)"
				local ylab_rnetliab="ylabel(10.25(.25)11.25)"
				local yt_rtaxsale 11.9
				local yt_rnetliab 10.6
				
foreach var in rtaxsale rnetliab {
twoway (connected log_`var' period, mcolor(navy%60) msymbol(circle_hollow) lcolor(navy%60) lpattern(shortdash)), xtitle(Year-Month) ytitle(`l_`var'') tline(2011m12 2012m12 2013m12 2014m12 2015m12, lpattern(shortdash) lcolor(grey*0.2)) /*tline(2013m1, lpattern(solid) lcolor(blue%30))*/ tline(2014m8, lpattern(solid) lcolor(red)) `ylab_`var'' scale(1.08) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) tlabel(2011m12(12)2015m12) text(`yt_`var'' 655 "{&lArr} August 2014" "VAT Rebates of up to" "4 ppt Enter Into Effect", place(e)) 
graph export "trend_log_`var'_n02016.pdf", replace
}


*setting variables for de-seasonalized regression
sort year month
gen n=_n
*months to reform
sum n if year==2014 & month==8
gen reform=r(mean)
*post var
gen distt=n-reform
gen post=(distt>=0)


*de-seasonalized regression
foreach var in rtaxsale rnetliab {
*linear
reg log_`var' c.distt##i.post  i.month,r
* Deseason 
gen log_`var'_d1 = log_`var' if month==1
forvalues i = 2/12 {
replace log_`var'_d1 = log_`var' - _b[`i'.month] if month==`i'
}
}			


*local for text position
foreach var in rtaxsale rnetliab {
    sum log_`var'_d1, d
			local ylog_`var'_d1 =string(r(p25), "%3.2fc")
}

				local l_rtaxsale ="Log Output VAT"
				local l_rnetliab ="Log Net VAT Liability" 
				local ylab_rtaxsale="ylabel(11.75(.25)12.25)"
				local ylab_rnetliab="ylabel(10.25(.25)11.25)"
				
*transformed trends  
foreach var in rtaxsale rnetliab  {
twoway (connected log_`var'_d1 period, mcolor(navy%60) msymbol(circle_hollow) lcolor(navy%60) lpattern(shortdash)), xtitle(Year-Month) ytitle(`l_`var'') tline(2011m12 2012m12 2013m12 2014m12 2015m12, lpattern(shortdash) lcolor(grey*0.2)) /*tline(2013m1, lpattern(solid) lcolor(blue%30))*/ tline(2014m8, lpattern(solid) lcolor(red)) `ylab_`var'' scale(1.2) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) tlabel(2011m12(12)2015m12)  
graph export "trend_d_`var'_d1_n02016.pdf", replace
}

*****************************************
use "${datadir}\vat_returns_month_long.dta", clear 
keep if year>=2011 & year<=2015 

gen periodo=year*100+month
tostring periodo, gen(p)
encode p, gen(month_p)
numlabel, add
tab month_p

sum month_p if month==8 & year==2014
gen month_d=month_p-`r(mean)' 
drop p month_p 
	gen distt=month_d 
	gen post=(distt>=0)
	gen inter=distt*post 
	
collapse (mean) rtaxsale rtaxpur rnetliab, by(year month month_d)

	gen distt=month_d 
	gen post=(distt>=0)
	gen inter=distt*post 

	
	foreach y in rtaxsale rnetliab {
		gen log_`y'=log(1+`y')
		gen lev_`y'=`y'
		drop `y'
		rename log_`y' `y'
	}
	

********************************************************
* Same polynomial in both sides of the threshold
*******************************************************
		foreach P in 1 2 3 { 
		foreach y in rtaxsale rnetliab  {

 local spec_same1 c.distt i.post  i.month if  month_d>=-20 & month_d<=16, r 
 local spec_same2 c.distt##c.distt i.post  i.month if month_d>=-20 & month_d<=16, r 
 local spec_same3 c.distt##c.dist#c.distt i.post  i.month if month_d>=-20 & month_d<=16, r 
 
 		reg `y' `spec_same`P''
		
		foreach x in se b {
		glo `x'`y'pst`P'=_`x'[1.post]
		glo `x'`y'pst`P': di %3.2f  ${`x'`y'pst`P'}
		}
		}
		}
********************************************************
* De-season outcome for scatter plot
*******************************************************
*since rdrobust dont let us save coefficients from covariates, I am running the normal OLS

		foreach P in 1 2 3 { 
		foreach y in rtaxsale rnetliab {

		local spec1 c.distt##i.post  i.month, r  
		local spec2 c.distt##c.distt##i.post##i.post i.month, r
		local spec3 c.distt##c.distt##c.distt##i.post##i.post##i.post i.month, r

		reg `y' `spec`P''
		
		* Deseason weekly data by  month and day of the week
			gen `y'_`P'd = `y' if month==1
			forvalues i = 2/12 {
			replace `y'_`P'd = `y' - _b[`i'.month] if month==`i'
			}
		
			}
			}
********************************************************
* AGGREGATED SCATTER PLOT
*******************************************************
		* creating bins
		egen ranking=rank(month_d)
		egen group_b=cut(ranking) if month_d<0 & month_d>=-20, group(10)
		egen group_a=cut(ranking) if month_d>=0 & month_d<=16, group(10)

		replace group_a=10+group_a
		gen group=group_a if group_a!=. 
		replace group=group_b if group_a==. & group_b!=.
	

********************************************************
* GRAPHS
******************************************************
		
		* Creating text references for graph

		sum month_d if month_d>=-20 & month_d<=16, d
		glo xposi=r(min)
		glo textx=4*(${xposi}/5)
		glo textx: di %3.2f ${textx}
		scalar rmin=round(r(min),0.1)
		scalar rmax=round(r(max),0.1)
		
	
		local l_tot_sales ="Volume of Card Transactions"
		local l_count_trans="Number of Card Transactions"
		
		
		
			collapse (mean) rtaxsale_1d rnetliab_1d rtaxsale_2d rnetliab_2d rtaxsale_3d rnetliab_3d month_d, by(group)
			drop if group==. 
			
			foreach p in 1 2 3 {
			foreach y in rtaxsale rnetliab {
			gen coeff_`y'`p'=${b`y'pst`p'}
			sum `y'_`p'd if group==9
			gen lev_`y'_`p'=r(mean)
			gen rev_`y'_`p'=(coeff_`y'`p'/lev_`y'_`p')*100
			sum rev_`y'_`p'
			glo del_`y'_`p'=r(mean)
			glo del_`y'_`p': di %3.2f  ${del_`y'_`p'}
			}
			}
			
			local ylab_rtaxsale 12.5(0.25)13.25
			local ylab_rnetliab 11.5(0.25)12
			local ytext_rtaxsale 13
			local ytext_rnetliab 11.9
				
		foreach pgraph in  2 { 
		foreach y in rtaxsale rnetliab {

			sum `y'_`pgraph'd if month_d>=-20 & month_d<=16, d
			glo yt`y'_`pgraph'd = r(p99)
			
			twoway fpfitci `y'_`pgraph'd month_d if month_d<0 & month_d>=-20, ///
			level(95) estopts(degree(`pgraph')) lcolor(blue) acolor(gs12) alcolor(gs12) || ///
			fpfitci `y'_`pgraph'd month_d if month_d>=0 & month_d<=16, ///
			level(95) estopts(degree(`pgraph')) lcolor(blue) acolor(gs12) alcolor(gs12) || ///
			scatter `y'_`pgraph'd month_d if month_d>=-20 & month_d<=16 , ///
			xline(0, lcolor(black)) xline(12, lpattern(dash_dot) lcolor(black)) color(red) ///
			 xlabel(-20(2)16) ylabel(`ylab_`y'') ///
			legend(off) graphregion(color(white)) bgcolor(white) xtitle("Months to reform") ytitle(`l_`y'') ///
			text(`ytext_`y'' ${textx} "RD (Linear): ${b`y'pst1} (${se`y'pst1})" "RD (Quadratic): ${b`y'pst2} (${se`y'pst2})", place(e)) 
			graph export "RDrobust_m_log_`y'_16_deseason_bc`pgraph'.pdf", replace
	
			}
			}
			
