*-------------------------------------------------------------------------------
*1 Loading Monthly DATA
*-------------------------------------------------------------------------------
foreach a in $option_hist {

use "$datadir\card_transaction_monthly_rd.dta", clear
drop if year==2016
*replace values for April 2014 with average of March and May 2014
gen id_average=1 if (month==3 & year==2014) |(month==5 & year==2014)
gen one_d=1


foreach var in count_firms count_pos countn tot_sales {
		egen average_`var'=mean(`var'), by(id_average)
		replace average_`var'=. if id_average==.
		egen av_`var'=mean(average_`var'), by(one_d)
		replace `var'=av_`var' if month==4 & year==2014
		}

*log of outcomes
foreach var in count_firms count_pos countn tot_sales {
gen ln_`var'=ln(`var')
}

*months relative to reform
sort year month 
gen n=_n
sum n if year==2014 & month==8
gen reform=r(mean)
gen distt=n-reform
gen post=(distt>=0)
sum distt if year==2013 & month==1
local break_dist=r(mean)
gen break_2013=(distt>=`break_dist')

*deseason outcomes
foreach var in count_firms count_pos countn tot_sales {
foreach P in 1 2 { 

		local spec1_main c.distt##i.post  i.month, r  
		local spec2_main c.distt##c.distt##i.post##i.post i.month, r	
		local spec1_jan13 c.distt##i.post c.distt##i.break_2013  i.month, r  
		local spec2_jan13 c.distt##c.distt##i.post##i.post c.distt##c.distt##i.break_2013##i.break_2013 i.month, r			

			
reg ln_`var' `spec`P'_`a''


gen log_`var'_`P' = ln_`var' if month==1
forvalues i = 2/12 {
replace log_`var'_`P' = ln_`var' - _b[`i'.month] if month==`i'
		}
			
		}
rename ln_`var' log_`var'_0
		}

		
sort year month 
gen period=year*100+month
tostring period, gen(p)
gen d="01"
egen period_day=concat(p d)
gen p_day=date(period_day, "YMD")
format p_day %td
drop period
gen period=mofd(p_day)
format period %tm
tsset period, monthly

*log first difference
foreach var in count_firms count_pos countn tot_sales {
foreach P in 0 1 2 { 
gen d1log_`var'_`P'=d.log_`var'_`P'
}
}

*replace values for April 2014 with average of March and May 2014
foreach var in count_firms count_pos countn tot_sales {
foreach P in 0 1 2 { 
		egen average_`var'_`P'=mean(d1log_`var'_`P'), by(id_average)
		replace average_`var'_`P'=. if id_average==.
		egen av_`var'_`P'=mean(average_`var'_`P'), by(one_d)
		replace d1log_`var'_`P'=av_`var'_`P' if month==4 & year==2014

}
}


keep month year d1log_* distt post n reform

*creating two time series for months before and after the reform
reshape wide d1log_count_firms_1 d1log_count_pos_1 d1log_countn_1 d1log_tot_sales_1, i( year month n reform distt) j(post)

	
foreach var in count_firms count_pos countn tot_sales  {
egen d1log_`var'_t=rowtotal(d1log_`var'_11 d1log_`var'_10) 
}
gen post=(dist>=0)

gen one=1

gen seq=_n
tab seq, gen(placebo)

*variable to capture the coefficient
foreach var in count_firms count_pos countn tot_sales  {
gen pvalue_`var'=.
}

foreach var in count_firms count_pos countn tot_sales  {
forvalues i = 1(1)60 {
reg d1log_`var'_t placebo`i'
replace pvalue_`var'=_b[placebo`i'] if seq==`i'
}
}

*locals for text in graph
foreach var in count_firms count_pos countn tot_sales  {
sum pvalue_`var' if distt==0
local value_`var'=r(mean)
gen random_`var'=pvalue_`var'>=`value_`var''
replace random_`var'=. if distt==0
sum random_`var'
scalar random_`var'=r(mean)
scalar random_`var'=string(r(mean), "%05.3f")
}


foreach var in tot_sales countn count_firms count_pos  {
	*value for reform month
sum d1log_`var'_11 if year==2014 & month==8 
scalar mean_`var'=r(mean)
scalar mean_`var'_t=string(r(mean), "%05.3f")

*storing values for graphs and t-tests
sum d1log_`var'_11 if dist>=1
scalar meanpost_`var'_t=string(r(mean), "%05.3f")

sum d1log_`var'_11 if dist>=1
scalar meanpost_t_`var'=r(mean)

sum d1log_`var'_10 
scalar meanpre_`var'_t=string(r(mean), "%05.3f")

ttest d1log_`var'_10==`=scalar(mean_`var')'
scalar ttest1_`var'_t=string(r(p), "%05.3f")

ttest d1log_`var'_t if dist!=0, by(post ) 
scalar ttest2_`var'_t=string(r(p), "%05.3f")

sum d1log_`var'_t if dist!=0
scalar all_`var'_t=string(r(mean), "%05.3f")

replace d1log_`var'_t=. if dist==0

ttest d1log_`var'_t==`=scalar(mean_`var')' 
scalar ttest3_`var'_t=string(r(p), "%05.3f")

	global ly_count_firms=42
	global ly_count_pos=12 
	global ly_countn=10 
	global ly_tot_sales=10 
	global ly_rtaxsale=10 
	global ly_rnetliab=10
	
	global ly2_count_firms=38
	global ly2_count_pos=10 
	global ly2_countn=8 
	global ly2_tot_sales=8 
	global ly2_rtaxsale=8 
	global ly2_rnetliab=8
	
	global lx_count_firms=.013
	global lx_count_pos=.06 
	global lx_countn=.25 
	global lx_tot_sales=.13
	global lx_rtaxsale=.1 
	global lx_rnetliab=.1	
	
	global lx2_count_firms=.015
	global lx2_count_pos=.067
	global lx2_countn=.27 
	global lx2_tot_sales=.15 
	global lx2_rtaxsale=.12 
	global lx2_rnetliab=.12
	
	local a_count_firms="{&lArr} Reform-Month"
	local a_count_pos="{&lArr} Reform-Month"
	local a_countn="Reform-Month {&rArr}"
	local a_tot_sales="Reform-Month {&rArr}"
	
	*histograms
twoway (histogram d1log_`var'_10, /*bin(6)*/gap(35) fcolor(orange%29) lcolor(orange)) (histogram d1log_`var'_11 if distt>0, /*bin(6)*/gap(35) fcolor(navy%30) lcolor(navy)) (histogram d1log_`var'_11, bin(6) gap(35) fcolor(none) lcolor(none)), xline(`=scalar(mean_`var')', lwidth(medthick) lpattern(solid) lcolor(red)) legend(order(1 "Pre-Reform" 2 "Post-Reform")) scale(1.2) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(fcolor(white) ifcolor(white)) ///
note("Mean Pre Reform (`=scalar(meanpre_`var'_t)') vs Mean Post Reform (`=scalar(meanpost_`var'_t)'): ttest p-value (`=scalar(ttest2_`var'_t)')" "Month of Introduction (`=scalar(mean_`var'_t)') vs Mean All Other Months (`=scalar(all_`var'_t)'): ttest p-value (`=scalar(ttest3_`var'_t)')" "Mean Pre Reform (`=scalar(meanpre_`var'_t)') vs Month of Introduction (`=scalar(mean_`var'_t)'): ttest p-value (`=scalar(ttest1_`var'_t)')" "Randomization Inference p-value: (`=scalar(random_`var')')", span) ///
text(${ly_`var'} ${lx_`var'} "`a_`var''" , place(e)) ///
text(${ly2_`var'} ${lx2_`var'} "Growth Rate", place(e))
graph export "hist_1dtdif_`var'_all_random_`a'.pdf", replace	
}
}

