

use "$datadir\vat_returns_month_long.dta", clear
*-------------------------------------------------------------------------------
*1. Cleaning:
*-------------------------------------------------------------------------------

		bysort ide: egen sector = max(codgiro)
		gen retail = 0
		replace retail = 1 if floor(codgiro/1000) == 47 | codgiro==45102 | codgiro==45103 | codgiro==45109  | codgiro==45309
		gen wholesale = 0
		replace wholesale = 1 if floor(codgiro/1000) == 46  | codgiro==45101 | codgiro==45301
		
		keep if retail==1 | wholesale==1
	
	keep if period!=.	
	
	gen double rtotal_venta=rtot_venta
	replace rtotal_venta=0 if missing(rtot_venta)

	*identification of year of introduction
	xtset ide period_day
	bys ide (period_day): gen l_hascard2=hascard[_n-1] // lag of has a card
	gen card_introduction=((l_hascard2==0 & hascard==1) | (l_hascard2==. & hascard==1)) // introduction if went from not having to having a card or has alway had a card. 

	sort ide year month
	gen year_introduction=year if card_introduction==1 
	egen year_introt=min(year_introduction), by(ide)
	drop if year_introt==. // dropping if has never had a card machine. 
	
	gen month_introduction=month if card_introduction==1
	egen month_intro=min(month_introduction), by(ide year) // min month by year of introduction
	gen month_i=month_intro if year_introduction==year_introt // select the correct year
	egen month_d=min(month_i), by(ide)
	
	gen year_drop=year_introt if month_d>2 
	replace year_drop=year_introt-1 if month_d<=2
	
	
	drop if year<=year_drop

		* Total sales reported to VAT: generate yearly variable for CEDE (1 obs) vs non-CEDE (aggregate):
	egen double sales = rsum(rlinea_14 rlinea_214)
	gen double yrsales_nocede = sales if cede==0
	bysort id year: egen double yrsales_cede =total(sales) if cede==1
	egen double yrsales = rsum(yrsales_*)
	replace yrsales=max(0,yrsales)
	
	* Total card sales: aggregate at annual level for both: 
	bysort id year: egen double yrcardsales =total(rtotal_venta) 
	
	* collapsing to generate annual data
	collapse (mean) yrcardsales yrsales (max) codgiro cede, by(year ide)
	* ratio
	gen double scardsale = yrcardsales/yrsales
	winsor2 scardsale, suf(w) cuts(0 99) by(year)
		
	gen scard_bigger_1=(scardsale>1.05)
	gen scard_bigger_08=(scardsale>0.8)
		
	drop if year<2012 | year>2015
	
		*Print in graph
		sum scardsale if scardsale>0 & scardsale<=1, d
		local obs=r(N)
		local mean=r(mean)
		glo mean: di %3.2f `mean'
		local median=r(p50)
		glo median: di %3.2f `median'

		local mean_post=`mean'+0.002
		local median_post=`median'+0.002

		foreach year in 2012 2013 2014 2015 {
		sum scardsale if scardsale>0 & scardsale<=1 & year==`year', d
		local obs_`year'=r(N)
		}
		

		*Creating bins
drop if scardsale==. | scardsale==0
drop if scardsale>1

gen bins_cardsale=round(scardsale, .01)
gen bins=bins_cardsale*100
replace bins=bins/2
replace bins=floor(bins)

gen count_firms=1

collapse (sum) count_firms, by(year bins)
egen sum_firms=sum(count_firms), by(year)
gen fraction_firms=count_firms/sum_firms

replace bins=(bins*2)/100

			tw (line fraction_firms bins if year==2012, lcolor(blue) lpattern(shortdash)) ///
				(line fraction_firms bins if year==2013, lcolor(blue) lpattern(dot)) ///
				(line fraction_firms bins if year==2014, lcolor(blue) lpattern(longdash)) ///
				(line fraction_firms bins if year==2015, lcolor(blue) lpattern(solid)), /// 
				xline(`mean', lp(dash)) /*xlab(`mean' "mean", add angle(vertical))*/ xline(`median', lp(shortdash)) ///
				/*xlab(`median' "median", add angle(vertical))*/ ///
				title("") ytitle("Fraction")  xtitle("Share of Electronic Sales in Reported Sales, E/R", axis(1))  ///
			graphregion(color("white")) legend(cols(4) order(1 "2012" 2 "2013" 3 "2014" 4 "2015" )) ///
			caption("N: 2012=`obs_2012', 2013=`obs_2013', 2014=`obs_2014', 2015=`obs_2015'", size(medsmall)) text(.1 `mean_post' "2013 Mean: ${mean}", place(e) orient(vertical) size(medsmall)) ///
			 text(.1 `median_post' "2013 Median: ${median}", place(e) orient(vertical) size(medsmall))
			 	 graph export "scardsales_density`industry'_ms_3_line.pdf", replace
		
