
foreach year in 2014 2015 {
 use "$stata_raw\card_data_ext_`year'.dta", clear
 
gen credito_iva=tot_credito if tipo_tran==9

collapse (sum) credito_iva, by(id_afi year month)

if `year'==2014 {
drop if month<=7
}

save "$datadir\credit_iva_`year'.dta", replace
}

*******************************************************************
*cost of rebates as share of vat collected by firms
********************************************************************

use "${datadir}/vat_returns_month_long.dta", clear

*selected time frame 
keep if year==2014 | year==2015
drop if month<=7 & year==2014


gen madecredit=1 if tot_credito19210>0 & tot_credito19210!=.
gen liab_credit=netliab if madecredit==1
gen liab_pos=netliab if hascard==1
br tot_credito19210 liab_credit liab_pos netliab
collapse (sum) tot_credito19210 liab_credit liab_pos netliab, by(year month)

gen share_credit=(tot_credito19210/liab_credit)*100
gen share_pos=(tot_credito19210/liab_pos)*100
gen share_firms=(tot_credito19210/netliab)*100

sort year month 
gen period=year*100+month
tostring period, gen(p)
gen d="01"
egen period_day=concat(p d)
gen p_day=date(period_day, "YMD")
format p_day %td
drop period
gen period=mofd(p_day)
format period %tm
drop p_day period_day

sort period 
gen n=_n

twoway (connected share_credit n, mcolor(navy) msymbol(square) lcolor(navy) lwidth(medium) lpattern(dash_dot)) ///
(connected share_pos n, mcolor(orange) msymbol(T) lcolor(orange) lwidth(medium) lpattern(dash)) (connected share_firms n, mcolor(green) msymbol(Oh) lcolor(green) lwidth(medium) lpattern(solid)), ytitle("Cost of VAT Rebates as" "Share of Net VAT Liability") xtitle(Month-Year) legend(order(1 "Rebate Granting Firms" 2 "Firms with a POS"  3 "All Firms") row(3)) xlabel(1 "2014m8" 6 "2015m1" 12 "2015m7" 16.6 "2015m12", labsize(small)) graphregion(fcolor(white)) scale(1.15)
graph export "cost_rebates_firms.pdf", replace

********************************************************************
*cost as share of total revenue (by DGI)
********************************************************************

use "$datadir\credit_iva_2015.dta", replace

append using "$datadir\credit_iva_2014.dta"

collapse (sum) credito_iva, by(year month)

merge 1:1 month year using "$stata_raw\tax_revenue.dta"
keep if _merge==3

gen share=credito_iva/vat_revenue
replace share=share*100

sort year month 
gen period=year*100+month
tostring period, gen(p)
gen d="01"
egen period_day=concat(p d)
gen p_day=date(period_day, "YMD")
format p_day %td
drop period
gen period=mofd(p_day)
format period %tm
drop p_day period_day

sort period 
gen n=_n

gen amount=credito_iva/1000000

twoway (connected share n, mcolor(navy) msymbol(square) lcolor(navy) lwidth(medium) lpattern(dash_dot)), ytitle("Cost of VAT rebates as" "Share of National VAT Revenue") xtitle(Month-Year) xlabel(1 "2014m8" 6 "2015m1" 12 "2015m7" 16.6 "2015m12", labsize(small)) graphregion(fcolor(white)) scale(1.15)
graph export "cost_rebates_total.pdf", replace

twoway (connected amount n, mcolor(navy) msymbol(square) lcolor(navy) lwidth(medium) lpattern(dash_dot)), ytitle("Cost of VAT rebates" "Millions-Uruguayan Pesos") xtitle(Month-Year) xlabel(1 "2014m8" 6 "2015m1" 12 "2015m7" 16.6 "2015m12", labsize(small)) graphregion(fcolor(white)) scale(1.15)
graph export "cost_rebates_nominal.pdf", replace
******************************************************
use "$stata_raw\BM_Subsidy.dta", clear
drop if pos==. 
drop if pos<0
gen n_pos=pos/209
drop if year>2015
save "$datadir\pos_subsidy.dta", replace

collapse (sum) pos (count) npos=pos, by(year month)

merge 1:1 month year using "$stata_raw\tax_revenue.dta"
keep if _merge==3

gen share=pos/vat_revenue
replace share=share*100

sort year month 
gen period=year*100+month
tostring period, gen(p)
gen d="01"
egen period_day=concat(p d)
gen p_day=date(period_day, "YMD")
format p_day %td
drop period
gen period=mofd(p_day)
format period %tm
drop p_day period_day

sort period 
gen n=_n

gen amount=pos/1000

gen id=(n==15 | n==16)
egen av_share=mean(share), by(id)
replace share=av_share if id==1

egen av_amount=mean(amount), by(id)
replace amount=av_amount if id==1


twoway (connected share n, mcolor(navy) msymbol(square) lcolor(navy) lwidth(medium) lpattern(dash_dot)), ytitle("Cost of POS Subsidies as" "Share of National VAT Revenue") xtitle(Month-Year) xlabel(1 "2012m9" 5 "2013m1" 11 "2013m7" 17 "2014m1" 23 "2014m7" 29 "2015m1" 35 "2015m7" 40 "2015m12", labsize(vsmall)) graphregion(fcolor(white)) scale(1.15)
graph export "cost_subsidy_total.pdf", replace

twoway (connected amount n, mcolor(navy) msymbol(square) lcolor(navy) lwidth(medium) lpattern(dash_dot)), ytitle("Cost of POS Subsidies" "Thousands-Uruguayan Pesos") xtitle(Month-Year) xlabel(1 "2012m9" 5 "2013m1" 11 "2013m7" 17 "2014m1" 23 "2014m7" 29 "2015m1" 35 "2015m7" 40 "2015m12", labsize(vsmall)) graphregion(fcolor(white)) scale(1.15)
graph export "cost_subsidy_nominal.pdf", replace


*************************************
use "${datadir}/vat_returns_month_long.dta", clear

drop if year<=2011
drop if month<=9 & year==2012
drop if year>2015

merge 1:1 ide year month using "$datadir\pos_subsidy.dta", gen(merge)
drop if merge==2

gen hassubsidy=1 if pos>0 & pos!=.
gen liab_subsidy=netliab if hassubsidy==1
gen liab_pos=netliab if hascard==1
collapse (sum) pos liab_subsidy liab_pos netliab, by(year month)

gen share_subsidy=(pos/liab_subsidy)*100
gen share_pos=(pos/liab_pos)*100
gen share_firms=(pos/netliab)*100

sort year month 
gen period=year*100+month
tostring period, gen(p)
gen d="01"
egen period_day=concat(p d)
gen p_day=date(period_day, "YMD")
format p_day %td
drop period
gen period=mofd(p_day)
format period %tm
drop p_day period_day

sort period 
gen n=_n

gen id=(n==15 | n==16)
egen av=mean(share_subsidy), by(id)
replace share_subsidy=av if id==1

egen av2=mean(share_pos), by(id)
replace share_pos=av2 if id==1

egen av3=mean(share_firms), by(id)
replace share_firms=av3 if id==1

twoway (connected share_subsidy n, mcolor(navy) msymbol(square) lcolor(navy) lwidth(medium) lpattern(dash_dot)) ///
(connected share_pos n, yaxis(2) mcolor(orange) msymbol(T) lcolor(orange) lwidth(medium) lpattern(dash)) (connected share_firms n, yaxis(2) mcolor(green) msymbol(Oh) lcolor(green) lwidth(medium) lpattern(solid)), ytitle("Cost of POS Subsidies as" "Share of Net VAT Liability") xtitle(Month-Year) legend(order(1 "Subsidy Receiving Firms (Left Axis)" 2 "Firms with a POS (Right Axis)"  3 "All Firms (Right Axis)") row(3)) xlabel(5 "2013m1" 11 "2013m7" 17 "2014m1" 23 "2014m7" 29 "2015m1" 35 "2015m7" 40 "2015m12", labsize(small)) graphregion(fcolor(white)) scale(1.15)
graph export "cost_subsidy_firms.pdf", replace

