

	*Unbalanced Sample 2010-2015 	
	use "${datadir}/data_ub_10.dta", clear

	* post and distance to 2014 
	gen distt=year-2014
	gen post=(distt>=0) 

	*card pre reform 
	egen card_pre_aux=max(hascard), by(post ide)
	replace card_pre_aux=. if post==1
	egen card_pre=mean(card_pre_aux), by(ide)

	*samples: retail firm with POS pre reform		
	gen r7=(retail==1 & card_pre==1) 

	*samples: wholesale firms witout POS pre reform
	gen r8=(retail==1 & card_pre==0)

	*negative value of outcomes
	foreach v in aoutput ainput total_sales total_tsales {
	gen neg_`v'=(`v'<0)
	egen t_neg_`v'=max(neg_`v'), by(ide)
	}

	*count negative
	egen sum_negative=rowtotal(t_neg_aoutput t_neg_ainput t_neg_total_sales t_neg_total_tsales)

	*keeping firms with all positive values
	keep if sum_negative==0

	keep if year==2013

	*merging CIT returns
	merge 1:1 ide using "${datadir}/cit_id.dta", gen(_merge2) 
	drop if _merge2==2
	gen cit_file=(_merge2==3)

	*Legal Nature
	recode codnatjuridica (1=1) (5 7=2) (10 11=3) (else=4), gen(inc)
	tab inc, gen(incor)
	tab codnatjuridica
	tab codnatjuridica, gen(inc)
	replace incor1=. if cit_file==0
	replace incor3=. if cit_file==0

	*winsorizing
	foreach var in total_tsales aoutput ainput aliability total_sales card_sales cantidad_oper {
	winsor2 `var', cuts(0 99) by(retail) replace 
	}

	*positive liability 
	gen posi_liab=(aliability>0 & aliability!=.)

	*share of card sales over total sales
	gen share=card_sales/total_sales

	*thousands
	foreach x in aoutput ainput aliability total_sales card_sales cantidad_oper  {
	replace `x'=`x'/1000
	}

	*for sample conditional
	gen all=1


	*percentiles of tax relates variables
	foreach v in aoutput ainput aliability total_sales  {
	foreach s in all retail wholesale r7 r8 {
	sum `v' if `s'==1, d
	foreach p in mean sd p5 p25 p50 p75 p90 min max {
	local `p'_`v'_`s'=string(r(`p'), "%15.0fc")
	}
	}
	}

	*mean and sd
	foreach v in posi_liab hascard incor1 incor3  {
	foreach s in all retail wholesale r7 r8 {
	sum `v' if `s'==1, d
	local mean_`v'_`s'=string(r(mean), "%15.2fc")
	local sd_`v'_`s'=string(r(sd), "%15.2fc")
	}
	}

	*sales percentiles for rest of stats
	foreach s in all retail wholesale r7 r8 {
	foreach p in p5 p25 p50 p75 p90 min max {
	sum total_sales if `s'==1, d
	gen `p'_s_`s'=r(`p')
	}
	}

	* other characteristics by sales percentiles
	foreach v in posi_liab hascard incor1 incor3 {
	foreach s in all retail wholesale r7 r8 { 
	foreach p in  p5 p25 p50 p75 p90 min max {
	sum `v' if `s'==1 & total_sales<=`p'_s_`s', d
	local `p'_`v'_`s'p=string(r(mean), "%15.2fc")
	}
	}
	}

	* card transactions stats (conditional on having pos )
	foreach v in  card_sales cantidad_oper  {
	foreach s in all retail wholesale r7 r8 {
	sum `v' if `s'==1 & hascard==1, d
	foreach p in mean sd p5 p25 p50 p75 p90 min max {
	local `p'_`v'_`s'=string(r(`p'), "%15.0fc")
	}
	}
	} 

	*share of card sales 
	foreach v in share   {
	foreach s in all retail wholesale r7 r8 {
	sum `v' if `s'==1 & `v'<10, d
	foreach p in mean sd p5 p25 p50 p75 p90 min max  {
	local `p'_`v'_`s'=string(r(`p'), "%15.2fc")
	}
	}
	} 

	gen random=runiform(0,1)

	foreach s in all retail wholesale r7 r8 {
	sum random if `s'==1
	local n_`s'=r(N)
	}


texdoc init "sumstat_uruguay_f3_ub_r8.tex", force replace
tex						\begin{tabular}{clccccccccc}
tex							\toprule 
tex							\hline
tex & & & & \multicolumn{5}{c}{Percentile} \\
tex 	& & Mean & SD & Min & 5th & 25th & 50th & 75th & 90th & Max \\  \hline
tex & Total Annual Sales & `mean_total_sales_all' & `sd_total_sales_all'& `min_total_sales_all' & `p5_total_sales_all' & `p25_total_sales_all' & `p50_total_sales_all' & `p75_total_sales_all' & `p90_total_sales_all' & `max_total_sales_all' \\
tex & Input VAT & `mean_ainput_all' & `sd_ainput_all' & `min_ainput_all' & `p5_ainput_all' & `p25_ainput_all' & `p50_ainput_all' & `p75_ainput_all' & `p90_ainput_all' & `max_ainput_all' \\
tex & Output VAT & `mean_aoutput_all' & `sd_aoutput_all' & `min_aoutput_all' & `p5_aoutput_all' & `p25_aoutput_all' & `p50_aoutput_all' & `p75_aoutput_all' & `p90_aoutput_all' & `max_aoutput_all' \\
tex & Net VAT Liability & `mean_aliability_all' & `sd_aliability_all' & `min_aliability_all' & `p5_aliability_all' & `p25_aliability_all' & `p50_aliability_all' & `p75_aliability_all' & `p90_aliability_all' & `max_aliability_all' \\
tex All Firms & Sole Proprietorship & `mean_incor1_all' & `sd_incor1_all' & 0 & `p5_incor1_allp' & `p25_incor1_allp' & `p50_incor1_allp' & `p75_incor1_allp' & `p90_incor1_allp' & `max_incor1_allp' \\
tex N=`n_all' & Corporation & `mean_incor3_all' & `sd_incor3_all' & 0 & `p5_incor3_allp' & `p25_incor3_allp' & `p50_incor3_allp' & `p75_incor3_allp' & `p90_incor3_allp' & `max_incor3_allp' \\
tex  & Has POS & `mean_hascard_all' & `sd_hascard_all' & 0 & `p5_hascard_allp' & `p25_hascard_allp'  & `p50_hascard_allp' & `p75_hascard_allp' & `p90_hascard_allp' & `max_hascard_allp' \\
tex & Number of Card Transactions & `mean_cantidad_oper_all' & `sd_cantidad_oper_all' & `min_cantidad_oper_all' & `p5_cantidad_oper_all' & `p25_cantidad_oper_all' & `p50_cantidad_oper_all' & `p75_cantidad_oper_all' & `p90_cantidad_oper_all' & `max_cantidad_oper_all' \\
tex & Volume of Card Transactions & `mean_card_sales_all' & `sd_card_sales_all' & `min_card_sales_all'& `p5_card_sales_all' & `p25_card_sales_all' & `p50_card_sales_all' & `p75_card_sales_all' & `p90_card_sales_all' & `max_card_sales_all'\\
tex & Share of Electronic Sales & `mean_share_all' & `sd_share_all' & `min_share_all' & `p5_share_all' & `p25_share_all' & `p50_share_all' & `p75_share_all' & `p90_share_all'& `max_share_all' \\ \hline
tex & Total Annual Sales & `mean_total_sales_r8' & `sd_total_sales_r8'& `min_total_sales_r8' & `p5_total_sales_r8' & `p25_total_sales_r8' & `p50_total_sales_r8' & `p75_total_sales_r8' & `p90_total_sales_r8' & `max_total_sales_r8' \\
tex & Input VAT & `mean_ainput_r8' & `sd_ainput_r8' & `min_ainput_r8' & `p5_ainput_r8' & `p25_ainput_r8' & `p50_ainput_r8' & `p75_ainput_r8' & `p90_ainput_r8' & `max_ainput_r8' \\
tex & Output VAT & `mean_aoutput_r8' & `sd_aoutput_r8' & `min_aoutput_r8' & `p5_aoutput_r8' & `p25_aoutput_r8' & `p50_aoutput_r8' & `p75_aoutput_r8' & `p90_aoutput_r8' & `max_aoutput_r8' \\
tex & Net VAT Liability & `mean_aliability_r8' & `sd_aliability_r8' & `min_aliability_r8' & `p5_aliability_r8' & `p25_aliability_r8' & `p50_aliability_r8' & `p75_aliability_r8' & `p90_aliability_r8' & `max_aliability_r8' \\
tex Retail Firms & Sole Proprietorship & `mean_incor1_r8' & `sd_incor1_r8' & 0 & `p5_incor1_r8p' & `p25_incor1_r8p' & `p50_incor1_r8p' & `p75_incor1_r8p' & `p90_incor1_r8p' & `max_incor1_r8p' \\
tex No POS Pre Reform & Corporation &  `mean_incor3_r8' & `sd_incor3_r8' & 0 & `p5_incor3_r8p' & `p25_incor3_r8p' & `p50_incor3_r8p' & `p75_incor3_r8p' & `p90_incor3_r8p' & `max_incor3_r8p' \\
tex N=`n_r8' & Has POS & `mean_hascard_r8' & `sd_hascard_r8' & 0 & `p5_hascard_r8p' & `p25_hascard_r8p'  & `p50_hascard_r8p' & `p75_hascard_r8p' & `p90_hascard_r8p' & `max_hascard_r8p' \\
tex  & Number of Card Transactions & 0.00 & 0.00 & 0.00 & 0.00 & 0.00 & 0.00 & 0.00 & 0.00 & 0.00 \\
tex & Volume of Card Transactions & 0 & 0 & 0 & 0 & 0 & 0 & 0 & 0 & 0 \\
tex & Share of Electronic Sales & 0.00 & 0.00 & 0.00 & 0.00 & 0.00 & 0.00 & 0.00 & 0.00 & 0.00 \\ \hline
tex & Total Annual Sales & `mean_total_sales_r7' & `sd_total_sales_r7'& `min_total_sales_r7' & `p5_total_sales_r7' & `p25_total_sales_r7' & `p50_total_sales_r7' & `p75_total_sales_r7' & `p90_total_sales_r7' & `max_total_sales_r7' \\
tex & Input VAT & `mean_ainput_r7' & `sd_ainput_r7' & `min_ainput_r7' & `p5_ainput_r7' & `p25_ainput_r7' & `p50_ainput_r7' & `p75_ainput_r7' & `p90_ainput_r7' & `max_ainput_r7' \\
tex & Output VAT & `mean_aoutput_r7' & `sd_aoutput_r7' & `min_aoutput_r7' & `p5_aoutput_r7' & `p25_aoutput_r7' & `p50_aoutput_r7' & `p75_aoutput_r7' & `p90_aoutput_r7' & `max_aoutput_r7' \\
tex & Net VAT Liability & `mean_aliability_r7' & `sd_aliability_r7' & `min_aliability_r7' & `p5_aliability_r7' & `p25_aliability_r7' & `p50_aliability_r7' & `p75_aliability_r7' & `p90_aliability_r7' & `max_aliability_r7' \\
tex Retail Firms & Sole Proprietorship & `mean_incor1_r7' & `sd_incor1_r7' & 0 & `p5_incor1_r7p' & `p25_incor1_r7p' & `p50_incor1_r7p' & `p75_incor1_r7p' & `p90_incor1_r7p' & `max_incor1_r7p' \\
tex POS Pre Reform & Corporation & `mean_incor3_r7' & `sd_incor3_r7' & 0 & `p5_incor3_r7p' & `p25_incor3_r7p' & `p50_incor3_r7p' & `p75_incor3_r7p' & `p90_incor3_r7p' & `max_incor3_r7p' \\
tex N=`n_r7' & Has POS & `mean_hascard_r7' & `sd_hascard_r7' & 0 & `p5_hascard_r7p' & `p25_hascard_r7p'  & `p50_hascard_r7p' & `p75_hascard_r7p' & `p90_hascard_r7p' & `max_hascard_r7p' \\
tex & Number of Card Transactions & `mean_cantidad_oper_r7' & `sd_cantidad_oper_r7' & `min_cantidad_oper_r7' & `p5_cantidad_oper_r7' & `p25_cantidad_oper_r7' & `p50_cantidad_oper_r7' & `p75_cantidad_oper_r7' & `p90_cantidad_oper_r7' & `max_cantidad_oper_r7' \\
tex & Volume of Card Transactions & `mean_card_sales_r7' & `sd_card_sales_r7' & `min_card_sales_r7'& `p5_card_sales_r7' & `p25_card_sales_r7' & `p50_card_sales_r7' & `p75_card_sales_r7' & `p90_card_sales_r7' & `max_card_sales_r7'\\
tex & Share of Electronic Sales & `mean_share_r7' & `sd_share_r7' & `min_share_r7' & `p5_share_r7' & `p25_share_r7' & `p50_share_r7' & `p75_share_r7' & `p90_share_r7'& `max_share_r7' \\ \hline
tex & Total Annual Sales & `mean_total_sales_wholesale' & `sd_total_sales_wholesale'& `min_total_sales_wholesale' & `p5_total_sales_wholesale' & `p25_total_sales_wholesale' & `p50_total_sales_wholesale' & `p75_total_sales_wholesale' & `p90_total_sales_wholesale' & `max_total_sales_wholesale' \\
tex & Input VAT & `mean_ainput_wholesale' & `sd_ainput_wholesale' & `min_ainput_wholesale' & `p5_ainput_wholesale' & `p25_ainput_wholesale' & `p50_ainput_wholesale' & `p75_ainput_wholesale' & `p90_ainput_wholesale' & `max_ainput_wholesale' \\
tex & Output VAT & `mean_aoutput_wholesale' & `sd_aoutput_wholesale' & `min_aoutput_wholesale' & `p5_aoutput_wholesale' & `p25_aoutput_wholesale' & `p50_aoutput_wholesale' & `p75_aoutput_wholesale' & `p90_aoutput_wholesale' & `max_aoutput_wholesale' \\
tex & Net VAT Liability & `mean_aliability_wholesale' & `sd_aliability_wholesale' & `min_aliability_wholesale' & `p5_aliability_wholesale' & `p25_aliability_wholesale' & `p50_aliability_wholesale' & `p75_aliability_wholesale' & `p90_aliability_wholesale' & `max_aliability_wholesale' \\
tex Wholesale Firms & Sole Proprietorship & `mean_incor1_wholesale' & `sd_incor1_wholesale' & 0 & `p5_incor1_wholesalep' & `p25_incor1_wholesalep' & `p50_incor1_wholesalep' & `p75_incor1_wholesalep' & `p90_incor1_wholesalep' & `max_incor1_wholesalep' \\
tex N=`n_wholesale' & Corporation  & `mean_incor3_wholesale' & `sd_incor3_wholesale' & 0 & `p5_incor3_wholesalep' & `p25_incor3_wholesalep' & `p50_incor3_wholesalep' & `p75_incor3_wholesalep' & `p90_incor3_wholesalep' & `max_incor3_wholesalep' \\
tex  & Has POS & `mean_hascard_wholesale' & `sd_hascard_wholesale' & 0 & `p5_hascard_wholesalep' & `p25_hascard_wholesalep'  & `p50_hascard_wholesalep' & `p75_hascard_wholesalep' & `p90_hascard_wholesalep' & `max_hascard_wholesalep' \\
tex & Number of Card Transactions & `mean_cantidad_oper_wholesale' & `sd_cantidad_oper_wholesale' & `min_cantidad_oper_wholesale' & `p5_cantidad_oper_wholesale' & `p25_cantidad_oper_wholesale' & `p50_cantidad_oper_wholesale' & `p75_cantidad_oper_wholesale' & `p90_cantidad_oper_wholesale' & `max_cantidad_oper_wholesale' \\
tex & Volume of Card Transactions & `mean_card_sales_wholesale' & `sd_card_sales_wholesale' & `min_card_sales_wholesale'& `p5_card_sales_wholesale' & `p25_card_sales_wholesale' & `p50_card_sales_wholesale' & `p75_card_sales_wholesale' & `p90_card_sales_wholesale' & `max_card_sales_wholesale'\\
tex & Share of Electronic Sales & `mean_share_wholesale' & `sd_share_wholesale' & `min_share_wholesale' & `p5_share_wholesale' & `p25_share_wholesale' & `p50_share_wholesale' & `p75_share_wholesale' & `p90_share_wholesale'& `max_share_wholesale' \\ \hline
tex				\hline
tex				\end{tabular}
texdoc close
