
*appending firm day data of all years
use "${datadir}/daily_firm_pos_2011.dta", replace

foreach y in 2012 2013 {
append using "${datadir}/daily_firm_pos_`y'.dta"
}

*collapse at the week-firm-pos level
collapse (sum) tot_venta count, by(year month id_afi nro_pos)

gen count_pos=1

*collapse at the week-firm-pos level
collapse (sum) tot_venta count count_pos, by(year month id_afi)

rename id_afi ide 
save "${datadir}/month_card_subsidy.dta", replace

foreach var in tot_sales count_trans hascard {
use "${datadir}\vat_returns_month_long.dta", clear 

keep if year>=2011 & year<=2013
drop if year==2013 & month>3


	** RETAIL + WHOLESALE DATA
		bysort ide: egen sector = max(codgiro)
		gen retail = 0
		replace retail = 1 if floor(codgiro/1000) == 47
		gen wholesale = 0
		replace wholesale = 1 if floor(codgiro/1000) == 46
		
keep if retail==1 | wholesale==1

merge 1:1 ide year month using "$datadir\month_card_subsidy.dta", gen(merge1)
drop if merge1==2


gen has_pos=(count_pos>0 & count_pos!=.)
gen has_pos2=(count_pos>1 & count_pos!=.)
gen has_pos3=(count_pos>2 & count_pos!=.)

if "`var'"!= "hascard" {
keep if merge1==3
}

rename tot_venta tot_sales 
rename count count_trans

* Balanced sample (quarter):
* Quarter indicator
		sort ide period
		gen quarter = qofd(dofm(period))
		format quarter %tq
		
* Counting observations per quarter
		foreach i in 2011q1 2011q2 2011q3 2011q4 2012q1 2012q2 2012q3 2012q4 2013q1 {
		gen has`i'_aux = quarter==tq(`i')
		by id: egen has`i'=max(has`i'_aux )
		}
		egen numq = rsum(has2011q1 has2011q2 has2011q3 has2011q4 has2012q1 has2012q2 has2012q3 has2012q4 has2013q1)
		keep if numq==9 
		
		keep period tot_sales count_trans retail wholesale hascard ide year year_birth
		
		if "`var'"!= "hascard" {
		reshape wide tot_sales count_trans year, i(hascard retail wholesale year_birth ide) j(period)
		reshape long tot_sales count_trans year, i(hascard retail wholesale year_birth ide) j(period)

		replace count_trans=0 if count_trans==.
		replace tot_sales=0 if tot_sales==.
		}

		destring year_birth, replace
		recode  year_birth (1950=1950) (1951/1955=1951) (1956/1960=1956) (1961/1965=1961) ///
		(1966/1970=1966) (1971/1975=1971) (1976/1980=1976), gen(year_inc)
		
		gen distt=period-tm(2012m1)
		
		gen post=(distt>=0) 

		* Interaction 
		gen did_rvsw=retail*post
		
		keep if distt>=-12 & dist<=12
		
		replace tot_sales=tot_sales*1000000
		replace count_trans=count_trans*1000000
		
		foreach v in tot_sales count_trans {
		winsor2 `v', suffix(_99) cuts(0 99) by(year retail)
		gen aux_`v'=`v'_99
		sum aux_`v' if aux_`v'>=1
		local min=r(min)
		gen minvar_`v'=`min'
		gen log_modif_`v'=log(`v'_99/(minvar_`v'))
		replace log_modif_`v'=-0.1 if `v'_99==0
		}
		
		gen log_modif_hascard=hascard 

		* Scaling outcome variables by pre-reform mean
		egen aux_sc_log_modif_`var'=mean(log_modif_`var'), by(post retail)
		replace aux_sc_log_modif_`var'=. if post==1
		bys retail: egen scale_log_modif_`var'=min(aux_sc_log_modif_`var')
		gen s_log_modif_`var'=log_modif_`var'/scale_log_modif_`var'	


		reghdfe log_modif_`var' did_rvsw, absorb(i.ide i.distt i.year_birth#i.year) cluster(i.ide)

		foreach x in se b {
		glo p`x'_log_modif_`var'=_`x'[did_rvsw]
		glo p`x'_log_modif_`var': di %4.3f ${p`x'_log_modif_`var'}
			}

/*-------------------------------------------------------------------------------
				4. Graphs
*-------------------------------------------------------------------------------*/


		*Unique tag per firm
		egen tag=tag(ide)
			
		** Sample size for graph (unique taxpayers)
		count if retail==1 & tag==1
		local n_treat=r(N)
		count if retail==0 & tag==1
		local n_control=r(N)


		* collapsing at the yearly level by treatment
		collapse (mean) s_log_modif_`var'=s_log_modif_`var' m_log_modif_`var'=log_modif_`var' (semean) se_log_modif_`var'=s_log_modif_`var', by(distt retail)
		
		** building means and confidence interval 
		gen v_log_modif_`var'=se_log_modif_`var'*1.96
		gen lower_log_modif_`var'=s_log_modif_`var'-v_log_modif_`var'
		gen upper_log_modif_`var'=s_log_modif_`var'+v_log_modif_`var'
		gen mean_log_modif_`var'=s_log_modif_`var'
		
		*Reshape
		keep lower_* upper_* mean_* distt retail
		reshape wide lower_* upper_* mean_*, i(distt) j(retail)
		
	 * Local for text in graphs
		local yaxis_text="Relative to Pre-Reform Average"
		local l_tot_sales="Volume of Card Transactions" 
		local l_count_trans="Number of Card Transactions"
		local c_log="OLS DD (Log)"
	
	twoway (conn mean_log_modif_`var'0 distt, lcolor(blue) mcolor(blue) msymbol(X) msize(medium)) ///
	(conn mean_log_modif_`var'1 distt, color(red) mcolor(red) msize(medium)), ///
	 graphregion(fcolor(white)) ///
	ylabel(0.9(0.1)1.15, labsize(medium)) legend(order(2 "Treated" 1 "Control") rows(1) size(small)) ///
	ytitle("Normalized Log Outcome" "(`yaxis_text')", size(medium)) xline(0, lwidth(medthin) lcolor(black)) ///
	xtitle(Months to Reform, size(medium)) scale(1.2) ///
		note("DiD: ${pb_log_modif_`var'} (${pse_log_modif_`var'}). N Treated=`n_treat', N Control=`n_control'")
		
				graph export did_month_`var'_b_log_modif_jan2012.pdf, replace

}

 