use "${datadir}/vat_returns_month_long.dta", clear
drop if period==.

destring year_birth, replace 
rename  n_branches cantidadsucursales 

collapse (max) hascard year_birth cantidadsucursales coddeptofiscal codnatjuridica codgiro receivedsubs rlinea_14 rlinea_214 nlinea_214 nlinea_14 cede (sum) taxsale taxpur netliab cantidad_oper oper19210 tot_venta tot_venta19210 tot_credito tot_credito19210 rtaxsale rtaxpur rnetliab rtot_venta rtot_credito, by( ide year)

gen age=year- year_birth
replace age=0 if age<0
gen positive_liab=netliab>0

		bysort ide: egen sector = max(codgiro)
		gen retail = 0
		replace retail = 1 if floor(codgiro/1000) == 47

		gen wholesale = 0
		replace wholesale = 1 if floor(codgiro/1000) == 46
		
		gen construction = 0
		replace construction = 1 if floor(codgiro/1000) >= 41 &  floor(codgiro/1000)==43

		gen services=0
		replace services=1 if floor(codgiro/1000)>=48 & floor(codgiro/1000)<=96
		
		gen hotelfood = 0
		replace hotelfood = 1 if floor(codgiro/1000) == 55 |  floor(codgiro/1000)==56

		gen entretaiment = 0
		replace entretaiment = 1 if floor(codgiro/1000) >= 90 &  floor(codgiro/1000)==93

		gen finance = 0
		replace finance = 1 if floor(codgiro/1000) >= 64 &  floor(codgiro/1000)==66

		gen other_services=0
		replace other_services=1 if services==1 & entretaiment==0 & hotelfood==0 & finance==0
		
		gen all_others=0
		replace all_others=1 if retail==0 & wholesale==0 & services==0 & construction==0
		
		gen turnover=(rlinea_214 + rlinea_14)
		gen log_turnover=log(turnover+1)
		gen log_taxsale=log(rtaxsale+1)
		gen log_taxpur=log(rtaxpur+1)
		gen liability=max(0,rnetliab)
		replace liability=0 if liability<=0
		gen log_liab=log(1+liability)
		gen etr=netliab/turnover
		replace etr=0 if etr<=0
		gen netliab2=liability/1000

		gen ln_liab=ln(liability+1)
		sum ln_liab
		
		gen nocard=hascard==0
	gen posi_liab=netliab>0
	preserve
	keep if year==2013
	
foreach v in cantidadsucursales cede log_turnover log_taxsale log_taxpur retail wholesale construction hotelfood entretaiment finance other_services all_others netliab2 etr age log_liab posi_liab {
	reg `v' hascard
	matrix m_`v'=r(table)
	local `v'd=string(m_`v'[1,1], "%15.3fc")
	local `v'p=string(m_`v'[4,1], "%15.3fc")
	sum `v' if hascard==1
	local `v'1=string(r(mean), "%15.2fc")
	sum `v' if hascard==0
	local `v'0=string(r(mean), "%15.2fc")

}
count if hascard==1
local count1=string(r(N), "%15.0fc")
count if hascard==0
local count0=string(r(N), "%15.0fc")

texdoc init "differences_hascard", force replace
tex \begin{tabular}{lcccc}\hline
tex & POS  & No POS  & Difference & P-value  \\ 
tex & Terminal &  Terminal &   & \\ \hline
tex Log(Turnover+1) & `log_turnover1' & `log_turnover0' & `log_turnoverd' & [`log_turnoverp'] \\
tex Log(Output VAT+1) & `log_taxsale1' & `log_taxsale0' & `log_taxsaled' & [`log_taxsalep'] \\
tex Log(Input VAT+1) & `log_taxpur1' & `log_taxpur0' & `log_taxpurd' & [`log_taxpurp'] \\
tex Log(Net Liability+1) & `log_liab1' & `log_liab0' & `log_liabd' & [`log_liabp'] \\
tex Positive Liability & `posi_liab1' & `posi_liab0' & `posi_liabd' & [`posi_liabp'] \\
tex Effective Tax Rate & `etr1' & `etr0' & `etrd'  & [`etrp'] \\
tex Branches & `cantidadsucursales1' & `cantidadsucursales0' & `cantidadsucursalesd'  & [`cantidadsucursalesp'] \\
tex Firm Age & `age1' & `age0' & `aged' & [`agep'] \\
tex Retail & `retail1' & `retail0' & `retaild' & [`retailp'] \\
tex Wholesale & `wholesale1' & `wholesale0' & `wholesaled' & [`wholesalep'] \\
tex Construction & `construction1' & `construction0' & `constructiond' & [`constructionp'] \\
tex Hotels and Restaurants & `hotelfood1' & `hotelfood0' & `hotelfoodd' & [`hotelfoodp'] \\
tex Finance & `finance1' & `finance0' & `financed' & [`financep'] \\
tex Entretaiment & `entretaiment1' & `entretaiment0' & `entretaimentd' & [`entretaimentp'] \\
tex Other Services & `other_services1' & `other_services0' & `other_servicesd' & [`other_servicesp']  \\
tex All Other Sectors & `all_others1' & `all_others0' & `all_othersd' & [`all_othersp'] \\
tex CEDE Status & `cede1' & `cede0' & `ceded' & [`cedep']  \\ \hline
tex N & `count1' & `count0' & &  \\ \hline
tex \end{tabular}
texdoc close 

foreach v in cantidadsucursales cede log_turnover log_taxsale log_taxpur netliab2 etr age log_liab posi_liab {
	reg `v' hascard if retail==1
	matrix m_`v'=r(table)
	local `v'd=string(m_`v'[1,1], "%15.3fc")
	local `v'p=string(m_`v'[4,1], "%15.3fc")
	sum `v' if hascard==1 & retail==1
	local `v'1=string(r(mean), "%15.2fc")
	sum `v' if hascard==0 & retail==1
	local `v'0=string(r(mean), "%15.2fc")

}
count if hascard==1 & retail==1
local count1=string(r(N), "%15.0fc")
count if hascard==0 & retail==1
local count0=string(r(N), "%15.0fc")


texdoc init "differences_hascard_retail", force replace
tex \begin{tabular}{lcccc}\hline
tex & POS  & No POS  & Difference & P-value  \\ 
tex & Terminal &  Terminal &   & \\ \hline
tex Log(Turnover+1) & `log_turnover1' & `log_turnover0' & `log_turnoverd' & [`log_turnoverp'] \\
tex Log(Output VAT+1) & `log_taxsale1' & `log_taxsale0' & `log_taxsaled' & [`log_taxsalep'] \\
tex Log(Input VAT+1) & `log_taxpur1' & `log_taxpur0' & `log_taxpurd' & [`log_taxpurp'] \\
tex Log(Net Liability+1) & `log_liab1' & `log_liab0' & `log_liabd' & [`log_liabp'] \\
tex Positive Liability & `posi_liab1' & `posi_liab0' & `posi_liabd' & [`posi_liabp'] \\
tex Effective Tax Rate & `etr1' & `etr0' & `etrd'  & [`etrp'] \\
tex Branches & `cantidadsucursales1' & `cantidadsucursales0' & `cantidadsucursalesd'  & [`cantidadsucursalesp'] \\
tex Firm Age & `age1' & `age0' & `aged' & [`agep'] \\
tex CEDE Status & `cede1' & `cede0' & `ceded' & [`cedep']  \\ \hline
tex N & `count1' & `count0' & &  \\ \hline
tex \end{tabular}
texdoc close 

restore


	
	preserve
	
	egen tag=tag(ide)

	drop log_taxsale log_taxpur log_liab log_turnover


		foreach v in turnover rtaxsale rtaxpur liability {
		winsor2 `v', suffix(_99) cuts(0 99) by(year retail)
		gen aux_`v'=`v'_99
		sum aux_`v' if aux_`v'>0
		local min=r(min)
		gen minvar_`v'=`min'
		gen log_`v'=log(`v'_99/(minvar_`v'))
		replace log_`v'=-0.1 if `v'_99==0
		}
		
		
reghdfe log_rtaxsale hascard i.year log_turnover  , absorb(i.ide)
	local taxsaled=string(_b[hascard], "%15.2fc")
	local taxsalese=string(_se[hascard], "%15.3fc")
	sum log_rtaxsale
	local taxsale_m=string(r(mean), "%15.3fc")
	egen t1_a=tag(ide) if e(sample)==1
	count if t1_a==1 & hascard==1
	local taxsaleNt=string(r(N), "%15.0fc")
	count if t1_a==1 & hascard==0
	local taxsaleNc=string(r(N), "%15.0fc")
reghdfe log_rtaxpur hascard i.year log_turnover  , absorb(i.ide)
	local taxpurd=string(_b[hascard], "%15.2fc")
	local taxpurse=string(_se[hascard], "%15.3fc")
	sum log_rtaxpur
	local taxpur_m=string(r(mean), "%15.3fc")
	egen t1_b=tag(ide) if e(sample)==1
	count if t1_b==1 & hascard==1
	local taxpurNt=string(r(N), "%15.0fc")
	count if t1_b==1 & hascard==0
	local taxpurNc=string(r(N), "%15.0fc")
reghdfe log_liability hascard i.year log_turnover  , absorb(i.ide)
	local netliabd=string(_b[hascard], "%15.2fc")
	local netliabse=string(_se[hascard], "%15.3fc")
	sum log_liability
	local netliab_m=string(r(mean), "%15.3fc")
	egen t1_c=tag(ide) if e(sample)==1
	count if t1_c==1 & hascard==1
	local netliabNt=string(r(N), "%15.0fc")
	count if t1_c==1 & hascard==0
	local netliabNc=string(r(N), "%15.0fc")
reghdfe posi_liab hascard i.year log_turnover  , absorb(i.ide)
	local posid=string(_b[hascard], "%15.2fc")
	local posise=string(_se[hascard], "%15.3fc")
 	sum posi_liab
	local posi_liab_m=string(r(mean), "%15.3fc")
	egen t1_d=tag(ide) if e(sample)==1
	count if t1_d==1 & hascard==1
	local posiNt=string(r(N), "%15.0fc")
	count if t1_d==1 & hascard==0
	local posiNc=string(r(N), "%15.0fc")
reghdfe etr hascard i.year log_turnover  , absorb(i.ide)
	local etrd=string(_b[hascard], "%15.2fc")
	local etrse=string(_se[hascard], "%15.3fc")
	sum etr
	local etr_m=string(r(mean), "%15.3fc")
	egen t1_e=tag(ide) if e(sample)==1
	count if t1_e==1 & hascard==1
	local etrNt=string(r(N), "%15.0fc")
	count if t1_e==1 & hascard==0
	local etrNc=string(r(N), "%15.0fc")

texdoc init "FirmFE_hascard", force replace
tex \begin{tabular}{lccccc}\hline
tex & Log Output VAT & Log Input VAT & Positive Liability & Net Liability & ETR \\ \hline
tex Has POS Terminal & `taxsaled'& `taxpurd' & `posid' & `netliabd' & `etrd' \\
tex  & `taxsalese'& `taxpurse' & `posise' & `netliabse' & `etrse'\\ \hline
tex Mean & `taxsale_m' & `taxpur_m' & `posi_liab_m' & `etr_m' \\ \hline
tex Firm FE & Yes & Yes & Yes & Yes & Yes \\
tex Year FE & Yes & Yes & Yes & Yes & Yes \\
tex Turnover Control FE & Yes & Yes & Yes & Yes & Yes \\ \hline
tex N Treated & `taxsaleNt' & `taxpurNt' & `netliabNt' & `posiNt' & `etrNt' \\
tex N Control & `taxsaleNc' & `taxpurNc' & `netliabNc' & `posiNc' & `etrNc' \\ \hline
tex \end{tabular}
texdoc close 
restore

preserve

	egen tag=tag(ide)

	drop log_taxsale log_taxpur log_liab log_turnover


		foreach v in turnover rtaxsale rtaxpur liability {
		winsor2 `v', suffix(_99) cuts(0 99) by(year retail)
		gen aux_`v'=`v'_99
		sum aux_`v' if aux_`v'>0
		local min=r(min)
		gen minvar_`v'=`min'
		gen log_`v'=log(`v'_99/(minvar_`v'))
		replace log_`v'=-0.1 if `v'_99==0
		}
		
		
		
keep if retail==1
reghdfe log_rtaxsale hascard i.year log_turnover  , absorb(i.ide)
	local taxsaled=string(_b[hascard], "%15.2fc")
	local taxsalese=string(_se[hascard], "%15.3fc")
	sum log_rtaxsale
	local taxsale_m=string(r(mean), "%15.3fc")
	egen t1_a=tag(ide) if e(sample)==1
	count if t1_a==1 & hascard==1
	local taxsaleNt=string(r(N), "%15.0fc")
	count if t1_a==1 & hascard==0
	local taxsaleNc=string(r(N), "%15.0fc")
reghdfe log_rtaxpur hascard i.year log_turnover  , absorb(i.ide)
	local taxpurd=string(_b[hascard], "%15.2fc")
	local taxpurse=string(_se[hascard], "%15.3fc")
	sum log_rtaxpur
	local taxpur_m=string(r(mean), "%15.3fc")
	egen t1_b=tag(ide) if e(sample)==1
	count if t1_b==1 & hascard==1
	local taxpurNt=string(r(N), "%15.0fc")
	count if t1_b==1 & hascard==0
	local taxpurNc=string(r(N), "%15.0fc")
reghdfe log_liability hascard i.year log_turnover  , absorb(i.ide)
	local netliabd=string(_b[hascard], "%15.2fc")
	local netliabse=string(_se[hascard], "%15.3fc")
	sum log_liability
	local netliab_m=string(r(mean), "%15.3fc")
	egen t1_c=tag(ide) if e(sample)==1
	count if t1_c==1 & hascard==1
	local netliabNt=string(r(N), "%15.0fc")
	count if t1_c==1 & hascard==0
	local netliabNc=string(r(N), "%15.0fc")
reghdfe posi_liab hascard i.year log_turnover  , absorb(i.ide)
	local posid=string(_b[hascard], "%15.2fc")
	local posise=string(_se[hascard], "%15.3fc")
 	sum posi_liab
	local posi_liab_m=string(r(mean), "%15.3fc")
	egen t1_d=tag(ide) if e(sample)==1
	count if t1_d==1 & hascard==1
	local posiNt=string(r(N), "%15.0fc")
	count if t1_d==1 & hascard==0
	local posiNc=string(r(N), "%15.0fc")
reghdfe etr hascard i.year log_turnover  , absorb(i.ide)
	local etrd=string(_b[hascard], "%15.2fc")
	local etrse=string(_se[hascard], "%15.3fc")
	sum etr
	local etr_m=string(r(mean), "%15.3fc")
	egen t1_e=tag(ide) if e(sample)==1
	count if t1_e==1 & hascard==1
	local etrNt=string(r(N), "%15.0fc")
	count if t1_e==1 & hascard==0
	local etrNc=string(r(N), "%15.0fc")
	
texdoc init "FirmFE_hascard2", force replace
tex \begin{tabular}{lccccc}\hline
tex & Log Output VAT & Log Input VAT & Positive Liability & Net Liability & ETR \\ \hline
tex Has POS Terminal & `taxsaled'& `taxpurd' & `posid' & `netliabd' & `etrd' \\
tex  & `taxsalese'& `taxpurse' & `posise' & `netliabse' & `etrse'\\ \hline
tex Mean & `taxsale_m' & `taxpur_m' & `posi_liab_m' & `etr_m' \\ \hline
tex Firm FE & Yes & Yes & Yes & Yes & Yes \\
tex Year FE & Yes & Yes & Yes & Yes & Yes \\
tex Turnover Control FE & Yes & Yes & Yes & Yes & Yes \\ \hline
tex N Treated & `taxsaleNt' & `taxpurNt' & `netliabNt' & `posiNt' & `etrNt' \\
tex N Control & `taxsaleNc' & `taxpurNc' & `netliabNc' & `posiNc' & `etrNc' \\ \hline
tex \end{tabular}
texdoc close 
restore

gen montevideo=coddeptofiscal==10

probit hascard cantidadsucursales cede log_turnover retail wholesale construction hotelfood entretaiment finance other_services age montevideo if year==2013

margins, dydx(*)
matrix hascard=r(table)
matrix list hascard

	local branches_b=string(hascard[1,1], "%15.3fc")
	local branches_se=string(hascard[2,1], "%15.3fc")
	local cede_b=string(hascard[1,2], "%15.3fc")
	local cede_se=string(hascard[2,2], "%15.3fc")
	local turnover_b=string(hascard[1,3], "%15.3fc")
	local turnover_se=string(hascard[2,3], "%15.3fc")
	local retail_b=string(hascard[1,4], "%15.3fc")
	local retail_se=string(hascard[2,4], "%15.3fc")
	local wholesale_b=string(hascard[1,5], "%15.3fc")
	local wholesale_se=string(hascard[2,5], "%15.3fc")
	local construction_b=string(hascard[1,6], "%15.3fc")
	local construction_se=string(hascard[2,6], "%15.3fc")
	local hotelfood_b=string(hascard[1,7], "%15.3fc")
	local hotelfood_se=string(hascard[2,7], "%15.3fc")
	local entretaiment_b=string(hascard[1,8], "%15.3fc")
	local entretaiment_se=string(hascard[2,8], "%15.3fc")
	local finance_b=string(hascard[1,9], "%15.3fc")
	local finance_se=string(hascard[2,9], "%15.3fc")
	local other_services_b=string(hascard[1,10], "%15.3fc")
	local other_services_se=string(hascard[2,10], "%15.3fc")
	local age_b=string(hascard[1,11], "%15.3fc")
	local age_se=string(hascard[2,11], "%15.3fc")
	local montevideo_b=string(hascard[1,12], "%15.3fc")
	local montevideo_se=string(hascard[2,12], "%15.3fc")


texdoc init "probit_hascard", force replace
tex \begin{tabular}{lc}\hline
tex & dydx \\ \hline
tex Log(Turnover+1) & `turnover_b' \\
tex & (`turnover_se') \\
tex N Branches & `branches_b' \\
tex & (`branches_se') \\
tex Montevideo & `montevideo_b' \\
tex & (`montevideo_se') \\
tex Age & `age_b' \\
tex & (`age_se') \\
tex CEDE & `cede_b' \\
tex & (`cede_se') \\
tex Retail & `retail_b' \\
tex & (`retail_se') \\
tex Wholesale & `wholesale_b' \\
tex & (`wholesale_se') \\
tex Hotel and Restaurants & `hotelfood_b' \\
tex & (`hotelfood_se') \\
tex Entretaiment & `entretaiment_b' \\
tex & (`entretaiment_se') \\
tex Construction & `construction_b' \\
tex & (`construction_se') \\
tex Finance & `finance_b' \\
tex & (`finance_se') \\
tex Other Services & `other_services_b' \\
tex & (`other_services_se') \\ \hline
tex \end{tabular}
texdoc close 


egen meanhascard=mean(hascard), by(ide)

egen minyear=min(year) if meanhascard!=0 & meanhascard!=1 & hascard==1, by(ide)

egen mean_year=mean(minyear) if meanhascard!=0 & meanhascard!=1, by(ide)

gen post=(year>=mean_year) if meanhascard!=0 & meanhascard!=1

gen hascard_model=hascard if meanhascard==0 | meanhascard==1
replace hascard_model=post if meanhascard!=0 & meanhascard!=1

stset year, id(ide) failure(hascard_model) scale(1)


stcox cantidadsucursales cede log_turnover retail wholesale construction hotelfood entretaiment finance other_services age montevideo, vce(robust)
matrix hz_ratio=r(table)
matrix list hz_ratio
gen sample_c1=e(sample)
egen tag_firms_c1=tag(ide) if sample_c1==1
count if tag_firms_c1==1
local n1=string(r(N), "%15.0fc")
stcox cantidadsucursales cede log_turnover retail wholesale construction hotelfood entretaiment finance other_services age montevideo, nohr vce(robust)
matrix coeff=r(table)
matrix list coeff
gen sample_c2=e(sample)
egen tag_firms_c2=tag(ide) if sample_c2==1
count if tag_firms_c2==1
local n2=string(r(N), "%15.0fc")

	local branches_b=string(hz_ratio[1,1], "%15.3fc")
	local branches_se=string(hz_ratio[2,1], "%15.3fc")
	local cede_b=string(hz_ratio[1,2], "%15.3fc")
	local cede_se=string(hz_ratio[2,2], "%15.3fc")
	local turnover_b=string(hz_ratio[1,3], "%15.3fc")
	local turnover_se=string(hz_ratio[2,3], "%15.3fc")
	local retail_b=string(hz_ratio[1,4], "%15.3fc")
	local retail_se=string(hz_ratio[2,4], "%15.3fc")
	local wholesale_b=string(hz_ratio[1,5], "%15.3fc")
	local wholesale_se=string(hz_ratio[2,5], "%15.3fc")
	local construction_b=string(hz_ratio[1,6], "%15.3fc")
	local construction_se=string(hz_ratio[2,6], "%15.3fc")
	local hotelfood_b=string(hz_ratio[1,7], "%15.3fc")
	local hotelfood_se=string(hz_ratio[2,7], "%15.3fc")
	local entretaiment_b=string(hz_ratio[1,8], "%15.3fc")
	local entretaiment_se=string(hz_ratio[2,8], "%15.3fc")
	local finance_b=string(hz_ratio[1,9], "%15.3fc")
	local finance_se=string(hz_ratio[2,9], "%15.3fc")
	local other_services_b=string(hz_ratio[1,10], "%15.3fc")
	local other_services_se=string(hz_ratio[2,10], "%15.3fc")
	local age_b=string(hz_ratio[1,11], "%15.3fc")
	local age_se=string(hz_ratio[2,11], "%15.3fc")
	local montevideo_b=string(hz_ratio[1,12], "%15.3fc")
	local montevideo_se=string(hz_ratio[2,12], "%15.3fc")
	
	local branches_b_c=string(coeff[1,1], "%15.3fc")
	local branches_se_c=string(coeff[2,1], "%15.3fc")
	local cede_b_c=string(coeff[1,2], "%15.3fc")
	local cede_se_c=string(coeff[2,2], "%15.3fc")
	local turnover_b_c=string(coeff[1,3], "%15.3fc")
	local turnover_se_c=string(coeff[2,3], "%15.3fc")
	local retail_b_c=string(coeff[1,4], "%15.3fc")
	local retail_se_c=string(coeff[2,4], "%15.3fc")
	local wholesale_b_c=string(coeff[1,5], "%15.3fc")
	local wholesale_se_c=string(coeff[2,5], "%15.3fc")
	local construction_b_c=string(coeff[1,6], "%15.3fc")
	local construction_se_c=string(coeff[2,6], "%15.3fc")
	local hotelfood_b_c=string(coeff[1,7], "%15.3fc")
	local hotelfood_se_c=string(coeff[2,7], "%15.3fc")
	local entretaiment_b_c=string(coeff[1,8], "%15.3fc")
	local entretaiment_se_c=string(coeff[2,8], "%15.3fc")
	local finance_b_c=string(coeff[1,9], "%15.3fc")
	local finance_se_c=string(coeff[2,9], "%15.3fc")
	local other_services_b_c=string(coeff[1,10], "%15.3fc")
	local other_services_se_c=string(coeff[2,10], "%15.3fc")
	local age_b_c=string(coeff[1,11], "%15.3fc")
	local age_se_c=string(coeff[2,11], "%15.3fc")
	local montevideo_b_c=string(coeff[1,12], "%15.3fc")
	local montevideo_se_c=string(coeff[2,12], "%15.3fc")

	
texdoc init "hazard_hascard", force replace
tex \begin{tabular}{lcc}\hline
tex & Hazard Ratio & Coefficient \\ \hline
tex Log(Turnover+1) & `turnover_b' & `turnover_b_c' \\
tex & (`turnover_se') & (`turnover_se_c') \\
tex N Branches & `branches_b' & `branches_b_c'  \\
tex & (`branches_se') & (`branches_se_c') \\
tex Montevideo & `montevideo_b' & `montevideo_b_c' \\
tex & (`montevideo_se')  & (`montevideo_se_c') \\
tex Age & `age_b' & `age_b_c' \\
tex & (`age_se') & (`age_se_c') \\
tex CEDE & `cede_b'  & `cede_b_c' \\
tex & (`cede_se') & (`cede_se_c') \\
tex Retail & `retail_b' & `retail_b_c' \\
tex & (`retail_se') & (`retail_se_c') \\
tex Wholesale & `wholesale_b' & `wholesale_b_c' \\
tex & (`wholesale_se')  & (`wholesale_se_c')\\
tex Hotel and Restaurants & `hotelfood_b' & `hotelfood_b_c' \\
tex & (`hotelfood_se') & (`hotelfood_se_c') \\
tex Entretaiment & `entretaiment_b' & `entretaiment_b_c' \\
tex & (`entretaiment_se') & (`entretaiment_se_c') \\
tex Construction & `construction_b' & `construction_b_c' \\
tex & (`construction_se') & (`construction_se_c') \\
tex Finance & `finance_b' & `finance_b_c' \\
tex & (`finance_se')  & (`finance_se_c') \\
tex Other Services & `other_services_b' & `other_services_b_c' \\
tex & (`other_services_se')  & (`other_services_se_c') \\ \hline
tex N & `n1' & `n2' \\ \hline
tex \end{tabular}
texdoc close 