*TRANSACTION DATA BY FIRM MONTH-REBATE
foreach y in 2012 2013 2014 2015 {
use "$stata_raw\card_data_ext_`y'.dta", clear

gen rebate=(tot_credito>0 & tot_credito!=.)

gen count=1

gen rebate_rate=((tot_credito/tot_venta)*122) if rebate==1
replace rebate_rate=0 if rebate==0

egen mean_rebate_rate_firm=mean(rebate_rate), by(id_afi month)

collapse (sum) count tot_venta tot_credito (mean) mean_rebate_rate_firm , by(id_afi month rebate)
gen year=`y'

save "$datadir\card_ym_`y'.dta", replace
}

use "$datadir\card_ym_2012.dta", clear
foreach y in 2013 2014 2015 {
append using "$datadir\card_ym_`y'.dta"
}

foreach y in 2012 2013 2014 2015 {
erase "$datadir\card_ym_`y'.dta"
}

drop if id_afi==0
rename id_afi ide

reshape wide count tot_venta tot_credito mean_rebate_rate_firm, i(ide year month) j(rebate)

drop mean_rebate_rate_firm0
egen total_count=rowtotal(count0 count1)
egen total_vol=rowtotal(tot_venta0 tot_venta1)

gen rebate_rate_ad=(tot_credito1/tot_venta1)*122
gen rebate_rate_ad_m=rebate_rate_ad
gen rebate_card=rebate_rate_ad if rebate_rate_ad<=10
gen rebate_card_z=rebate_card
replace rebate_card_z=0 if rebate_card_z==.
replace rebate_rate_ad=0 if rebate_rate_ad==.

gen mean_rebate_rate_firm_z=mean_rebate_rate_firm1
replace mean_rebate_rate_firm_z=0 if mean_rebate_rate_firm1==.
save "$datadir\firm_card_data.dta", replace

******************
* VAT return data 
	use "${datadir}\vat_returns_month_long.dta", clear	
	keep if year<=2015 & year>=2012
	drop if year==2012 & month<=9
		
		gen one = 1
							
		** Retail + Wholesale
		bysort ide: egen sector = max(codgiro)
		gen retail = 0
		replace retail = 1 if floor(codgiro/1000) == 47
		gen wholesale = 0
		replace wholesale = 1 if floor(codgiro/1000) == 46
		
		drop if retail == 0 & wholesale == 0
		
		
		sort ide period
		xtset ide period
		
		sum period if year==2014 & month==8 
		gen distt=period-`r(mean)'
		gen post=distt>=0
		
		*POS pre reform
		egen card_pre_aux=max(hascard), by(post ide)
		replace card_pre_aux=. if post==1
		egen card_pre=mean(card_pre_aux), by(ide)
		
		gen r7=((retail==1 & card_pre==1) | retail==0)
		
		*keep if r7==1
	
		cap gen did_rvsw=retail*post
		
		merge 1:1 year month ide using "$datadir\firm_card_data.dta", gen(merge_card)
		drop if merge_card==2
		
*sales
egen sales=rowtotal(rlinea_14 rlinea_214)
gen sales_m=sales if cede==1
replace sales_m=sales/12 if cede==0 

*vat_rebate
gen vat_rebate=((tot_credito1>0 & tot_credito1!=.)*100)

*count_transactions
gen count1_th=count1/1000
replace count1_th=0 if count1_th==0

*rebate_sale
gen rebate_sale_2=(tot_venta1/sales_m)*100
replace rebate_sale_2=0 if rebate_sale_2==.



			foreach x in vat_rebate rebate_sale_2  {
			reghdfe `x' did_rvsw, abs(i.period i.ide) vce(cluster ide)	
			local b_did_`x'=string(_b[did_rvsw], "%15.3fc")
			}
			
			
			
		collapse (sum) count1 count1_th total_count tot_venta1 total_vol tot_credito1 ///
		(mean)  vat_rebate rebate_sale_2 , by(period distt retail)
		
		gen post=(dist>=0)
		gen did_rvsw=retail*post
		
		*millions
		replace tot_venta1=tot_venta1/1000000


			foreach x in /*vat_rebate rebate_sale_2*/ count1_th tot_venta1  {
			reghdfe `x' did_rvsw retail, abs(i.period) vce(cluster retail)	
			local b_did_`x'=string(_b[did_rvsw], "%15.3fc")
			}
			
			local vat_rebate_ty="25"
			local count1_th_ty="6000"
			local rebate_sale_2_ty="25" 
			local tot_venta1_ty="6000"
			
			foreach x in vat_rebate rebate_sale_2     {
				local `x'_l="Share"
			}
			

			local count1_th_l= "Thousands"
			local tot_venta1_l= "Millions"
			
			foreach x in vat_rebate rebate_sale_2 count1_th tot_venta1 {
				twoway  (conn `x' period if retail==0,  lpattern(dash) msymbol(x)  msize(vlarge) lcolor(blue)  mcolor(blue)) ///
			    (conn `x' period if retail==1, lcolor(red)  mcolor(red)), ///
				tline(2014m7, lcolor(gs5) lpattern(dash)) ytitle("``x'_l'") graphregion(c(white)) ///
				legend(row(1) order(1 2) lab(1 "Wholesale") lab(2 "Retail")) ///
				xtitle(Year-Month) ttext(``x'_ty' 2014m8 "VAT Rebates Expanded", place(e)) ///
				note("DiD Estimate: `b_did_`x''") 
				graph export did_`x'_2014.pdf, replace	

			}



