

/****************************************************************/
// Figure D.4. SHARE OF CARD SALES IN TOTAL SALES IN COSTA RICA 
/****************************************************************/

	// Paths
	glo	crdatadir     "D:\Costa Rica\data"  
	*folder contains the raw data obtained rom the Costa Rican tax authority

	// Get VAT data and keep relavant variables
		insheet using "${crdatadir}\Data 2015-10-07 - Plan de ventas\VENTAS_BM1.txt", delim("|") clear 
		gen year=substr(d_periodo,1,4)
		destring year, replace
		keep if year==2013	
		foreach v in p_vta_expor p_vta_exe p_vta_gra p_otros_rubros {
		destring `v', replace dpcomma
		}
		egen tsales=rowtotal(p_vta_expor p_vta_exe p_vta_gra p_otros_rubros)		
		ren nro_idu idu
		collapse tsales, by(year idu)
		so idu
		tempfile cr_sales
		sa `cr_sales'
	
	// Get D153 card transactions data and keep relevant variables
		insheet using "${crdatadir}\Data 2015-07-05 - informes control extensivo julio (renta+informativas)\D153.txt", delim("|") clear 
		gen year=substr(d_periodo,1,4)
		destring year, replace
		keep if year==2013	
		cap destring p_trans_mes, dpcomma replace
		ren p_trans_mes d153base
		ren nro_idu_rete idu
		collapse d153base, by(year idu)
		so idu
	
	// Merge the two datasets, prepare relevant variable and stats 
		merge 1:1 idu using `cr_sales'
		gen scardsales=d153base/tsale		
		replace scardsales=. if scardsales>1 | scardsales==0
		drop if scardsale==.		
		sum scardsale if year==2013, det 
		global mean=round(`r(mean)',.01) // fix these !!!
		global p50=round(`r(p50)',.01)
	
	// Collapse data for connected graph 
		gen bin=round(scardsale,0.01)
		gen freq=1	
		collapse (sum) freq, by(bin year)
		bys year: egen total=total(freq)
		replace freq=freq/total
		drop if bin==. | bin==0
		so bin
		
	// Plot graph
		twoway (line freq bin if year==2013, lcolor(blue)),  /// 
		xline($mean, lpattern(dash)) xline($p50, lpattern(dashdot)) ///
		xtitle("Share of Electronic Sales in Reported Sales, E/R") ///
		ytitle(Density)  graphregion(fcolor(white)) /// 
		text(.02 $mean "2013 Mean: $mean", place(ne) orient(vertical)) ///
		text(.02 $p50 "2013 Median: $p50", place(ne) orient(vertical))							
		graph export "costarica_cardsales_congraph_replication.pdf", replace 
