use "$stata_raw\unidades_indexadas_daily.dta", clear 
		* This is monthly UI
		gen period=mofd(mdy(month, day, year))
		format period %tm
		sort year month day
		rename UI ui
		collapse (first) ui, by(period)
		foreach y of numlist 2010 2011 {
		sum ui if period==tm(`y'm12)
		glo ui_`y'm12 = r(mean)
		}
		tempfile ui
		save "`ui'"
		
	use "${datadir}/vat_returns_month_long.dta", clear
		merge m:1 period using "`ui'"
		keep if _merge==3
		drop _merge
	
		rename tot_venta total_venta
		rename tot_credito total_credito
		rename rtot_venta rtotal_venta
		rename rtot_credito rtotal_credito
		replace rtotal_credito=0 if rtotal_credito==.
		replace total_credito=0 if total_credito==.
		gen creditopos=(total_credito>0)
		
		* To generate eligibility for POS Subsidy and above/below median turnover categories, get 2010 and 2011 turnover from VAT. 
		* For CEDE, add monthly records. For non-CEDE, take any file that year:
		foreach y of numlist 2010 2011{
		bysort ide: egen double totinc`y'_vat_ui_cede = sum((rlinea_14+rlinea_214)*(cpi/100)/ui) if year==`y' & cede==1
		gen double totinc`y'_vat_ui_nocede=((rlinea_14+rlinea_214)*(cpi/100)/${ui_`y'm12}) if year==`y' & cede==0
		egen double totinc`y'_vat_ui_aux = rsum(totinc`y'_vat_ui_cede totinc`y'_vat_ui_nocede)
		replace totinc`y'_vat_ui_aux=. if missing(totinc`y'_vat_ui_cede) & missing(totinc`y'_vat_ui_nocede)
		bysort ide: egen double totinc`y'_vat_ui = mean(totinc`y'_vat_ui_aux)
		}
		* For turnover size comparison: If no 2011 VAT, use 2010 VAT. If not available either, code as 0:
		gen double totinc_ui = totinc2011_vat_ui
		replace totinc_ui = totinc2010_vat_ui if missing(totinc_ui)
		replace totinc_ui = 0 if missing(totinc_ui)
		
		* Eligibility = 1  if sales of last fiscal period "sufficiently" below UI 4 million :
		 local tolerance = 0
		 gen eligible = .
		 replace eligible = 1 if totinc_ui<(4e6-`tolerance')
		 replace eligible = 0 if totinc_ui>=(4e6+`tolerance')
		 replace eligible = . if totinc_ui==.
 
		* Merge with POS subsidy data:
		merge 1:1 ide year month using "$stata_raw/BM_Subsidy.dta"
		keep if _merge!=2
		drop _merge
		sort id period
		gen hassub = !missing(pos)

		* POS subsidy reform in Sep 2012
		gen distt=period-tm(2012m9)	
		
		* Builds retail/wholesale categories based on CIIU sector info a la Naritomi:
		gen retail = 0
		replace retail = 1 if floor(codgiro/1000) == 47

		gen wholesale = 0
		replace wholesale = 1 if floor(codgiro/1000) == 46
		
		* Replace with missing if negative VAT sales or VAT purchases
		replace rtaxsale = . if rtaxsale<0
		replace rtaxpur = . if rtaxpur<0
				

	egen minperiod=min(period) if hassub==1, by(ide)
egen first_sub=min(minperiod), by(ide)
gen dist_firm_sub=period-first_sub
gen post_sub=(dist_firm_sub>=0 & dist_firm_sub!=.)
egen hascard_pre=max(hascard), by(ide post_sub)
gen hascard_pre_aux=hascard_pre if post_sub==0
egen pre_card=max(hascard_pre_aux) if first_sub!=., by(ide)

gen first_timers=(pre_card==0) if first_sub!=. & eligible==1

drop minperiod
egen minperiod=min(period) if hascard==1, by(ide)
egen first_card=min(minperiod), by(ide)
gen dist_card_sub=first_card-first_sub

preserve
duplicates drop ide, force
drop if retail == 0 
keep if pre_card==1
gen more_three_months=(dist_card_sub<=-3) if pre_card==1
tab more_three_months
restore

		
		drop if retail == 0 
		drop if distt==15 // drop 2013m12

		gen one = 1
		collapse (sum) hassub one (mean) share_sub=hassub first_timers, by(period)		 
		gen double sh = (hassub/one)*100
		replace first_timers=first_timers*100
	
		twoway 	(conn sh period if period>=tm(2012m6) & period<tm(2015m6), msymbol(circle) lcolor(red) mcolor(red)) (conn first_timers period if period>=tm(2012m6) & period<tm(2015m6), msymbol(T) lcolor(blue) mcolor(blue) yaxis(2)), graphregion(c(white)) xtitle("Time") ///
				 ytitle("Share of Eligible Retail Firms (%)") ytitle("Share of Subsidy Receiving Retail Firms (%)", axis(2)) tlab(2012m6 2012m12 2013m6 2013m12 2014m6 2014m12 2015m6) tline(2012m10, lcolor(black)) ylabel(0(5)20, axis(2)) ///
				 legend(order(1 2) row(2) lab(1 "Firms Receiving POS Subsidy (Left Axis)") lab(2 "Firms Without POS before Subsidy (Right Axis)")) ttext(9.7 2012m11 " {&lArr} POS Subsidies Become Available", place(e)) 
	
			graph export subsidy_firms_share.pdf, replace	
