
// NOTE: TO RUN THIS FILE, YOU NEED TO CHANGE THE FILE PATH IN LINE 9  
		* DOWNLOAD THE RAW SURVEY DATASETS INTO THE DATA FOLDER, following the instructions in the readme file 

***************
* DIRECTORIES *
***************

	global main "C:/Users/wb614536/Github/uruguay_tax_rebates/PUBLIC_DATA_CODES"		
	global rawdatadir "$main/data"
	global outdir "$main/graphs"
	
	set varabbrev on
	
	sysdir set PLUS "$main/dofiles/ado/"

	*cap ssc install valuesof
	*cap ssc install moremata
		
		
************************************
* PRODUCING FIGURE D5, PANEL B
************************************	
	*This code is based on the replication for Bachas et al 2023 [Review of Economic Studies], Informality, Consumption Taxes and Redistribution
	
	/* Scenarios: 
	central: modern taxed (large stores and specialized stores), traditional untaxed (self-production, non brick and mortar, corner sdtores)
	proba: applies probabilities of being taxed by store type using the MX census
	specific: country specific probabilities for modern and traditional using retail reports ("$main/proc/dataset_formalityshare_actualpredict.dta") 
	robust: moves specialized stores to traditional (unused in the paper)
	*/ 
	
	*** INFORMALITY DEFINITION
	global scenario = "central"			// Choose scenario to be run: central, specific, vat_input, proba, robust
	display "$scenario"
	
	if "$scenario" == "central" {
			global Inf_weight_5 = 0		// Share of large stores informal 
			global Inf_weight_4 = 0		// Share of specialized stores informal
			global Inf_weight_3 = 1		// Share of corner stores informal
			global Inf_weight_2 = 1		// Share of non brick and mortar front informal
			}
	else if "$scenario" == "vat_input" {
			global Inf_weight_5 = 0		// Share of large stores informal 
			global Inf_weight_4 = 0		// Share of specialized stores informal
			global Inf_weight_3 = 0.9		// Share of corner stores informal
			global Inf_weight_2 = 0.9		// Share of non brick and mortar front informal	
			}
	else if "$scenario" == "proba" {
			global Inf_weight_5 = 0.1	// Share of large stores informal 
			global Inf_weight_4 = 0.5	// Share of specialized stores informal
			global Inf_weight_3 = 0.9	// Share of corner stores informal
			global Inf_weight_2 = 1		// Share of non brick and mortar front informal
			}	
	else if "$scenario" == "robust" {
			global Inf_weight_5 = 0		// Share of large stores informal 
			global Inf_weight_4 = 1		// Share of specialized stores informal
			global Inf_weight_3 = 1		// Share of corner stores informal
			global Inf_weight_2 = 1		// Share of non brick and mortar front informal	
			}		
			
	global format eps // Change to pdf for higher graph resolution
	
	** RUN DO FILES
	
	cd "$main\dofiles"
	
	** To clean Uruguay's ENIGH data
		do _figD5_b_clean_enigh.do
	
	** To install all necessary packages 
		  do _figD5_b_config_data.do
	
	** Descriptive Figures: Based on microdata, country by country 
		  do _figD5_b_Informality_Engel_curves.do				
		  
**********************************************
* PRODUCING FIGURE D5, PANELS A AND C
**********************************************

	do _figD5_a_c.do
	

**********************************************
* PRODUCING FIGURES A1 AND A9
**********************************************

	do _figA1_figA9.do 

**********************************************
* PRODUCING FIGURES B8
**********************************************
	cd "$main\dofiles"
	do _figB8_argentina_mediospago.do 
