clear
import excel "$rawdatadir\debser.xls", sheet("MEP") cellrange(A26:M317) firstrow
keep debfec debmes deb062 deb064 deb067 deb069

*getting year 
tostring debfec, gen(date)
split date, p(.)
destring date1, replace 
drop if date1==. 

*fixing october
replace date2="10" if debmes=="Oct."
drop if date2=="13"
destring date2, replace

*year and month 
rename date1 year 
rename date2 month 

drop debfec date debmes

* pesos volume
rename deb062 m_pesos
* dollars volume
rename deb064 m_dollars
* pesos transaction number 
rename deb067 q_pesos
* dollars transaction number 
rename deb069 q_dollars


drop if month==.
replace q_dollars=. if q_dollars==0

*total trans
gen trans=q_pesos+q_dollars

gen modate=ym(year, month)
format modate %tm

* selected time frame
keep if year>=2009 & year<=2017
tset modate 

gen log_trans=log(trans)

* graph deseasonal levels
reg trans i.month 
gen trans_d=trans if month==1
	forvalues i = 2/12 {
			replace trans_d = trans- _b[`i'.month] if month==`i'
		
			}
			
twoway (conn trans_d modate, mcolor(navy%60) msymbol(circle_hollow) lcolor(navy%60) lpattern(shortdash)), tline(2009m12 2010m12 2011m12 2012m12 2013m12 2014m12 2015m12 2016m12 2017m12, lpattern(shortdash) lcolor(grey*0.2)) ///
ytitle("Number of Transactions" "Deseasonalized") xtitle(Year-Month) ///
 scale(1.2) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) ///
plotregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) tlabel(2009m12(18)2017m12) ///
tline(2014m8, lpattern(solid) lcolor(black))  graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
graph export "$outdir/argentina_trans_d.pdf", replace


*graph raw logs 
twoway (conn log_trans modate, mcolor(navy%60) msymbol(circle_hollow) lcolor(navy%60) lpattern(shortdash)), tline(2009m12 2010m12 2011m12 2012m12 2013m12 2014m12 2015m12 2016m12 2017m12, lpattern(shortdash) lcolor(grey*0.2)) ///
ytitle("Log Number of Transactions") xtitle(Year-Month) ///
 scale(1.2) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) ///
plotregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) ylabel(11(1)13) tlabel(2009m12(18)2017m12) /// 
tline(2014m8, lpattern(solid) lcolor(black))  graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
graph export "$outdir/argentina_logtrans.pdf", replace







