
//******************************************************************//
* This do file produces figure D5, panels A and C
//******************************************************************//

	// Get household characteristics data to retrieve income variable 
		use "$rawdatadir\Hogares_ECH_idEFHU.dta", clear
		duplicates drop hogar_id, force
		keep hogar_id ech_tht11
		rename ech_tht11 hh_income
		tempfile hhincome2014
		sa `hhincome2014'
	
	// Get survey data on card use
		use "$rawdatadir\Hogares_EFHU.dta", clear
		duplicates drop hogar_id, force
		rename d_38 has_cc
		rename d_61 has_dc
		recode has_cc (1=1 "si") (2=0 "no"), gen(has_cc_d)
		recode has_dc (1=1 "si") (2=0 "no"), gen(has_dc_d)
		gen any_card=(has_cc_d==1 | has_dc_d==1)
		
		gen cardshare=.
		replace cardshare=25 if d_76==1
		replace cardshare=50 if d_76==2
		replace cardshare=75 if d_76==3
		replace cardshare=100 if d_76==4
		replace cardshare=0 if has_dc_d==0
		
		keep hogar_id has_cc_d has_dc_d any_card cardshare
	
	// Merge data, prepare income deciles 
		merge 1:1 hogar_id using `hhincome2014', gen(merge_income)
		keep if merge_income==3 
		drop merge_income
		
		egen income_decile=cut(hh_income), group(10)

		gen conditional_debit=has_dc_d
		replace conditional_debit=. if any_card==0
		
		collapse (mean) any_card hh_income cardshare conditional_debit, by(income_decile)
		replace income_decile=income_decile+1
		
		foreach x in any_card conditional_debit {
		replace `x'=`x'*100
		}
		
	
	*PANEL A: Card ownership
	
		*Get ratio of rate in D10 vs D1: 
			sum any_card if income_decile==1
			local share1=`r(mean)'
			sum any_card if income_decile==10
			local shareten=`r(mean)'		
			local ratio=round(`shareten'/`share1',0.01)
	
			twoway (connected any_card income_decile, mcolor(orange_red) msymbol(square) lcolor(orange_red)) (connected conditional_debit income_decile, mcolor(forest_green) msymbol(triangle) lcolor(forest_green)),  graphregion(color(white)) plotregion(color(white))  bgcolor(white) ///
		 ytitle(Share of Households) xtitle(Income Decile) xlabel(1(1)10) ///
			legend(order(1 "Share with Credit or Debit Card" 2 "Share With Debit Card (Conditional on Any Card)" ) rows(2) ring(0) pos(5))   scale(0.9) note(Ratio of Card Ownership Share in D10 vs D1: `ratio' )
			graph export "$outdir/conditional_simple_replication.pdf", replace	


	*PANEL C: Debit card exenditure share
		
			*Get ratio of rate in D10 vs D1: 
			sum cardshare if income_decile==1
			local share1=`r(mean)'
			sum cardshare if income_decile==10
			local shareten=`r(mean)'		
			local ratio=round(`shareten'/`share1',0.01)
			
			twoway 	(connected cardshare income_decile, mcolor(red) msymbol(round) lcolor(red) lwidth(thick) lpattern(solid) yaxis(1)), graphregion(color(white))  plotregion(color(white)) bgcolor(white) ///
			ytitle(Share of Expenditure Paid by Debit Card) xtitle(Income Decile) xlabel(1(1)10) ///
			scale(0.9) note(Ratio of Debit Card Payment Share in D10 vs D1: `ratio' )
			graph export "$outdir/debit_card_exp_share_replication.pdf", replace	
				