README
 
This file explains how to replicate the analysis for the paper “Electronic Payment Technology and Tax Compliance: Evidence from Uruguay’s Financial Inclusion Reform” (American Economic Journal: Economic Policy, by Anne Brockmeyer and Magaly Saenz Somarriba), using STATA.


Data Availability Statement 

Administrative data

Access to the confidential tax data for Uruguay

Most of the analysis in this paper uses firm-level VAT declarations and firm characteristics from the taxpayer registry held by the Uruguayan tax authority. The authors accessed this data under the requirement that no micro data could be shared with third parties. The data that the research team obtained is stored on a secure World Bank server which only authorized World Bank staff and consultants can access.
The Uruguayan Tax Administration does not currently have a formal policy for granting access to these data. Any other person wishing to obtain access to the data would therefore have to approach the director of the Tax Administration and the head of the economic studies department and make a business case to them for access to the data. The case may also be reviewed by the Ministry of Finance. Since March 2020, the authors have not been able to obtain access to additional data for this project (beyond the data they had already accessed previously). The Tax Administrations’ policies for granting data access to researchers may change in the future, e.g. with a change in government. 

The authors are happy to facilitate introductions for researchers proposing projects for which they could make a business case. The authors are also committed to run any sensitivity analyses and share the results with anyone wishing to run such analyses. 

A replication analysis via the World Bank DIME replication service is being carried out. 

If the AEA data editor seeks to access the data, or seeks to nominate a third-party researcher to conduct an audit for the replication files, the authors may be able to provide them access to the data through the World Bank secure data server, subject to some conditions. In particular, the individual seeking to access the data would either already be a World Bank staff or consultant, or needs to be provided a non-fee consulting contract with the World Bank, which is subject to World Bank management approval. The individual seeking to access the data will also need to sign and abide by the World Bank’s data confidentiality agreement. 

Access to the confidential tax data for Costa Rica  

Appendix Figure D.4 (share of card sales in total reported sales in Costa Rica) uses micro administrative data from the Costa Rican tax administration as in the paper "Taxation, Information and Withholding: Evidence from Costa Rica" by Anne Brockmeyer and Marco Hernandez: https://www.annebrockmeyer.com/uploads/1/2/1/4/121485108/costa_rica_paper_2022-11-14.pdf. Specifically, the data uses the D104 sales tax declaration and the D153 credit and debit card withholding form for the year 2013. From the D104 data, we use the tax return boxes 20, 21, 22 and 23 (variables: ventas por exportaciones, ventas exentas y authorizadas sin impuesto, ventas gravadas, otros rubros a incluir en la base imponible) and sum them to construct total sales. From the D153 declaration, we use the variable “monto total de transacciones”, which captures the total amount of card transactions.
The access to this data is very similar to the access for the Uruguay data described above. The data is owned by the Costa Rican Tax Administration. The authors accessed this data under the requirement that no micro data could be shared with third parties. The data that the research team obtained is stored on a secure World Bank server which only authorized World Bank staff and consultants can access.
The Costa Rican Tax Administration does not currently have a formal policy for granting access to these data. Any other person wishing to obtain access to the data would therefore have to approach the director of the Tax Administration and make a business case to them for access to the data. The case may also be reviewed by the Ministry of Finance.  
The authors are happy to facilitate introductions for researchers proposing projects for which they could make a business case. The authors are also committed to run any sensitivity analyses and share the results with anyone wishing to run such analyses. 
A replication analysis via the World Bank DIME replication service is being carried out. 
If the AEA data editor seeks to access the data, or seeks to nominate a third-party researcher to conduct an audit for the replication files, the authors may be able to provide them access to the data through the World Bank secure data server, subject to the above-listed conditions.


Publicly available data

The following datasets need to be downloaded and saved in the folder \PUBLIC_DATA_CODES\data.
World Bank global findex data (Figure A1, panels A.I and A.II, and Figure A.9)
The Findex data can be downloaded here: https://www.worldbank.org/en/publication/globalfindex/Data (go to country-level data and download the stata version).
The codes merge this data with GDP per capita data from the World Development Indicators (also used in some of the other figures mentioned below). To download the GDP per capita data, go to https://databank.worldbank.org/source/world-development-indicators, and select:
Countries: all, time period: 2011 and 2017, series: GDP per capita, constant 2015 US$
Unselect everything else. Then download as a CSV file. Unzip it, and discard the smaller of the two resulting CSV files (which is a meta data file). Save the other file under the name WDI_gdp_pc.csv in the data folder.


Informality rates (Figure A1, panel B)

The data is from Table A.1. in the IMF working paper by Schneider and Medina (2018): Shadow economies around the world: What did we learn over the last 20 years? https://www.imf.org/en/Publications/WP/Issues/2018/01/25/Shadow-Economies-Around-the-World-What-Did-We-Learn-Over-the-Last-20-Years-45583
We extracted the data from the pdf into a dta file (data_informality.dta) which is part of the replication package (in the folder PUBLIC_DATA_CODES – to be transferred into the data folder).


Uruguay households finance survey (Figure D.5, panels A and C)

These data, used to construct figure D5, panels A and C, can be downloaded here: 
https://docs.google.com/forms/d/e/1FAIpQLSdJqJG-3gH2ykI_woUf8Xx4hl47bI_HJTDFM3QZSeNkTM9-Pw/viewform?embedded=true 
If this does not work, go the his link: https://cienciassociales.edu.uy/departamento-de-economia/investigacion/encuesta-financiera-de-los-hogares-uruguayos/ Go to EFHU 2, and click “solicitor accesso a microdatos”. A form will open that you should fill in and submit. 
The data will then be sent to the email address you indicate when submitting the form. 	

ENIGH household survey data from the Uruguay National Institute of Statistics (INE) (Figure D.5, panel B)

To obtain these data, go to the following link: https://www4.ine.gub.uy/Anda5/index.php/catalog/42, click on the tab “obtener microdatos”, register as a user and then enter your account details to enter the protected part of the website. Then download “Conjunto de datos de los hogares”, “Características demográficas de las personas del hogar” and “Consumos”. Unzip the files. You should obtain the files personas.DBF, hogar.DBF and consumos.DBF. Add these to the data folder. 
Alternatively (or if the above website link is not working), you can send an email to difusion@ine.gub.uy to request the micro data. In the document “Data request Spanish for INE.docx” in this replication folder, you will see the project description we provided to INE.
Note that we used the 2005-2006 data, as it was the latest available data when we conducted the analysis. The 2016 data has recently been released.

Argentina Central Bank Means of Payment Statistics (Figure B.8)

The data needs to be downloaded from: https://www.bcra.gob.ar/PublicacionesEstadisticas/Cuadros_estandarizados_series_estadisticas.asp selecting the following options: --> Volumen de transacciones, instrumentos de pago, infraestructura del sistema financiero e informaciones por división política.--> Medios de pago -->  Volumen de transacciones e instrumentos de pago, por tipo de depósito y canal. This should download an excel file titled "debser". Add this file to the data folder. 


Instructions for Data Preparation and Analysis


This replication package contains two sets of codes. The first set of codes, in the folder ADMIN_DATA_CODES, draws on the confidential tax data. For users replicating the analysis on the World Bank secure tax data server, this folder should be transferred into the server (into the folder “Replication”) via OneDrive or with the help of World Bank IT (Brandon Mills). The first few lines in the Master do-file tell you which file paths you need to update and which folders you need to create so that the code executes correctly. Then please execute the master file, and this should run all other codes. 


Some of the do files execute more than one exhibit, for this we created globals to select which specific to execute. To replicate everything make sure all options of globals in lines 80, 91, 108, 191-192, and 214 are all un-commented out. 


At the end, one manual step is required: For the figures did_2lines_nliab_ab_10_11_log_modif_99_r7_as1_esp10_wholesale.gph and did_2lines_nliab_ab_10_11_log_modif_99_r99_as1_esp10_wholesale.gph [figure 3, panel C.I, and figure C.2, panel C.I], open the gph files, and in the note below the graph, add the point estimate (PE) and standard error (SE) from the synthetic difference-in-difference (SDID) estimation. For figure did_2lines_nliab_ab_10_11_log_modif_99_r7_as1_esp10_wholesale.gph [figure 3, panel C.I0], the PE and SE are found in 1 did_robust_table_logmodif_mixed.tex, column 9 [table 1]. For Figure did_2lines_nliab_ab_10_11_log_modif_99_r99_as1_esp10_wholesale.gph [figure C.2, panel C.I], the PE and SE are found in table did_robust_table_logmodif_mixed_r99.tex, column 9 [table C.7]. After changing the PE and SE manually in these figures, export the figure as PDF, adding the postscript _edit to the name. Note that we opted for having this manual step, as it allows us to otherwise run the SDID separately from the main DID analysis, which facilitates trouble-shooting the code, as the SDID takes a long time to run. 


The second set of codes, in the folder PUBLIC_DATA_CODES\dofiles, runs on publicly available data described above, and should not be transferred into the secure data server. These codes produce only appendix exhibits. The first few lines in Master_public_data.do tell you which file paths you need to update so that the code executes correctly.
If any of the raw datasets are compressed, please unzip them. 

Execution time

The codes for the publicly available data should take no more than 20 minutes to run. 

The codes for the confidential tax data (on the server) should run in about 8 hours. To achieve this speed, we made a simplifying tweak in the synthetic difference-in-difference estimation (SDID) [setting a low number of bootstrap iterations] which implies that the present version of the code will replicate the point estimates for the SDID estimations (and everything else in the paper and appendix) but will not correctly replicate the SDID standard errors. We suggest that the replicator first runs this version of the code, to make sure everything executes, and then reruns it to obtain the right standard errors for the SDID.

To obtain the same SDID standard errors as in the paper and appendix, change the globals “run_time” and “replication” in 0_master_replication.do to 50 and 500 respectively (note that each of the globals appears multiple times in this code - lines 163,164,195,196,216, and 217). After this change, the code will take 3-4 days to run. 




